Class: Aws::Outposts::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Outposts::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-outposts/client.rb,
sig/client.rbs
Overview
An API client for Outposts. To construct a client, you need to configure a :region and :credentials.
client = Aws::Outposts::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CancelCapacityTaskResponseSuccess, _CancelOrderResponseSuccess, _CreateOrderResponseSuccess, _CreateOutpostResponseSuccess, _CreatePrivateConnectivityConfigResponseSuccess, _CreateQuoteResponseSuccess, _CreateRenewalResponseSuccess, _CreateSiteResponseSuccess, _DeleteOutpostResponseSuccess, _DeleteQuoteResponseSuccess, _DeleteSiteResponseSuccess, _GetCapacityTaskResponseSuccess, _GetCatalogItemResponseSuccess, _GetConnectionResponseSuccess, _GetOrderResponseSuccess, _GetOutpostBillingInformationResponseSuccess, _GetOutpostInstanceTypesResponseSuccess, _GetOutpostResponseSuccess, _GetOutpostSupportedInstanceTypesResponseSuccess, _GetPrivateConnectivityConfigResponseSuccess, _GetQuoteResponseSuccess, _GetRenewalPricingResponseSuccess, _GetSiteAddressResponseSuccess, _GetSiteResponseSuccess, _ListAssetInstancesResponseSuccess, _ListAssetsResponseSuccess, _ListBlockingInstancesForCapacityTaskResponseSuccess, _ListCapacityTasksResponseSuccess, _ListCatalogItemsResponseSuccess, _ListOrderableInstanceTypesResponseSuccess, _ListOrdersResponseSuccess, _ListOutpostsResponseSuccess, _ListQuotesResponseSuccess, _ListSitesResponseSuccess, _ListTagsForResourceResponseSuccess, _StartCapacityTaskResponseSuccess, _StartConnectionResponseSuccess, _StartOutpostDecommissionResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateOutpostResponseSuccess, _UpdateQuoteResponseSuccess, _UpdateSiteAddressResponseSuccess, _UpdateSiteRackPhysicalPropertiesResponseSuccess, _UpdateSiteResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_capacity_task(params = {}) ⇒ Struct
Cancels the capacity task.
-
#cancel_order(params = {}) ⇒ Struct
Cancels the specified order for an Outpost.
-
#create_order(params = {}) ⇒ Types::CreateOrderOutput
Creates an order for an Outpost.
-
#create_outpost(params = {}) ⇒ Types::CreateOutpostOutput
Creates an Outpost.
-
#create_private_connectivity_config(params = {}) ⇒ Types::CreatePrivateConnectivityConfigOutput
Creates the private connectivity configuration for the specified Outpost.
-
#create_quote(params = {}) ⇒ Types::CreateQuoteOutput
Creates a quote for an Outpost.
-
#create_renewal(params = {}) ⇒ Types::CreateRenewalOutput
Creates a renewal contract for the specified Outpost.
-
#create_site(params = {}) ⇒ Types::CreateSiteOutput
Creates a site for an Outpost.
-
#delete_outpost(params = {}) ⇒ Struct
Deletes the specified Outpost.
-
#delete_quote(params = {}) ⇒ Struct
Deletes the specified quote.
-
#delete_site(params = {}) ⇒ Struct
Deletes the specified site.
-
#get_capacity_task(params = {}) ⇒ Types::GetCapacityTaskOutput
Gets details of the specified capacity task.
-
#get_catalog_item(params = {}) ⇒ Types::GetCatalogItemOutput
Gets information about the specified catalog item.
-
#get_connection(params = {}) ⇒ Types::GetConnectionResponse
Amazon Web Services uses this action to install Outpost servers. -
#get_order(params = {}) ⇒ Types::GetOrderOutput
Gets information about the specified order.
-
#get_outpost(params = {}) ⇒ Types::GetOutpostOutput
Gets information about the specified Outpost.
-
#get_outpost_billing_information(params = {}) ⇒ Types::GetOutpostBillingInformationOutput
Gets current and historical billing information about the specified Outpost.
-
#get_outpost_instance_types(params = {}) ⇒ Types::GetOutpostInstanceTypesOutput
Gets the instance types for the specified Outpost.
-
#get_outpost_supported_instance_types(params = {}) ⇒ Types::GetOutpostSupportedInstanceTypesOutput
Gets the instance types that an Outpost can support in
InstanceTypeCapacity. -
#get_private_connectivity_config(params = {}) ⇒ Types::GetPrivateConnectivityConfigOutput
Gets the private connectivity configuration for the specified Outpost.
-
#get_quote(params = {}) ⇒ Types::GetQuoteOutput
Gets information about the specified quote.
-
#get_renewal_pricing(params = {}) ⇒ Types::GetRenewalPricingOutput
Gets all available renewal pricing options for the specified Outpost.
-
#get_site(params = {}) ⇒ Types::GetSiteOutput
Gets information about the specified Outpost site.
-
#get_site_address(params = {}) ⇒ Types::GetSiteAddressOutput
Gets the site address of the specified site.
-
#list_asset_instances(params = {}) ⇒ Types::ListAssetInstancesOutput
A list of Amazon EC2 instances, belonging to all accounts, running on the specified Outpost.
-
#list_assets(params = {}) ⇒ Types::ListAssetsOutput
Lists the hardware assets for the specified Outpost.
-
#list_blocking_instances_for_capacity_task(params = {}) ⇒ Types::ListBlockingInstancesForCapacityTaskOutput
A list of Amazon EC2 instances running on the Outpost and belonging to the account that initiated the capacity task.
-
#list_capacity_tasks(params = {}) ⇒ Types::ListCapacityTasksOutput
Lists the capacity tasks for your Amazon Web Services account.
-
#list_catalog_items(params = {}) ⇒ Types::ListCatalogItemsOutput
Lists the items in the catalog.
-
#list_orderable_instance_types(params = {}) ⇒ Types::ListOrderableInstanceTypesOutput
Lists the instance types that can be ordered for an Outpost.
-
#list_orders(params = {}) ⇒ Types::ListOrdersOutput
Lists the Outpost orders for your Amazon Web Services account.
-
#list_outposts(params = {}) ⇒ Types::ListOutpostsOutput
Lists the Outposts for your Amazon Web Services account.
-
#list_quotes(params = {}) ⇒ Types::ListQuotesOutput
Lists the quotes for your Amazon Web Services account.
-
#list_sites(params = {}) ⇒ Types::ListSitesOutput
Lists the Outpost sites for your Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#start_capacity_task(params = {}) ⇒ Types::StartCapacityTaskOutput
Starts the specified capacity task.
-
#start_connection(params = {}) ⇒ Types::StartConnectionResponse
Amazon Web Services uses this action to install Outpost servers. -
#start_outpost_decommission(params = {}) ⇒ Types::StartOutpostDecommissionOutput
Starts the decommission process to return the Outposts racks or servers.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
-
#update_outpost(params = {}) ⇒ Types::UpdateOutpostOutput
Updates an Outpost.
-
#update_quote(params = {}) ⇒ Types::UpdateQuoteOutput
Updates the specified quote.
-
#update_site(params = {}) ⇒ Types::UpdateSiteOutput
Updates the specified site.
-
#update_site_address(params = {}) ⇒ Types::UpdateSiteAddressOutput
Updates the address of the specified site.
-
#update_site_rack_physical_properties(params = {}) ⇒ Types::UpdateSiteRackPhysicalPropertiesOutput
Update the physical and logistical details for a rack at a site.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-outposts/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3287 3288 3289 |
# File 'lib/aws-sdk-outposts/client.rb', line 3287 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3290 3291 3292 |
# File 'lib/aws-sdk-outposts/client.rb', line 3290 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3260 3261 3262 3263 3264 3265 3266 3267 3268 3269 3270 3271 3272 3273 3274 3275 3276 |
# File 'lib/aws-sdk-outposts/client.rb', line 3260 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Outposts') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-outposts' context[:gem_version] = '1.109.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_capacity_task(params = {}) ⇒ Struct
Cancels the capacity task.
85 |
# File 'sig/client.rbs', line 85
def cancel_capacity_task: (
|
#cancel_order(params = {}) ⇒ Struct
Cancels the specified order for an Outpost.
95 |
# File 'sig/client.rbs', line 95
def cancel_order: (
|
#create_order(params = {}) ⇒ Types::CreateOrderOutput
Creates an order for an Outpost.
105 |
# File 'sig/client.rbs', line 105
def create_order: (
|
#create_outpost(params = {}) ⇒ Types::CreateOutpostOutput
Creates an Outpost.
You can specify either an Availability one or an AZ ID.
125 |
# File 'sig/client.rbs', line 125
def create_outpost: (
|
#create_private_connectivity_config(params = {}) ⇒ Types::CreatePrivateConnectivityConfigOutput
Creates the private connectivity configuration for the specified Outpost. Private connectivity establishes a service link VPN connection between the Outpost and its home Amazon Web Services Region using a VPC and subnet that you specify, which allows the service link traffic to flow through your VPC and minimizes public internet exposure.
142 |
# File 'sig/client.rbs', line 142
def create_private_connectivity_config: (
|
#create_quote(params = {}) ⇒ Types::CreateQuoteOutput
Creates a quote for an Outpost. A quote provides pricing and configuration options based on the requested capacity. You can optionally associate the quote with an existing Outpost or create a standalone quote by specifying only the country code and requested capacities.
159 |
# File 'sig/client.rbs', line 159
def create_quote: (
|
#create_renewal(params = {}) ⇒ Types::CreateRenewalOutput
Creates a renewal contract for the specified Outpost.
191 |
# File 'sig/client.rbs', line 191
def create_renewal: (
|
#create_site(params = {}) ⇒ Types::CreateSiteOutput
Creates a site for an Outpost.
204 |
# File 'sig/client.rbs', line 204
def create_site: (
|
#delete_outpost(params = {}) ⇒ Struct
Deletes the specified Outpost.
229 |
# File 'sig/client.rbs', line 229
def delete_outpost: (
|
#delete_quote(params = {}) ⇒ Struct
Deletes the specified quote.
238 |
# File 'sig/client.rbs', line 238
def delete_quote: (
|
#delete_site(params = {}) ⇒ Struct
Deletes the specified site.
247 |
# File 'sig/client.rbs', line 247
def delete_site: (
|
#get_capacity_task(params = {}) ⇒ Types::GetCapacityTaskOutput
Gets details of the specified capacity task.
269 |
# File 'sig/client.rbs', line 269
def get_capacity_task: (
|
#get_catalog_item(params = {}) ⇒ Types::GetCatalogItemOutput
Gets information about the specified catalog item.
280 |
# File 'sig/client.rbs', line 280
def get_catalog_item: (
|
#get_connection(params = {}) ⇒ Types::GetConnectionResponse
Gets information about the specified connection.
Use CloudTrail to monitor this action or Amazon Web Services managed policy for Amazon Web Services Outposts to secure it. For more information, see Amazon Web Services managed policies for Amazon Web Services Outposts and Logging Amazon Web Services Outposts API calls with Amazon Web Services CloudTrail in the Amazon Web Services Outposts User Guide.
291 |
# File 'sig/client.rbs', line 291
def get_connection: (
|
#get_order(params = {}) ⇒ Types::GetOrderOutput
Gets information about the specified order.
301 |
# File 'sig/client.rbs', line 301
def get_order: (
|
#get_outpost(params = {}) ⇒ Types::GetOutpostOutput
Gets information about the specified Outpost.
311 |
# File 'sig/client.rbs', line 311
def get_outpost: (
|
#get_outpost_billing_information(params = {}) ⇒ Types::GetOutpostBillingInformationOutput
Gets current and historical billing information about the specified Outpost.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
325 |
# File 'sig/client.rbs', line 325
def get_outpost_billing_information: (
|
#get_outpost_instance_types(params = {}) ⇒ Types::GetOutpostInstanceTypesOutput
Gets the instance types for the specified Outpost.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
340 |
# File 'sig/client.rbs', line 340
def get_outpost_instance_types: (
|
#get_outpost_supported_instance_types(params = {}) ⇒ Types::GetOutpostSupportedInstanceTypesOutput
Gets the instance types that an Outpost can support in
InstanceTypeCapacity. This will generally include instance types
that are not currently configured and therefore cannot be launched
with the current Outpost capacity configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
353 |
# File 'sig/client.rbs', line 353
def get_outpost_supported_instance_types: (
|
#get_private_connectivity_config(params = {}) ⇒ Types::GetPrivateConnectivityConfigOutput
Gets the private connectivity configuration for the specified Outpost.
367 |
# File 'sig/client.rbs', line 367
def get_private_connectivity_config: (
|
#get_quote(params = {}) ⇒ Types::GetQuoteOutput
Gets information about the specified quote.
377 |
# File 'sig/client.rbs', line 377
def get_quote: (
|
#get_renewal_pricing(params = {}) ⇒ Types::GetRenewalPricingOutput
Gets all available renewal pricing options for the specified Outpost.
388 |
# File 'sig/client.rbs', line 388
def get_renewal_pricing: (
|
#get_site(params = {}) ⇒ Types::GetSiteOutput
Gets information about the specified Outpost site.
398 |
# File 'sig/client.rbs', line 398
def get_site: (
|
#get_site_address(params = {}) ⇒ Types::GetSiteAddressOutput
Gets the site address of the specified site.
410 |
# File 'sig/client.rbs', line 410
def get_site_address: (
|
#list_asset_instances(params = {}) ⇒ Types::ListAssetInstancesOutput
A list of Amazon EC2 instances, belonging to all accounts, running on the specified Outpost. Does not include Amazon EBS or Amazon S3 instances.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
422 |
# File 'sig/client.rbs', line 422
def list_asset_instances: (
|
#list_assets(params = {}) ⇒ Types::ListAssetsOutput
Lists the hardware assets for the specified Outpost.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
439 |
# File 'sig/client.rbs', line 439
def list_assets: (
|
#list_blocking_instances_for_capacity_task(params = {}) ⇒ Types::ListBlockingInstancesForCapacityTaskOutput
A list of Amazon EC2 instances running on the Outpost and belonging to the account that initiated the capacity task. Use this list to specify the instances you cannot stop to free up capacity to run the capacity task.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
455 |
# File 'sig/client.rbs', line 455
def list_blocking_instances_for_capacity_task: (
|
#list_capacity_tasks(params = {}) ⇒ Types::ListCapacityTasksOutput
Lists the capacity tasks for your Amazon Web Services account.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
469 |
# File 'sig/client.rbs', line 469
def list_capacity_tasks: (
|
#list_catalog_items(params = {}) ⇒ Types::ListCatalogItemsOutput
Lists the items in the catalog.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
483 |
# File 'sig/client.rbs', line 483
def list_catalog_items: (
|
#list_orderable_instance_types(params = {}) ⇒ Types::ListOrderableInstanceTypesOutput
Lists the instance types that can be ordered for an Outpost. You can filter the results by Outpost generation.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
498 |
# File 'sig/client.rbs', line 498
def list_orderable_instance_types: (
|
#list_orders(params = {}) ⇒ Types::ListOrdersOutput
Lists the Outpost orders for your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
511 |
# File 'sig/client.rbs', line 511
def list_orders: (
|
#list_outposts(params = {}) ⇒ Types::ListOutpostsOutput
Lists the Outposts for your Amazon Web Services account.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
524 |
# File 'sig/client.rbs', line 524
def list_outposts: (
|
#list_quotes(params = {}) ⇒ Types::ListQuotesOutput
Lists the quotes for your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
539 |
# File 'sig/client.rbs', line 539
def list_quotes: (
|
#list_sites(params = {}) ⇒ Types::ListSitesOutput
Lists the Outpost sites for your Amazon Web Services account. Use filters to return specific results.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
551 |
# File 'sig/client.rbs', line 551
def list_sites: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
565 |
# File 'sig/client.rbs', line 565
def list_tags_for_resource: (
|
#start_capacity_task(params = {}) ⇒ Types::StartCapacityTaskOutput
Starts the specified capacity task. You can have one active capacity task for each order and each Outpost.
587 |
# File 'sig/client.rbs', line 587
def start_capacity_task: (
|
#start_connection(params = {}) ⇒ Types::StartConnectionResponse
Starts the connection required for Outpost server installation.
Use CloudTrail to monitor this action or Amazon Web Services managed policy for Amazon Web Services Outposts to secure it. For more information, see Amazon Web Services managed policies for Amazon Web Services Outposts and Logging Amazon Web Services Outposts API calls with Amazon Web Services CloudTrail in the Amazon Web Services Outposts User Guide.
613 |
# File 'sig/client.rbs', line 613
def start_connection: (
|
#start_outpost_decommission(params = {}) ⇒ Types::StartOutpostDecommissionOutput
Starts the decommission process to return the Outposts racks or servers.
627 |
# File 'sig/client.rbs', line 627
def start_outpost_decommission: (
|
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
637 |
# File 'sig/client.rbs', line 637
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
647 |
# File 'sig/client.rbs', line 647
def untag_resource: (
|
#update_outpost(params = {}) ⇒ Types::UpdateOutpostOutput
Updates an Outpost.
658 |
# File 'sig/client.rbs', line 658
def update_outpost: (
|
#update_quote(params = {}) ⇒ Types::UpdateQuoteOutput
Updates the specified quote. You can modify the requested capacities, constraints, payment options, payment terms, or Outpost association.
671 |
# File 'sig/client.rbs', line 671
def update_quote: (
|
#update_site(params = {}) ⇒ Types::UpdateSiteOutput
Updates the specified site.
699 |
# File 'sig/client.rbs', line 699
def update_site: (
|
#update_site_address(params = {}) ⇒ Types::UpdateSiteAddressOutput
Updates the address of the specified site.
You can't update a site address if there is an order in progress. You must wait for the order to complete or cancel the order.
You can update the operating address before you place an order at the site, or after all Outposts that belong to the site have been deactivated.
713 |
# File 'sig/client.rbs', line 713
def update_site_address: (
|
#update_site_rack_physical_properties(params = {}) ⇒ Types::UpdateSiteRackPhysicalPropertiesOutput
Update the physical and logistical details for a rack at a site. For more information about hardware requirements for racks, see Network readiness checklist in the Amazon Web Services Outposts User Guide.
To update a rack at a site with an order of IN_PROGRESS, you must
wait for the order to complete or cancel the order.
725 |
# File 'sig/client.rbs', line 725
def update_site_rack_physical_properties: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3280 3281 3282 |
# File 'lib/aws-sdk-outposts/client.rb', line 3280 def waiter_names [] end |