Class: Aws::Outposts::Types::CatalogItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Information about a catalog item.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#catalog_item_id ⇒ String

The ID of the catalog item.

Returns:

  • (String)


391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/aws-sdk-outposts/types.rb', line 391

class CatalogItem < Struct.new(
  :catalog_item_id,
  :item_status,
  :ec2_capacities,
  :power_kva,
  :weight_lbs,
  :supported_uplink_gbps,
  :supported_storage,
  :rack_scaling_type)
  SENSITIVE = []
  include Aws::Structure
end

#ec2_capacities ⇒ Array<Types::EC2Capacity>

Information about the EC2 capacity of an item.

Returns:



391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/aws-sdk-outposts/types.rb', line 391

class CatalogItem < Struct.new(
  :catalog_item_id,
  :item_status,
  :ec2_capacities,
  :power_kva,
  :weight_lbs,
  :supported_uplink_gbps,
  :supported_storage,
  :rack_scaling_type)
  SENSITIVE = []
  include Aws::Structure
end

#item_status ⇒ String

The status of a catalog item.

Returns:

  • (String)


391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/aws-sdk-outposts/types.rb', line 391

class CatalogItem < Struct.new(
  :catalog_item_id,
  :item_status,
  :ec2_capacities,
  :power_kva,
  :weight_lbs,
  :supported_uplink_gbps,
  :supported_storage,
  :rack_scaling_type)
  SENSITIVE = []
  include Aws::Structure
end

#power_kva ⇒ Float

Information about the power draw of an item.

Returns:

  • (Float)


391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/aws-sdk-outposts/types.rb', line 391

class CatalogItem < Struct.new(
  :catalog_item_id,
  :item_status,
  :ec2_capacities,
  :power_kva,
  :weight_lbs,
  :supported_uplink_gbps,
  :supported_storage,
  :rack_scaling_type)
  SENSITIVE = []
  include Aws::Structure
end

#rack_scaling_type ⇒ String

The rack scaling type supported by the catalog item. Valid values are SINGLE_RACK and MULTI_RACK.

Returns:

  • (String)


391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/aws-sdk-outposts/types.rb', line 391

class CatalogItem < Struct.new(
  :catalog_item_id,
  :item_status,
  :ec2_capacities,
  :power_kva,
  :weight_lbs,
  :supported_uplink_gbps,
  :supported_storage,
  :rack_scaling_type)
  SENSITIVE = []
  include Aws::Structure
end

#supported_storage ⇒ Array<String>

The supported storage options for the catalog item.

Returns:

  • (Array<String>)


391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/aws-sdk-outposts/types.rb', line 391

class CatalogItem < Struct.new(
  :catalog_item_id,
  :item_status,
  :ec2_capacities,
  :power_kva,
  :weight_lbs,
  :supported_uplink_gbps,
  :supported_storage,
  :rack_scaling_type)
  SENSITIVE = []
  include Aws::Structure
end

The uplink speed this catalog item requires for the connection to the Region.

Returns:

  • (Array<Integer>)


391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/aws-sdk-outposts/types.rb', line 391

class CatalogItem < Struct.new(
  :catalog_item_id,
  :item_status,
  :ec2_capacities,
  :power_kva,
  :weight_lbs,
  :supported_uplink_gbps,
  :supported_storage,
  :rack_scaling_type)
  SENSITIVE = []
  include Aws::Structure
end

#weight_lbs ⇒ Integer

The weight of the item in pounds.

Returns:

  • (Integer)


391
392
393
394
395
396
397
398
399
400
401
402
# File 'lib/aws-sdk-outposts/types.rb', line 391

class CatalogItem < Struct.new(
  :catalog_item_id,
  :item_status,
  :ec2_capacities,
  :power_kva,
  :weight_lbs,
  :supported_uplink_gbps,
  :supported_storage,
  :rack_scaling_type)
  SENSITIVE = []
  include Aws::Structure
end