Class: Aws::Outposts::Types::CreateOrderInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#line_items ⇒ Array<Types::LineItemRequest>

The line items that make up the order.

Returns:



543
544
545
546
547
548
549
550
551
552
# File 'lib/aws-sdk-outposts/types.rb', line 543

class CreateOrderInput < Struct.new(
  :outpost_identifier,
  :quote_identifier,
  :quote_option_identifier,
  :line_items,
  :payment_option,
  :payment_term)
  SENSITIVE = []
  include Aws::Structure
end

#outpost_identifier ⇒ String

The ID or the Amazon Resource Name (ARN) of the Outpost.

Returns:

  • (String)


543
544
545
546
547
548
549
550
551
552
# File 'lib/aws-sdk-outposts/types.rb', line 543

class CreateOrderInput < Struct.new(
  :outpost_identifier,
  :quote_identifier,
  :quote_option_identifier,
  :line_items,
  :payment_option,
  :payment_term)
  SENSITIVE = []
  include Aws::Structure
end

#payment_option ⇒ String

The payment option.

Returns:

  • (String)


543
544
545
546
547
548
549
550
551
552
# File 'lib/aws-sdk-outposts/types.rb', line 543

class CreateOrderInput < Struct.new(
  :outpost_identifier,
  :quote_identifier,
  :quote_option_identifier,
  :line_items,
  :payment_option,
  :payment_term)
  SENSITIVE = []
  include Aws::Structure
end

#payment_term ⇒ String

The payment terms.

Returns:

  • (String)


543
544
545
546
547
548
549
550
551
552
# File 'lib/aws-sdk-outposts/types.rb', line 543

class CreateOrderInput < Struct.new(
  :outpost_identifier,
  :quote_identifier,
  :quote_option_identifier,
  :line_items,
  :payment_option,
  :payment_term)
  SENSITIVE = []
  include Aws::Structure
end

#quote_identifier ⇒ String

The ID of the quote to use for the order.

Returns:

  • (String)


543
544
545
546
547
548
549
550
551
552
# File 'lib/aws-sdk-outposts/types.rb', line 543

class CreateOrderInput < Struct.new(
  :outpost_identifier,
  :quote_identifier,
  :quote_option_identifier,
  :line_items,
  :payment_option,
  :payment_term)
  SENSITIVE = []
  include Aws::Structure
end

#quote_option_identifier ⇒ String

The ID of the quote option to use for the order.

Returns:

  • (String)


543
544
545
546
547
548
549
550
551
552
# File 'lib/aws-sdk-outposts/types.rb', line 543

class CreateOrderInput < Struct.new(
  :outpost_identifier,
  :quote_identifier,
  :quote_option_identifier,
  :line_items,
  :payment_option,
  :payment_term)
  SENSITIVE = []
  include Aws::Structure
end