Class: Aws::Outposts::Types::CreateOutpostInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Note:

When making an API call, you may pass CreateOutpostInput data as a hash:

{
  name: "OutpostName", # required
  description: "OutpostDescription",
  site_id: "SiteId", # required
  availability_zone: "AvailabilityZone",
  availability_zone_id: "AvailabilityZoneId",
  tags: {
    "TagKey" => "TagValue",
  },
  supported_hardware_type: "RACK", # accepts RACK, SERVER
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zoneString

The Availability Zone.

Returns:

  • (String)


406
407
408
409
410
411
412
413
414
415
416
# File 'lib/aws-sdk-outposts/types.rb', line 406

class CreateOutpostInput < Struct.new(
  :name,
  :description,
  :site_id,
  :availability_zone,
  :availability_zone_id,
  :tags,
  :supported_hardware_type)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zone_idString

The ID of the Availability Zone.

Returns:

  • (String)


406
407
408
409
410
411
412
413
414
415
416
# File 'lib/aws-sdk-outposts/types.rb', line 406

class CreateOutpostInput < Struct.new(
  :name,
  :description,
  :site_id,
  :availability_zone,
  :availability_zone_id,
  :tags,
  :supported_hardware_type)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the Outpost.

Returns:

  • (String)


406
407
408
409
410
411
412
413
414
415
416
# File 'lib/aws-sdk-outposts/types.rb', line 406

class CreateOutpostInput < Struct.new(
  :name,
  :description,
  :site_id,
  :availability_zone,
  :availability_zone_id,
  :tags,
  :supported_hardware_type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the Outpost.

Returns:

  • (String)


406
407
408
409
410
411
412
413
414
415
416
# File 'lib/aws-sdk-outposts/types.rb', line 406

class CreateOutpostInput < Struct.new(
  :name,
  :description,
  :site_id,
  :availability_zone,
  :availability_zone_id,
  :tags,
  :supported_hardware_type)
  SENSITIVE = []
  include Aws::Structure
end

#site_idString

The ID or the Amazon Resource Name (ARN) of the site.

<note markdown=“1”> In requests, Amazon Web Services Outposts accepts the Amazon Resource Name (ARN) or an ID for Outposts and sites throughout the Outposts Query API. To address backwards compatibility, the parameter names `OutpostID` or `SiteID` remain in use. Despite the parameter name, you can make the request with an ARN.

</note>

Returns:

  • (String)


406
407
408
409
410
411
412
413
414
415
416
# File 'lib/aws-sdk-outposts/types.rb', line 406

class CreateOutpostInput < Struct.new(
  :name,
  :description,
  :site_id,
  :availability_zone,
  :availability_zone_id,
  :tags,
  :supported_hardware_type)
  SENSITIVE = []
  include Aws::Structure
end

#supported_hardware_typeString

The type of hardware for this Outpost.

Returns:

  • (String)


406
407
408
409
410
411
412
413
414
415
416
# File 'lib/aws-sdk-outposts/types.rb', line 406

class CreateOutpostInput < Struct.new(
  :name,
  :description,
  :site_id,
  :availability_zone,
  :availability_zone_id,
  :tags,
  :supported_hardware_type)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags to apply to the Outpost.

Returns:

  • (Hash<String,String>)


406
407
408
409
410
411
412
413
414
415
416
# File 'lib/aws-sdk-outposts/types.rb', line 406

class CreateOutpostInput < Struct.new(
  :name,
  :description,
  :site_id,
  :availability_zone,
  :availability_zone_id,
  :tags,
  :supported_hardware_type)
  SENSITIVE = []
  include Aws::Structure
end