Class: Aws::Outposts::Types::CreateSiteInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the site.

Returns:

  • (String)


683
684
685
686
687
688
689
690
691
692
693
# File 'lib/aws-sdk-outposts/types.rb', line 683

class CreateSiteInput < Struct.new(
  :name,
  :description,
  :notes,
  :tags,
  :operating_address,
  :shipping_address,
  :rack_physical_properties)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the site.

Returns:

  • (String)


683
684
685
686
687
688
689
690
691
692
693
# File 'lib/aws-sdk-outposts/types.rb', line 683

class CreateSiteInput < Struct.new(
  :name,
  :description,
  :notes,
  :tags,
  :operating_address,
  :shipping_address,
  :rack_physical_properties)
  SENSITIVE = []
  include Aws::Structure
end

#notesString

Additional information that you provide about site access requirements, electrician scheduling, personal protective equipment, or regulation of equipment materials that could affect your installation process.

Returns:

  • (String)


683
684
685
686
687
688
689
690
691
692
693
# File 'lib/aws-sdk-outposts/types.rb', line 683

class CreateSiteInput < Struct.new(
  :name,
  :description,
  :notes,
  :tags,
  :operating_address,
  :shipping_address,
  :rack_physical_properties)
  SENSITIVE = []
  include Aws::Structure
end

#operating_addressTypes::Address

The location to install and power on the hardware. This address might be different from the shipping address.

Returns:



683
684
685
686
687
688
689
690
691
692
693
# File 'lib/aws-sdk-outposts/types.rb', line 683

class CreateSiteInput < Struct.new(
  :name,
  :description,
  :notes,
  :tags,
  :operating_address,
  :shipping_address,
  :rack_physical_properties)
  SENSITIVE = []
  include Aws::Structure
end

#rack_physical_propertiesTypes::RackPhysicalProperties

Information about the physical and logistical details for the rack at this site. For more information about hardware requirements for racks, see Network readiness checklist in the Amazon Web Services Outposts User Guide.



683
684
685
686
687
688
689
690
691
692
693
# File 'lib/aws-sdk-outposts/types.rb', line 683

class CreateSiteInput < Struct.new(
  :name,
  :description,
  :notes,
  :tags,
  :operating_address,
  :shipping_address,
  :rack_physical_properties)
  SENSITIVE = []
  include Aws::Structure
end

#shipping_addressTypes::Address

The location to ship the hardware. This address might be different from the operating address.

Returns:



683
684
685
686
687
688
689
690
691
692
693
# File 'lib/aws-sdk-outposts/types.rb', line 683

class CreateSiteInput < Struct.new(
  :name,
  :description,
  :notes,
  :tags,
  :operating_address,
  :shipping_address,
  :rack_physical_properties)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags to apply to a site.

Returns:

  • (Hash<String,String>)


683
684
685
686
687
688
689
690
691
692
693
# File 'lib/aws-sdk-outposts/types.rb', line 683

class CreateSiteInput < Struct.new(
  :name,
  :description,
  :notes,
  :tags,
  :operating_address,
  :shipping_address,
  :rack_physical_properties)
  SENSITIVE = []
  include Aws::Structure
end