Class: Aws::Outposts::Types::DeleteOutpostInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Note:

When making an API call, you may pass DeleteOutpostInput data as a hash:

{
  outpost_id: "OutpostId", # required
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#outpost_idString

The ID or the Amazon Resource Name (ARN) of the Outpost.

<note markdown=“1”> In requests, Amazon Web Services Outposts accepts the Amazon Resource Name (ARN) or an ID for Outposts and sites throughout the Outposts Query API. To address backwards compatibility, the parameter names `OutpostID` or `SiteID` remain in use. Despite the parameter name, you can make the request with an ARN.

</note>

Returns:

  • (String)


547
548
549
550
551
# File 'lib/aws-sdk-outposts/types.rb', line 547

class DeleteOutpostInput < Struct.new(
  :outpost_id)
  SENSITIVE = []
  include Aws::Structure
end