Class: Aws::Outposts::Types::DeleteSiteInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Note:

When making an API call, you may pass DeleteSiteInput data as a hash:

{
  site_id: "SiteId", # required
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#site_idString

The ID or the Amazon Resource Name (ARN) of the site.

<note markdown=“1”> In requests, Amazon Web Services Outposts accepts the Amazon Resource Name (ARN) or an ID for Outposts and sites throughout the Outposts Query API. To address backwards compatibility, the parameter names `OutpostID` or `SiteID` remain in use. Despite the parameter name, you can make the request with an ARN.

</note>

Returns:

  • (String)


597
598
599
600
601
# File 'lib/aws-sdk-outposts/types.rb', line 597

class DeleteSiteInput < Struct.new(
  :site_id)
  SENSITIVE = []
  include Aws::Structure
end