Class: Aws::Outposts::Types::DetailedInstanceTypeItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Information about an instance type that can be ordered for an Outpost, including hardware specifications and supported form factors.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#form_factor_configsArray<Types::FormFactorConfig>

The supported form factor and Outpost generation configurations for the instance type.

Returns:



883
884
885
886
887
888
889
890
891
# File 'lib/aws-sdk-outposts/types.rb', line 883

class DetailedInstanceTypeItem < Struct.new(
  :instance_type,
  :vcp_us,
  :memory_in_mib,
  :network_performance,
  :form_factor_configs)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The instance type.

Returns:

  • (String)


883
884
885
886
887
888
889
890
891
# File 'lib/aws-sdk-outposts/types.rb', line 883

class DetailedInstanceTypeItem < Struct.new(
  :instance_type,
  :vcp_us,
  :memory_in_mib,
  :network_performance,
  :form_factor_configs)
  SENSITIVE = []
  include Aws::Structure
end

#memory_in_mibInteger

The memory size of the instance type, in MiB.

Returns:

  • (Integer)


883
884
885
886
887
888
889
890
891
# File 'lib/aws-sdk-outposts/types.rb', line 883

class DetailedInstanceTypeItem < Struct.new(
  :instance_type,
  :vcp_us,
  :memory_in_mib,
  :network_performance,
  :form_factor_configs)
  SENSITIVE = []
  include Aws::Structure
end

#network_performanceString

The network performance of the instance type.

Returns:

  • (String)


883
884
885
886
887
888
889
890
891
# File 'lib/aws-sdk-outposts/types.rb', line 883

class DetailedInstanceTypeItem < Struct.new(
  :instance_type,
  :vcp_us,
  :memory_in_mib,
  :network_performance,
  :form_factor_configs)
  SENSITIVE = []
  include Aws::Structure
end

#vcp_usInteger

The number of default VCPUs in the instance type.

Returns:

  • (Integer)


883
884
885
886
887
888
889
890
891
# File 'lib/aws-sdk-outposts/types.rb', line 883

class DetailedInstanceTypeItem < Struct.new(
  :instance_type,
  :vcp_us,
  :memory_in_mib,
  :network_performance,
  :form_factor_configs)
  SENSITIVE = []
  include Aws::Structure
end