Class: Aws::Outposts::Types::GetCapacityTaskOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_idString

The ID of the Outpost asset. An Outpost asset can be a single server within an Outposts rack or an Outposts server configuration.

Returns:

  • (String)


1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
# File 'lib/aws-sdk-outposts/types.rb', line 1082

class GetCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :asset_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#capacity_task_idString

ID of the capacity task.

Returns:

  • (String)


1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
# File 'lib/aws-sdk-outposts/types.rb', line 1082

class GetCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :asset_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#capacity_task_statusString

Status of the capacity task.

A capacity task can have one of the following statuses:

  • REQUESTED - The capacity task was created and is awaiting the next step by Amazon Web Services Outposts.

  • IN_PROGRESS - The capacity task is running and cannot be cancelled.

  • FAILED - The capacity task could not be completed.

  • COMPLETED - The capacity task has completed successfully.

  • WAITING_FOR_EVACUATION - The capacity task requires capacity to run. You must stop the recommended EC2 running instances to free up capacity for the task to run.

  • CANCELLATION_IN_PROGRESS - The capacity task has been cancelled and is in the process of cleaning up resources.

  • CANCELLED - The capacity task is cancelled.

Returns:

  • (String)


1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
# File 'lib/aws-sdk-outposts/types.rb', line 1082

class GetCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :asset_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#completion_dateTime

The date the capacity task ran successfully.

Returns:

  • (Time)


1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
# File 'lib/aws-sdk-outposts/types.rb', line 1082

class GetCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :asset_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateTime

The date the capacity task was created.

Returns:

  • (Time)


1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
# File 'lib/aws-sdk-outposts/types.rb', line 1082

class GetCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :asset_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Performs a dry run to determine if you are above or below instance capacity.

Returns:

  • (Boolean)


1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
# File 'lib/aws-sdk-outposts/types.rb', line 1082

class GetCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :asset_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#failedTypes::CapacityTaskFailure

Reason why the capacity task failed.



1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
# File 'lib/aws-sdk-outposts/types.rb', line 1082

class GetCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :asset_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#instances_to_excludeTypes::InstancesToExclude

Instances that the user specified they cannot stop in order to free up the capacity needed to run the capacity task.



1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
# File 'lib/aws-sdk-outposts/types.rb', line 1082

class GetCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :asset_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_dateTime

The date the capacity task was last modified.

Returns:

  • (Time)


1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
# File 'lib/aws-sdk-outposts/types.rb', line 1082

class GetCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :asset_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#order_idString

ID of the Amazon Web Services Outposts order associated with the specified capacity task.

Returns:

  • (String)


1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
# File 'lib/aws-sdk-outposts/types.rb', line 1082

class GetCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :asset_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#outpost_idString

ID of the Outpost associated with the specified capacity task.

Returns:

  • (String)


1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
# File 'lib/aws-sdk-outposts/types.rb', line 1082

class GetCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :asset_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#requested_instance_poolsArray<Types::InstanceTypeCapacity>

List of instance pools requested in the capacity task.

Returns:



1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
# File 'lib/aws-sdk-outposts/types.rb', line 1082

class GetCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :asset_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#task_action_on_blocking_instancesString

User-specified option in case an instance is blocking the capacity task from running. Shows one of the following options:

  • WAIT_FOR_EVACUATION - Checks every 10 minutes over 48 hours to determine if instances have stopped and capacity is available to complete the task.

  • FAIL_TASK - The capacity task fails.

Returns:

  • (String)


1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
# File 'lib/aws-sdk-outposts/types.rb', line 1082

class GetCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :asset_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end