Class: Aws::Outposts::Types::GetOutpostBillingInformationOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contract_end_date ⇒ String

The date the current contract term ends for the specified Outpost. You must start the renewal or decommission process at least 5 business days before the current term for your Amazon Web Services Outposts ends. Failing to complete these steps at least 5 business days before the current term ends might result in unanticipated charges.

Returns:

  • (String)


1232
1233
1234
1235
1236
1237
1238
1239
1240
# File 'lib/aws-sdk-outposts/types.rb', line 1232

class GetOutpostBillingInformationOutput < Struct.new(
  :next_token,
  :subscriptions,
  :contract_end_date,
  :payment_term,
  :payment_option)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The pagination token.

Returns:

  • (String)


1232
1233
1234
1235
1236
1237
1238
1239
1240
# File 'lib/aws-sdk-outposts/types.rb', line 1232

class GetOutpostBillingInformationOutput < Struct.new(
  :next_token,
  :subscriptions,
  :contract_end_date,
  :payment_term,
  :payment_option)
  SENSITIVE = []
  include Aws::Structure
end

#payment_option ⇒ String

The payment option.

Returns:

  • (String)


1232
1233
1234
1235
1236
1237
1238
1239
1240
# File 'lib/aws-sdk-outposts/types.rb', line 1232

class GetOutpostBillingInformationOutput < Struct.new(
  :next_token,
  :subscriptions,
  :contract_end_date,
  :payment_term,
  :payment_option)
  SENSITIVE = []
  include Aws::Structure
end

#payment_term ⇒ String

The payment term.

Returns:

  • (String)


1232
1233
1234
1235
1236
1237
1238
1239
1240
# File 'lib/aws-sdk-outposts/types.rb', line 1232

class GetOutpostBillingInformationOutput < Struct.new(
  :next_token,
  :subscriptions,
  :contract_end_date,
  :payment_term,
  :payment_option)
  SENSITIVE = []
  include Aws::Structure
end

#subscriptions ⇒ Array<Types::Subscription>

The subscription details for the specified Outpost.

Returns:



1232
1233
1234
1235
1236
1237
1238
1239
1240
# File 'lib/aws-sdk-outposts/types.rb', line 1232

class GetOutpostBillingInformationOutput < Struct.new(
  :next_token,
  :subscriptions,
  :contract_end_date,
  :payment_term,
  :payment_option)
  SENSITIVE = []
  include Aws::Structure
end