Class: Aws::Outposts::Types::GetOutpostInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::GetOutpostInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Note:
When making an API call, you may pass GetOutpostInput data as a hash:
{
outpost_id: "OutpostId", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#outpost_id ⇒ String
The ID or the Amazon Resource Name (ARN) of the Outpost.
Instance Attribute Details
#outpost_id ⇒ String
The ID or the Amazon Resource Name (ARN) of the Outpost.
<note markdown=“1”> In requests, Amazon Web Services Outposts accepts the Amazon Resource Name (ARN) or an ID for Outposts and sites throughout the Outposts Query API. To address backwards compatibility, the parameter names `OutpostID` or `SiteID` remain in use. Despite the parameter name, you can make the request with an ARN.
</note>
750 751 752 753 754 |
# File 'lib/aws-sdk-outposts/types.rb', line 750 class GetOutpostInput < Struct.new( :outpost_id) SENSITIVE = [] include Aws::Structure end |