Class: Aws::Outposts::Types::GetOutpostInstanceTypesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::GetOutpostInstanceTypesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_types ⇒ Array<Types::InstanceTypeItem>
Information about the instance types.
-
#next_token ⇒ String
The pagination token.
-
#outpost_arn ⇒ String
The Amazon Resource Name (ARN) of the Outpost.
-
#outpost_id ⇒ String
The ID of the Outpost.
Instance Attribute Details
#instance_types ⇒ Array<Types::InstanceTypeItem>
Information about the instance types.
727 728 729 730 731 732 733 734 |
# File 'lib/aws-sdk-outposts/types.rb', line 727 class GetOutpostInstanceTypesOutput < Struct.new( :instance_types, :next_token, :outpost_id, :outpost_arn) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token.
727 728 729 730 731 732 733 734 |
# File 'lib/aws-sdk-outposts/types.rb', line 727 class GetOutpostInstanceTypesOutput < Struct.new( :instance_types, :next_token, :outpost_id, :outpost_arn) SENSITIVE = [] include Aws::Structure end |
#outpost_arn ⇒ String
The Amazon Resource Name (ARN) of the Outpost.
727 728 729 730 731 732 733 734 |
# File 'lib/aws-sdk-outposts/types.rb', line 727 class GetOutpostInstanceTypesOutput < Struct.new( :instance_types, :next_token, :outpost_id, :outpost_arn) SENSITIVE = [] include Aws::Structure end |
#outpost_id ⇒ String
The ID of the Outpost.
<note markdown=“1”> In requests, Amazon Web Services Outposts accepts the Amazon Resource Name (ARN) or an ID for Outposts and sites throughout the Outposts Query API. To address backwards compatibility, the parameter names `OutpostID` or `SiteID` remain in use. Despite the parameter name, you can make the request with an ARN.
</note>
727 728 729 730 731 732 733 734 |
# File 'lib/aws-sdk-outposts/types.rb', line 727 class GetOutpostInstanceTypesOutput < Struct.new( :instance_types, :next_token, :outpost_id, :outpost_arn) SENSITIVE = [] include Aws::Structure end |