Class: Aws::Outposts::Types::GetOutpostSupportedInstanceTypesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#asset_id ⇒ String

The ID of the Outpost asset. An Outpost asset can be a single server within an Outposts rack or an Outposts server configuration.

Returns:

  • (String)


1338
1339
1340
1341
1342
1343
1344
1345
1346
# File 'lib/aws-sdk-outposts/types.rb', line 1338

class GetOutpostSupportedInstanceTypesInput < Struct.new(
  :outpost_identifier,
  :order_id,
  :asset_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum page size.

Returns:

  • (Integer)


1338
1339
1340
1341
1342
1343
1344
1345
1346
# File 'lib/aws-sdk-outposts/types.rb', line 1338

class GetOutpostSupportedInstanceTypesInput < Struct.new(
  :outpost_identifier,
  :order_id,
  :asset_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The pagination token.

Returns:

  • (String)


1338
1339
1340
1341
1342
1343
1344
1345
1346
# File 'lib/aws-sdk-outposts/types.rb', line 1338

class GetOutpostSupportedInstanceTypesInput < Struct.new(
  :outpost_identifier,
  :order_id,
  :asset_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#order_id ⇒ String

The ID for the Amazon Web Services Outposts order.

Returns:

  • (String)


1338
1339
1340
1341
1342
1343
1344
1345
1346
# File 'lib/aws-sdk-outposts/types.rb', line 1338

class GetOutpostSupportedInstanceTypesInput < Struct.new(
  :outpost_identifier,
  :order_id,
  :asset_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#outpost_identifier ⇒ String

The ID or ARN of the Outpost.

Returns:

  • (String)


1338
1339
1340
1341
1342
1343
1344
1345
1346
# File 'lib/aws-sdk-outposts/types.rb', line 1338

class GetOutpostSupportedInstanceTypesInput < Struct.new(
  :outpost_identifier,
  :order_id,
  :asset_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end