Class: Aws::Outposts::Types::GetSiteAddressInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Note:

When making an API call, you may pass GetSiteAddressInput data as a hash:

{
  site_id: "SiteId", # required
  address_type: "SHIPPING_ADDRESS", # required, accepts SHIPPING_ADDRESS, OPERATING_ADDRESS
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#address_typeString

The type of the address you request.

Returns:

  • (String)


868
869
870
871
872
873
# File 'lib/aws-sdk-outposts/types.rb', line 868

class GetSiteAddressInput < Struct.new(
  :site_id,
  :address_type)
  SENSITIVE = []
  include Aws::Structure
end

#site_idString

The ID or the Amazon Resource Name (ARN) of the site.

<note markdown=“1”> In requests, Amazon Web Services Outposts accepts the Amazon Resource Name (ARN) or an ID for Outposts and sites throughout the Outposts Query API. To address backwards compatibility, the parameter names `OutpostID` or `SiteID` remain in use. Despite the parameter name, you can make the request with an ARN.

</note>

Returns:

  • (String)


868
869
870
871
872
873
# File 'lib/aws-sdk-outposts/types.rb', line 868

class GetSiteAddressInput < Struct.new(
  :site_id,
  :address_type)
  SENSITIVE = []
  include Aws::Structure
end