Class: Aws::Outposts::Types::GetSiteInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::GetSiteInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Note:
When making an API call, you may pass GetSiteInput data as a hash:
{
site_id: "SiteId", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#site_id ⇒ String
The ID or the Amazon Resource Name (ARN) of the site.
Instance Attribute Details
#site_id ⇒ String
The ID or the Amazon Resource Name (ARN) of the site.
<note markdown=“1”> In requests, Amazon Web Services Outposts accepts the Amazon Resource Name (ARN) or an ID for Outposts and sites throughout the Outposts Query API. To address backwards compatibility, the parameter names `OutpostID` or `SiteID` remain in use. Despite the parameter name, you can make the request with an ARN.
</note>
918 919 920 921 922 |
# File 'lib/aws-sdk-outposts/types.rb', line 918 class GetSiteInput < Struct.new( :site_id) SENSITIVE = [] include Aws::Structure end |