Class: Aws::Outposts::Types::ListOrderableInstanceTypesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::ListOrderableInstanceTypesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#instance_types ⇒ Array<Types::DetailedInstanceTypeItem>
Information about the instance types that can be ordered for the Outpost.
-
#next_token ⇒ String
The pagination token.
Instance Attribute Details
#instance_types ⇒ Array<Types::DetailedInstanceTypeItem>
Information about the instance types that can be ordered for the Outpost.
1974 1975 1976 1977 1978 1979 |
# File 'lib/aws-sdk-outposts/types.rb', line 1974 class ListOrderableInstanceTypesOutput < Struct.new( :instance_types, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token.
1974 1975 1976 1977 1978 1979 |
# File 'lib/aws-sdk-outposts/types.rb', line 1974 class ListOrderableInstanceTypesOutput < Struct.new( :instance_types, :next_token) SENSITIVE = [] include Aws::Structure end |