Class: Aws::Outposts::Types::Order
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::Order
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Information about an order.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#line_items ⇒ Array<Types::LineItem>
The line items for the order.
-
#order_fulfilled_date ⇒ Time
The fulfillment date of the order.
-
#order_id ⇒ String
The ID of the order.
-
#order_submission_date ⇒ Time
The submission date for the order.
-
#order_type ⇒ String
The type of order.
-
#outpost_id ⇒ String
The ID of the Outpost in the order.
-
#payment_option ⇒ String
The payment option for the order.
-
#payment_term ⇒ String
The payment term.
-
#quote_identifier ⇒ String
The ID of the quote associated with the order.
-
#quote_option_identifier ⇒ String
The ID of the quote option associated with the order.
-
#status ⇒ String
The status of the order.
Instance Attribute Details
#line_items ⇒ Array<Types::LineItem>
The line items for the order
2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 |
# File 'lib/aws-sdk-outposts/types.rb', line 2189 class Order < Struct.new( :outpost_id, :quote_identifier, :quote_option_identifier, :order_id, :status, :line_items, :payment_option, :order_submission_date, :order_fulfilled_date, :payment_term, :order_type) SENSITIVE = [] include Aws::Structure end |
#order_fulfilled_date ⇒ Time
The fulfillment date of the order.
2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 |
# File 'lib/aws-sdk-outposts/types.rb', line 2189 class Order < Struct.new( :outpost_id, :quote_identifier, :quote_option_identifier, :order_id, :status, :line_items, :payment_option, :order_submission_date, :order_fulfilled_date, :payment_term, :order_type) SENSITIVE = [] include Aws::Structure end |
#order_id ⇒ String
The ID of the order.
2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 |
# File 'lib/aws-sdk-outposts/types.rb', line 2189 class Order < Struct.new( :outpost_id, :quote_identifier, :quote_option_identifier, :order_id, :status, :line_items, :payment_option, :order_submission_date, :order_fulfilled_date, :payment_term, :order_type) SENSITIVE = [] include Aws::Structure end |
#order_submission_date ⇒ Time
The submission date for the order.
2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 |
# File 'lib/aws-sdk-outposts/types.rb', line 2189 class Order < Struct.new( :outpost_id, :quote_identifier, :quote_option_identifier, :order_id, :status, :line_items, :payment_option, :order_submission_date, :order_fulfilled_date, :payment_term, :order_type) SENSITIVE = [] include Aws::Structure end |
#order_type ⇒ String
The type of order.
2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 |
# File 'lib/aws-sdk-outposts/types.rb', line 2189 class Order < Struct.new( :outpost_id, :quote_identifier, :quote_option_identifier, :order_id, :status, :line_items, :payment_option, :order_submission_date, :order_fulfilled_date, :payment_term, :order_type) SENSITIVE = [] include Aws::Structure end |
#outpost_id ⇒ String
The ID of the Outpost in the order.
2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 |
# File 'lib/aws-sdk-outposts/types.rb', line 2189 class Order < Struct.new( :outpost_id, :quote_identifier, :quote_option_identifier, :order_id, :status, :line_items, :payment_option, :order_submission_date, :order_fulfilled_date, :payment_term, :order_type) SENSITIVE = [] include Aws::Structure end |
#payment_option ⇒ String
The payment option for the order.
2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 |
# File 'lib/aws-sdk-outposts/types.rb', line 2189 class Order < Struct.new( :outpost_id, :quote_identifier, :quote_option_identifier, :order_id, :status, :line_items, :payment_option, :order_submission_date, :order_fulfilled_date, :payment_term, :order_type) SENSITIVE = [] include Aws::Structure end |
#payment_term ⇒ String
The payment term.
2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 |
# File 'lib/aws-sdk-outposts/types.rb', line 2189 class Order < Struct.new( :outpost_id, :quote_identifier, :quote_option_identifier, :order_id, :status, :line_items, :payment_option, :order_submission_date, :order_fulfilled_date, :payment_term, :order_type) SENSITIVE = [] include Aws::Structure end |
#quote_identifier ⇒ String
The ID of the quote associated with the order.
2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 |
# File 'lib/aws-sdk-outposts/types.rb', line 2189 class Order < Struct.new( :outpost_id, :quote_identifier, :quote_option_identifier, :order_id, :status, :line_items, :payment_option, :order_submission_date, :order_fulfilled_date, :payment_term, :order_type) SENSITIVE = [] include Aws::Structure end |
#quote_option_identifier ⇒ String
The ID of the quote option associated with the order.
2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 |
# File 'lib/aws-sdk-outposts/types.rb', line 2189 class Order < Struct.new( :outpost_id, :quote_identifier, :quote_option_identifier, :order_id, :status, :line_items, :payment_option, :order_submission_date, :order_fulfilled_date, :payment_term, :order_type) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the order.
-
‘PREPARING` - Order is received and being prepared.
-
‘IN_PROGRESS` - Order is either being built or shipped. To get more details, see the line item status.
-
‘DELIVERED` - Order was delivered to the Outpost site.
-
‘COMPLETED` - Order is complete.
-
‘CANCELLED` - Order is cancelled.
-
‘ERROR` - Customer should contact support.
<note markdown=“1”> The following status are deprecated: ‘RECEIVED`, `PENDING`, `PROCESSING`, `INSTALLING`, and `FULFILLED`.
</note>
2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 |
# File 'lib/aws-sdk-outposts/types.rb', line 2189 class Order < Struct.new( :outpost_id, :quote_identifier, :quote_option_identifier, :order_id, :status, :line_items, :payment_option, :order_submission_date, :order_fulfilled_date, :payment_term, :order_type) SENSITIVE = [] include Aws::Structure end |