Class: Aws::Outposts::Types::OrderSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::OrderSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
A summary of line items in your order.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#line_item_counts_by_status ⇒ Hash<String,Integer>
The status of all line items in the order.
-
#order_fulfilled_date ⇒ Time
Fulfilment date for the order.
-
#order_id ⇒ String
The ID of the order.
-
#order_submission_date ⇒ Time
Submission date for the order.
-
#order_type ⇒ String
The type of order.
-
#outpost_id ⇒ String
The ID of the Outpost.
-
#status ⇒ String
The status of the order.
Instance Attribute Details
#line_item_counts_by_status ⇒ Hash<String,Integer>
The status of all line items in the order.
1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 |
# File 'lib/aws-sdk-outposts/types.rb', line 1335 class OrderSummary < Struct.new( :outpost_id, :order_id, :order_type, :status, :line_item_counts_by_status, :order_submission_date, :order_fulfilled_date) SENSITIVE = [] include Aws::Structure end |
#order_fulfilled_date ⇒ Time
Fulfilment date for the order.
1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 |
# File 'lib/aws-sdk-outposts/types.rb', line 1335 class OrderSummary < Struct.new( :outpost_id, :order_id, :order_type, :status, :line_item_counts_by_status, :order_submission_date, :order_fulfilled_date) SENSITIVE = [] include Aws::Structure end |
#order_id ⇒ String
The ID of the order.
1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 |
# File 'lib/aws-sdk-outposts/types.rb', line 1335 class OrderSummary < Struct.new( :outpost_id, :order_id, :order_type, :status, :line_item_counts_by_status, :order_submission_date, :order_fulfilled_date) SENSITIVE = [] include Aws::Structure end |
#order_submission_date ⇒ Time
Submission date for the order.
1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 |
# File 'lib/aws-sdk-outposts/types.rb', line 1335 class OrderSummary < Struct.new( :outpost_id, :order_id, :order_type, :status, :line_item_counts_by_status, :order_submission_date, :order_fulfilled_date) SENSITIVE = [] include Aws::Structure end |
#order_type ⇒ String
The type of order.
1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 |
# File 'lib/aws-sdk-outposts/types.rb', line 1335 class OrderSummary < Struct.new( :outpost_id, :order_id, :order_type, :status, :line_item_counts_by_status, :order_submission_date, :order_fulfilled_date) SENSITIVE = [] include Aws::Structure end |
#outpost_id ⇒ String
The ID of the Outpost.
1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 |
# File 'lib/aws-sdk-outposts/types.rb', line 1335 class OrderSummary < Struct.new( :outpost_id, :order_id, :order_type, :status, :line_item_counts_by_status, :order_submission_date, :order_fulfilled_date) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the order.
-
`PREPARING` - Order is received and is being prepared.
-
`IN_PROGRESS` - Order is either being built, shipped, or installed. For more information, see the `LineItem` status.
-
`COMPLETED` - Order is complete.
-
`CANCELLED` - Order is cancelled.
-
`ERROR` - Customer should contact support.
<note markdown=“1”> The following statuses are deprecated: `RECEIVED`, `PENDING`, `PROCESSING`, `INSTALLING`, and `FULFILLED`.
</note>
1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 |
# File 'lib/aws-sdk-outposts/types.rb', line 1335 class OrderSummary < Struct.new( :outpost_id, :order_id, :order_type, :status, :line_item_counts_by_status, :order_submission_date, :order_fulfilled_date) SENSITIVE = [] include Aws::Structure end |