Class: Aws::Outposts::Types::PrivateConnectivityConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Information about the private connectivity configuration for an Outpost.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#private_connectivity_statusString

The status of private connectivity for the Outpost. Valid values are ENABLED and DISABLED.

Returns:

  • (String)


2518
2519
2520
2521
2522
2523
2524
2525
# File 'lib/aws-sdk-outposts/types.rb', line 2518

class PrivateConnectivityConfig < Struct.new(
  :role_arn,
  :private_connectivity_status,
  :vpc_information_list,
  :provisioning_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#provisioning_role_arnString

The Amazon Resource Name (ARN) of the provisioning role in your account that Amazon Web Services Outposts uses to establish the service link connection during Outpost installation. This field is present only when VPC endpoint-based provisioning is configured.

Returns:

  • (String)


2518
2519
2520
2521
2522
2523
2524
2525
# File 'lib/aws-sdk-outposts/types.rb', line 2518

class PrivateConnectivityConfig < Struct.new(
  :role_arn,
  :private_connectivity_status,
  :vpc_information_list,
  :provisioning_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the service-linked role that Amazon Web Services Outposts creates and uses to provision and attach the network interfaces for private connectivity in your VPC. The role's permissions are scoped to the specific Outpost and VPC.

Returns:

  • (String)


2518
2519
2520
2521
2522
2523
2524
2525
# File 'lib/aws-sdk-outposts/types.rb', line 2518

class PrivateConnectivityConfig < Struct.new(
  :role_arn,
  :private_connectivity_status,
  :vpc_information_list,
  :provisioning_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_information_listArray<Types::VpcInformation>

Information about the VPC used for private connectivity.

Returns:



2518
2519
2520
2521
2522
2523
2524
2525
# File 'lib/aws-sdk-outposts/types.rb', line 2518

class PrivateConnectivityConfig < Struct.new(
  :role_arn,
  :private_connectivity_status,
  :vpc_information_list,
  :provisioning_role_arn)
  SENSITIVE = []
  include Aws::Structure
end