Class: Aws::Outposts::Types::QuoteOption
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::QuoteOption
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
A configuration and pricing option for a quote. Each option includes the capacity breakdown, physical specifications for the racks or servers, and pricing details.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacities ⇒ Array<Types::QuoteCapacity>
The capacities included in this quote option.
-
#capacity_summary ⇒ Types::CapacitySummary
A summary of the existing, final, and changed capacity for this quote option.
-
#pricing_options ⇒ Array<Types::PricingOption>
The pricing options for this quote option.
-
#quote_option_identifier ⇒ String
The ID of the quote option.
-
#specifications ⇒ Array<Types::QuoteSpecification>
The physical specifications for the racks or servers in this quote option.
Instance Attribute Details
#capacities ⇒ Array<Types::QuoteCapacity>
The capacities included in this quote option.
2589 2590 2591 2592 2593 2594 2595 2596 2597 |
# File 'lib/aws-sdk-outposts/types.rb', line 2589 class QuoteOption < Struct.new( :quote_option_identifier, :capacities, :capacity_summary, :specifications, :pricing_options) SENSITIVE = [] include Aws::Structure end |
#capacity_summary ⇒ Types::CapacitySummary
A summary of the existing, final, and changed capacity for this quote option.
2589 2590 2591 2592 2593 2594 2595 2596 2597 |
# File 'lib/aws-sdk-outposts/types.rb', line 2589 class QuoteOption < Struct.new( :quote_option_identifier, :capacities, :capacity_summary, :specifications, :pricing_options) SENSITIVE = [] include Aws::Structure end |
#pricing_options ⇒ Array<Types::PricingOption>
The pricing options for this quote option.
2589 2590 2591 2592 2593 2594 2595 2596 2597 |
# File 'lib/aws-sdk-outposts/types.rb', line 2589 class QuoteOption < Struct.new( :quote_option_identifier, :capacities, :capacity_summary, :specifications, :pricing_options) SENSITIVE = [] include Aws::Structure end |
#quote_option_identifier ⇒ String
The ID of the quote option.
2589 2590 2591 2592 2593 2594 2595 2596 2597 |
# File 'lib/aws-sdk-outposts/types.rb', line 2589 class QuoteOption < Struct.new( :quote_option_identifier, :capacities, :capacity_summary, :specifications, :pricing_options) SENSITIVE = [] include Aws::Structure end |
#specifications ⇒ Array<Types::QuoteSpecification>
The physical specifications for the racks or servers in this quote option.
2589 2590 2591 2592 2593 2594 2595 2596 2597 |
# File 'lib/aws-sdk-outposts/types.rb', line 2589 class QuoteOption < Struct.new( :quote_option_identifier, :capacities, :capacity_summary, :specifications, :pricing_options) SENSITIVE = [] include Aws::Structure end |