Class: Aws::Outposts::Types::RackSpecificationDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

The physical specification details for a rack in a quote option.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ec2_capacitiesArray<Types::EC2Capacity>

The Amazon EC2 capacities for the rack.

Returns:



2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
# File 'lib/aws-sdk-outposts/types.rb', line 2833

class RackSpecificationDetails < Struct.new(
  :rack_id,
  :rack_use,
  :rack_power_draw_kva,
  :rack_weight_lbs,
  :rack_height_inches,
  :rack_width_inches,
  :rack_depth_inches,
  :rack_unit_height,
  :ec2_capacities)
  SENSITIVE = []
  include Aws::Structure
end

#rack_depth_inchesFloat

The depth of the rack in inches.

Returns:

  • (Float)


2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
# File 'lib/aws-sdk-outposts/types.rb', line 2833

class RackSpecificationDetails < Struct.new(
  :rack_id,
  :rack_use,
  :rack_power_draw_kva,
  :rack_weight_lbs,
  :rack_height_inches,
  :rack_width_inches,
  :rack_depth_inches,
  :rack_unit_height,
  :ec2_capacities)
  SENSITIVE = []
  include Aws::Structure
end

#rack_height_inchesFloat

The height of the rack in inches.

Returns:

  • (Float)


2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
# File 'lib/aws-sdk-outposts/types.rb', line 2833

class RackSpecificationDetails < Struct.new(
  :rack_id,
  :rack_use,
  :rack_power_draw_kva,
  :rack_weight_lbs,
  :rack_height_inches,
  :rack_width_inches,
  :rack_depth_inches,
  :rack_unit_height,
  :ec2_capacities)
  SENSITIVE = []
  include Aws::Structure
end

#rack_idString

The ID of the rack.

Returns:

  • (String)


2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
# File 'lib/aws-sdk-outposts/types.rb', line 2833

class RackSpecificationDetails < Struct.new(
  :rack_id,
  :rack_use,
  :rack_power_draw_kva,
  :rack_weight_lbs,
  :rack_height_inches,
  :rack_width_inches,
  :rack_depth_inches,
  :rack_unit_height,
  :ec2_capacities)
  SENSITIVE = []
  include Aws::Structure
end

#rack_power_draw_kvaFloat

The maximum power draw of the rack in kVA.

Returns:

  • (Float)


2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
# File 'lib/aws-sdk-outposts/types.rb', line 2833

class RackSpecificationDetails < Struct.new(
  :rack_id,
  :rack_use,
  :rack_power_draw_kva,
  :rack_weight_lbs,
  :rack_height_inches,
  :rack_width_inches,
  :rack_depth_inches,
  :rack_unit_height,
  :ec2_capacities)
  SENSITIVE = []
  include Aws::Structure
end

#rack_unit_heightString

The rack unit height.

  • ‘HEIGHT_42U` - 42 rack units.

  • ‘HEIGHT_2U` - 2 rack units.

  • ‘HEIGHT_1U` - 1 rack unit.

Returns:

  • (String)


2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
# File 'lib/aws-sdk-outposts/types.rb', line 2833

class RackSpecificationDetails < Struct.new(
  :rack_id,
  :rack_use,
  :rack_power_draw_kva,
  :rack_weight_lbs,
  :rack_height_inches,
  :rack_width_inches,
  :rack_depth_inches,
  :rack_unit_height,
  :ec2_capacities)
  SENSITIVE = []
  include Aws::Structure
end

#rack_useString

The use of the rack. Valid values are ‘COMPUTE` and `NETWORKING`.

Returns:

  • (String)


2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
# File 'lib/aws-sdk-outposts/types.rb', line 2833

class RackSpecificationDetails < Struct.new(
  :rack_id,
  :rack_use,
  :rack_power_draw_kva,
  :rack_weight_lbs,
  :rack_height_inches,
  :rack_width_inches,
  :rack_depth_inches,
  :rack_unit_height,
  :ec2_capacities)
  SENSITIVE = []
  include Aws::Structure
end

#rack_weight_lbsFloat

The weight of the rack in pounds.

Returns:

  • (Float)


2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
# File 'lib/aws-sdk-outposts/types.rb', line 2833

class RackSpecificationDetails < Struct.new(
  :rack_id,
  :rack_use,
  :rack_power_draw_kva,
  :rack_weight_lbs,
  :rack_height_inches,
  :rack_width_inches,
  :rack_depth_inches,
  :rack_unit_height,
  :ec2_capacities)
  SENSITIVE = []
  include Aws::Structure
end

#rack_width_inchesFloat

The width of the rack in inches.

Returns:

  • (Float)


2833
2834
2835
2836
2837
2838
2839
2840
2841
2842
2843
2844
2845
# File 'lib/aws-sdk-outposts/types.rb', line 2833

class RackSpecificationDetails < Struct.new(
  :rack_id,
  :rack_use,
  :rack_power_draw_kva,
  :rack_weight_lbs,
  :rack_height_inches,
  :rack_width_inches,
  :rack_depth_inches,
  :rack_unit_height,
  :ec2_capacities)
  SENSITIVE = []
  include Aws::Structure
end