Class: Aws::Outposts::Types::StartCapacityTaskOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_task_idString

ID of the capacity task that you want to start.

Returns:



2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
# File 'lib/aws-sdk-outposts/types.rb', line 2124

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#capacity_task_statusString

Status of the specified capacity task.

Returns:



2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
# File 'lib/aws-sdk-outposts/types.rb', line 2124

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#completion_dateTime

Date that the specified capacity task ran successfully.

Returns:



2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
# File 'lib/aws-sdk-outposts/types.rb', line 2124

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateTime

Date that the specified capacity task was created.

Returns:



2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
# File 'lib/aws-sdk-outposts/types.rb', line 2124

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Results of the dry run showing if the specified capacity task is above or below the available instance capacity.

Returns:



2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
# File 'lib/aws-sdk-outposts/types.rb', line 2124

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#failedTypes::CapacityTaskFailure

Reason that the specified capacity task failed.

Returns:



2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
# File 'lib/aws-sdk-outposts/types.rb', line 2124

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#instances_to_excludeTypes::InstancesToExclude

User-specified instances that must not be stopped in order to free up the capacity needed to run the capacity task.

Returns:



2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
# File 'lib/aws-sdk-outposts/types.rb', line 2124

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_dateTime

Date that the specified capacity task was last modified.

Returns:



2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
# File 'lib/aws-sdk-outposts/types.rb', line 2124

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#order_idString

ID of the Amazon Web Services Outposts order of the host associated with the capacity task.

Returns:



2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
# File 'lib/aws-sdk-outposts/types.rb', line 2124

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#outpost_idString

ID of the Outpost associated with the capacity task.

Returns:



2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
# File 'lib/aws-sdk-outposts/types.rb', line 2124

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#requested_instance_poolsArray<Types::InstanceTypeCapacity>

List of the instance pools requested in the specified capacity task.

Returns:



2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
# File 'lib/aws-sdk-outposts/types.rb', line 2124

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end

#task_action_on_blocking_instancesString

User-specified option in case an instance is blocking the capacity task from running.

  • WAIT_FOR_EVACUATION - Checks every 10 minutes over 48 hours to determine if instances have stopped and capacity is available to complete the task.

  • FAIL_TASK - The capacity task fails.

Returns:



2124
2125
2126
2127
2128
2129
2130
2131
2132
2133
2134
2135
2136
2137
2138
2139
# File 'lib/aws-sdk-outposts/types.rb', line 2124

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :instances_to_exclude,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date,
  :task_action_on_blocking_instances)
  SENSITIVE = []
  include Aws::Structure
end