Class: Aws::Outposts::Types::StartConnectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::StartConnectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Note:
When making an API call, you may pass StartConnectionRequest data as a hash:
{
device_serial_number: "DeviceSerialNumber", # required
asset_id: "AssetId", # required
client_public_key: "WireGuardPublicKey", # required
network_interface_device_index: 1, # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_id ⇒ String
The ID of the Outpost server.
-
#client_public_key ⇒ String
The public key of the client.
-
#device_serial_number ⇒ String
The serial number of the dongle.
-
#network_interface_device_index ⇒ Integer
The device index of the network interface on the Outpost server.
Instance Attribute Details
#asset_id ⇒ String
The ID of the Outpost server.
1815 1816 1817 1818 1819 1820 1821 1822 |
# File 'lib/aws-sdk-outposts/types.rb', line 1815 class StartConnectionRequest < Struct.new( :device_serial_number, :asset_id, :client_public_key, :network_interface_device_index) SENSITIVE = [] include Aws::Structure end |
#client_public_key ⇒ String
The public key of the client.
1815 1816 1817 1818 1819 1820 1821 1822 |
# File 'lib/aws-sdk-outposts/types.rb', line 1815 class StartConnectionRequest < Struct.new( :device_serial_number, :asset_id, :client_public_key, :network_interface_device_index) SENSITIVE = [] include Aws::Structure end |
#device_serial_number ⇒ String
The serial number of the dongle.
1815 1816 1817 1818 1819 1820 1821 1822 |
# File 'lib/aws-sdk-outposts/types.rb', line 1815 class StartConnectionRequest < Struct.new( :device_serial_number, :asset_id, :client_public_key, :network_interface_device_index) SENSITIVE = [] include Aws::Structure end |
#network_interface_device_index ⇒ Integer
The device index of the network interface on the Outpost server.
1815 1816 1817 1818 1819 1820 1821 1822 |
# File 'lib/aws-sdk-outposts/types.rb', line 1815 class StartConnectionRequest < Struct.new( :device_serial_number, :asset_id, :client_public_key, :network_interface_device_index) SENSITIVE = [] include Aws::Structure end |