Class: Aws::Outposts::Types::StartOutpostDecommissionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::StartOutpostDecommissionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#outpost_identifier ⇒ String
The ID or ARN of the Outpost that you want to decommission.
-
#validate_only ⇒ Boolean
Validates the request without starting the decommission process.
Instance Attribute Details
#outpost_identifier ⇒ String
The ID or ARN of the Outpost that you want to decommission.
3205 3206 3207 3208 3209 3210 |
# File 'lib/aws-sdk-outposts/types.rb', line 3205 class StartOutpostDecommissionInput < Struct.new( :outpost_identifier, :validate_only) SENSITIVE = [] include Aws::Structure end |
#validate_only ⇒ Boolean
Validates the request without starting the decommission process.
3205 3206 3207 3208 3209 3210 |
# File 'lib/aws-sdk-outposts/types.rb', line 3205 class StartOutpostDecommissionInput < Struct.new( :outpost_identifier, :validate_only) SENSITIVE = [] include Aws::Structure end |