Class: Aws::Outposts::Types::StartOutpostDecommissionOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::StartOutpostDecommissionOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#blocking_resource_types ⇒ Array<String>
The resources still associated with the Outpost that you are decommissioning.
-
#status ⇒ String
The status of the decommission request.
Instance Attribute Details
#blocking_resource_types ⇒ Array<String>
The resources still associated with the Outpost that you are decommissioning.
3203 3204 3205 3206 3207 3208 |
# File 'lib/aws-sdk-outposts/types.rb', line 3203 class StartOutpostDecommissionOutput < Struct.new( :status, :blocking_resource_types) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the decommission request.
3203 3204 3205 3206 3207 3208 |
# File 'lib/aws-sdk-outposts/types.rb', line 3203 class StartOutpostDecommissionOutput < Struct.new( :status, :blocking_resource_types) SENSITIVE = [] include Aws::Structure end |