Class: Aws::Outposts::Types::UpdateQuoteInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#country_code ⇒ String

The country code for the Outpost site location.

Returns:

  • (String)


3576
3577
3578
3579
3580
3581
3582
3583
3584
3585
3586
3587
# File 'lib/aws-sdk-outposts/types.rb', line 3576

class UpdateQuoteInput < Struct.new(
  :quote_identifier,
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#description ⇒ String

A description for the quote.

Returns:

  • (String)


3576
3577
3578
3579
3580
3581
3582
3583
3584
3585
3586
3587
# File 'lib/aws-sdk-outposts/types.rb', line 3576

class UpdateQuoteInput < Struct.new(
  :quote_identifier,
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#outpost_identifier ⇒ String

The ID or ARN of the Outpost to associate with the quote. Specify an empty string to remove the Outpost association.

Returns:

  • (String)


3576
3577
3578
3579
3580
3581
3582
3583
3584
3585
3586
3587
# File 'lib/aws-sdk-outposts/types.rb', line 3576

class UpdateQuoteInput < Struct.new(
  :quote_identifier,
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#quote_identifier ⇒ String

The ID of the quote.

Returns:

  • (String)


3576
3577
3578
3579
3580
3581
3582
3583
3584
3585
3586
3587
# File 'lib/aws-sdk-outposts/types.rb', line 3576

class UpdateQuoteInput < Struct.new(
  :quote_identifier,
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#requested_capacities ⇒ Array<Types::QuoteCapacity>

The updated capacity requirements for the quote.

Returns:



3576
3577
3578
3579
3580
3581
3582
3583
3584
3585
3586
3587
# File 'lib/aws-sdk-outposts/types.rb', line 3576

class UpdateQuoteInput < Struct.new(
  :quote_identifier,
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#requested_constraints ⇒ Array<Types::QuoteConstraint>

The updated physical constraints for the quote.

Returns:



3576
3577
3578
3579
3580
3581
3582
3583
3584
3585
3586
3587
# File 'lib/aws-sdk-outposts/types.rb', line 3576

class UpdateQuoteInput < Struct.new(
  :quote_identifier,
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#requested_payment_options ⇒ Array<String>

The updated payment options to include in the quote pricing.

Returns:

  • (Array<String>)


3576
3577
3578
3579
3580
3581
3582
3583
3584
3585
3586
3587
# File 'lib/aws-sdk-outposts/types.rb', line 3576

class UpdateQuoteInput < Struct.new(
  :quote_identifier,
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#requested_payment_terms ⇒ Array<String>

The updated payment terms to include in the quote pricing.

Returns:

  • (Array<String>)


3576
3577
3578
3579
3580
3581
3582
3583
3584
3585
3586
3587
# File 'lib/aws-sdk-outposts/types.rb', line 3576

class UpdateQuoteInput < Struct.new(
  :quote_identifier,
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end