Class: Aws::Outposts::Types::UpdateSiteInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Note:

When making an API call, you may pass UpdateSiteInput data as a hash:

{
  site_id: "SiteId", # required
  name: "SiteName",
  description: "SiteDescription",
  notes: "SiteNotes",
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the site.

Returns:

  • (String)


1995
1996
1997
1998
1999
2000
2001
2002
# File 'lib/aws-sdk-outposts/types.rb', line 1995

class UpdateSiteInput < Struct.new(
  :site_id,
  :name,
  :description,
  :notes)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the site.

Returns:

  • (String)


1995
1996
1997
1998
1999
2000
2001
2002
# File 'lib/aws-sdk-outposts/types.rb', line 1995

class UpdateSiteInput < Struct.new(
  :site_id,
  :name,
  :description,
  :notes)
  SENSITIVE = []
  include Aws::Structure
end

#notesString

Notes about a site.

Returns:

  • (String)


1995
1996
1997
1998
1999
2000
2001
2002
# File 'lib/aws-sdk-outposts/types.rb', line 1995

class UpdateSiteInput < Struct.new(
  :site_id,
  :name,
  :description,
  :notes)
  SENSITIVE = []
  include Aws::Structure
end

#site_idString

The ID or the Amazon Resource Name (ARN) of the site.

<note markdown=“1”> In requests, Amazon Web Services Outposts accepts the Amazon Resource Name (ARN) or an ID for Outposts and sites throughout the Outposts Query API. To address backwards compatibility, the parameter names `OutpostID` or `SiteID` remain in use. Despite the parameter name, you can make the request with an ARN.

</note>

Returns:

  • (String)


1995
1996
1997
1998
1999
2000
2001
2002
# File 'lib/aws-sdk-outposts/types.rb', line 1995

class UpdateSiteInput < Struct.new(
  :site_id,
  :name,
  :description,
  :notes)
  SENSITIVE = []
  include Aws::Structure
end