Class: Aws::Outposts::Types::VpcInformation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Information about a VPC used for private connectivity, including its subnets and an associated VPC endpoint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#subnet_ids ⇒ Array<String>

The IDs of the subnets associated with the VPC endpoint. Currently, only one subnet is supported.

Returns:

  • (Array<String>)


3850
3851
3852
3853
3854
3855
3856
# File 'lib/aws-sdk-outposts/types.rb', line 3850

class VpcInformation < Struct.new(
  :vpc_id,
  :subnet_ids,
  :vpc_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_id ⇒ String

The ID of the interface VPC endpoint for the Amazon Web Services Outposts service. When specified, the endpoint must be in the available state and the specified subnets must be associated with it.

Returns:

  • (String)


3850
3851
3852
3853
3854
3855
3856
# File 'lib/aws-sdk-outposts/types.rb', line 3850

class VpcInformation < Struct.new(
  :vpc_id,
  :subnet_ids,
  :vpc_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_id ⇒ String

The ID of the VPC used for private connectivity.

Returns:

  • (String)


3850
3851
3852
3853
3854
3855
3856
# File 'lib/aws-sdk-outposts/types.rb', line 3850

class VpcInformation < Struct.new(
  :vpc_id,
  :subnet_ids,
  :vpc_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end