Class: Aws::Outposts::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Outposts::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-outposts/client.rb
Overview
An API client for Outposts. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Outposts::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_capacity_task(params = {}) ⇒ Struct
Cancels the capacity task.
-
#cancel_order(params = {}) ⇒ Struct
Cancels the specified order for an Outpost.
-
#create_order(params = {}) ⇒ Types::CreateOrderOutput
Creates an order for an Outpost.
-
#create_outpost(params = {}) ⇒ Types::CreateOutpostOutput
Creates an Outpost.
-
#create_site(params = {}) ⇒ Types::CreateSiteOutput
Creates a site for an Outpost.
-
#delete_outpost(params = {}) ⇒ Struct
Deletes the specified Outpost.
-
#delete_site(params = {}) ⇒ Struct
Deletes the specified site.
-
#get_capacity_task(params = {}) ⇒ Types::GetCapacityTaskOutput
Gets details of the specified capacity task.
-
#get_catalog_item(params = {}) ⇒ Types::GetCatalogItemOutput
Gets information about the specified catalog item.
-
#get_connection(params = {}) ⇒ Types::GetConnectionResponse
<note markdown=“1”> Amazon Web Services uses this action to install Outpost servers.
-
#get_order(params = {}) ⇒ Types::GetOrderOutput
Gets information about the specified order.
-
#get_outpost(params = {}) ⇒ Types::GetOutpostOutput
Gets information about the specified Outpost.
-
#get_outpost_instance_types(params = {}) ⇒ Types::GetOutpostInstanceTypesOutput
Gets the instance types for the specified Outpost.
-
#get_outpost_supported_instance_types(params = {}) ⇒ Types::GetOutpostSupportedInstanceTypesOutput
Gets the instance types that an Outpost can support in ‘InstanceTypeCapacity`.
-
#get_site(params = {}) ⇒ Types::GetSiteOutput
Gets information about the specified Outpost site.
-
#get_site_address(params = {}) ⇒ Types::GetSiteAddressOutput
Gets the site address of the specified site.
-
#list_assets(params = {}) ⇒ Types::ListAssetsOutput
Lists the hardware assets for the specified Outpost.
-
#list_capacity_tasks(params = {}) ⇒ Types::ListCapacityTasksOutput
Lists the capacity tasks for your Amazon Web Services account.
-
#list_catalog_items(params = {}) ⇒ Types::ListCatalogItemsOutput
Lists the items in the catalog.
-
#list_orders(params = {}) ⇒ Types::ListOrdersOutput
Lists the Outpost orders for your Amazon Web Services account.
-
#list_outposts(params = {}) ⇒ Types::ListOutpostsOutput
Lists the Outposts for your Amazon Web Services account.
-
#list_sites(params = {}) ⇒ Types::ListSitesOutput
Lists the Outpost sites for your Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#start_capacity_task(params = {}) ⇒ Types::StartCapacityTaskOutput
Starts the specified capacity task.
-
#start_connection(params = {}) ⇒ Types::StartConnectionResponse
<note markdown=“1”> Amazon Web Services uses this action to install Outpost servers.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
-
#update_outpost(params = {}) ⇒ Types::UpdateOutpostOutput
Updates an Outpost.
-
#update_site(params = {}) ⇒ Types::UpdateSiteOutput
Updates the specified site.
-
#update_site_address(params = {}) ⇒ Types::UpdateSiteAddressOutput
Updates the address of the specified site.
-
#update_site_rack_physical_properties(params = {}) ⇒ Types::UpdateSiteRackPhysicalPropertiesOutput
Update the physical and logistical details for a rack at a site.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
446 447 448 |
# File 'lib/aws-sdk-outposts/client.rb', line 446 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2174 2175 2176 |
# File 'lib/aws-sdk-outposts/client.rb', line 2174 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2177 2178 2179 |
# File 'lib/aws-sdk-outposts/client.rb', line 2177 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2147 2148 2149 2150 2151 2152 2153 2154 2155 2156 2157 2158 2159 2160 2161 2162 2163 |
# File 'lib/aws-sdk-outposts/client.rb', line 2147 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Outposts') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-outposts' context[:gem_version] = '1.68.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_capacity_task(params = {}) ⇒ Struct
Cancels the capacity task.
474 475 476 477 |
# File 'lib/aws-sdk-outposts/client.rb', line 474 def cancel_capacity_task(params = {}, = {}) req = build_request(:cancel_capacity_task, params) req.send_request() end |
#cancel_order(params = {}) ⇒ Struct
Cancels the specified order for an Outpost.
496 497 498 499 |
# File 'lib/aws-sdk-outposts/client.rb', line 496 def cancel_order(params = {}, = {}) req = build_request(:cancel_order, params) req.send_request() end |
#create_order(params = {}) ⇒ Types::CreateOrderOutput
Creates an order for an Outpost.
561 562 563 564 |
# File 'lib/aws-sdk-outposts/client.rb', line 561 def create_order(params = {}, = {}) req = build_request(:create_order, params) req.send_request() end |
#create_outpost(params = {}) ⇒ Types::CreateOutpostOutput
Creates an Outpost.
You can specify either an Availability one or an AZ ID.
629 630 631 632 |
# File 'lib/aws-sdk-outposts/client.rb', line 629 def create_outpost(params = {}, = {}) req = build_request(:create_outpost, params) req.send_request() end |
#create_site(params = {}) ⇒ Types::CreateSiteOutput
Creates a site for an Outpost.
748 749 750 751 |
# File 'lib/aws-sdk-outposts/client.rb', line 748 def create_site(params = {}, = {}) req = build_request(:create_site, params) req.send_request() end |
#delete_outpost(params = {}) ⇒ Struct
Deletes the specified Outpost.
770 771 772 773 |
# File 'lib/aws-sdk-outposts/client.rb', line 770 def delete_outpost(params = {}, = {}) req = build_request(:delete_outpost, params) req.send_request() end |
#delete_site(params = {}) ⇒ Struct
Deletes the specified site.
792 793 794 795 |
# File 'lib/aws-sdk-outposts/client.rb', line 792 def delete_site(params = {}, = {}) req = build_request(:delete_site, params) req.send_request() end |
#get_capacity_task(params = {}) ⇒ Types::GetCapacityTaskOutput
Gets details of the specified capacity task.
845 846 847 848 |
# File 'lib/aws-sdk-outposts/client.rb', line 845 def get_capacity_task(params = {}, = {}) req = build_request(:get_capacity_task, params) req.send_request() end |
#get_catalog_item(params = {}) ⇒ Types::GetCatalogItemOutput
Gets information about the specified catalog item.
884 885 886 887 |
# File 'lib/aws-sdk-outposts/client.rb', line 884 def get_catalog_item(params = {}, = {}) req = build_request(:get_catalog_item, params) req.send_request() end |
#get_connection(params = {}) ⇒ Types::GetConnectionResponse
<note markdown=“1”> Amazon Web Services uses this action to install Outpost servers.
</note>
Gets information about the specified connection.
Use CloudTrail to monitor this action or Amazon Web Services managed policy for Amazon Web Services Outposts to secure it. For more information, see [ Amazon Web Services managed policies for Amazon Web Services Outposts] and [ Logging Amazon Web Services Outposts API calls with Amazon Web Services CloudTrail] in the *Amazon Web Services Outposts User Guide*.
[1]: docs.aws.amazon.com/outposts/latest/userguide/security-iam-awsmanpol.html [2]: docs.aws.amazon.com/outposts/latest/userguide/logging-using-cloudtrail.html
936 937 938 939 |
# File 'lib/aws-sdk-outposts/client.rb', line 936 def get_connection(params = {}, = {}) req = build_request(:get_connection, params) req.send_request() end |
#get_order(params = {}) ⇒ Types::GetOrderOutput
Gets information about the specified order.
984 985 986 987 |
# File 'lib/aws-sdk-outposts/client.rb', line 984 def get_order(params = {}, = {}) req = build_request(:get_order, params) req.send_request() end |
#get_outpost(params = {}) ⇒ Types::GetOutpostOutput
Gets information about the specified Outpost.
1024 1025 1026 1027 |
# File 'lib/aws-sdk-outposts/client.rb', line 1024 def get_outpost(params = {}, = {}) req = build_request(:get_outpost, params) req.send_request() end |
#get_outpost_instance_types(params = {}) ⇒ Types::GetOutpostInstanceTypesOutput
Gets the instance types for the specified Outpost.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1070 1071 1072 1073 |
# File 'lib/aws-sdk-outposts/client.rb', line 1070 def get_outpost_instance_types(params = {}, = {}) req = build_request(:get_outpost_instance_types, params) req.send_request() end |
#get_outpost_supported_instance_types(params = {}) ⇒ Types::GetOutpostSupportedInstanceTypesOutput
Gets the instance types that an Outpost can support in ‘InstanceTypeCapacity`. This will generally include instance types that are not currently configured and therefore cannot be launched with the current Outpost capacity configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1119 1120 1121 1122 |
# File 'lib/aws-sdk-outposts/client.rb', line 1119 def get_outpost_supported_instance_types(params = {}, = {}) req = build_request(:get_outpost_supported_instance_types, params) req.send_request() end |
#get_site(params = {}) ⇒ Types::GetSiteOutput
Gets information about the specified Outpost site.
1166 1167 1168 1169 |
# File 'lib/aws-sdk-outposts/client.rb', line 1166 def get_site(params = {}, = {}) req = build_request(:get_site, params) req.send_request() end |
#get_site_address(params = {}) ⇒ Types::GetSiteAddressOutput
Gets the site address of the specified site.
1212 1213 1214 1215 |
# File 'lib/aws-sdk-outposts/client.rb', line 1212 def get_site_address(params = {}, = {}) req = build_request(:get_site_address, params) req.send_request() end |
#list_assets(params = {}) ⇒ Types::ListAssetsOutput
Lists the hardware assets for the specified Outpost.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1274 1275 1276 1277 |
# File 'lib/aws-sdk-outposts/client.rb', line 1274 def list_assets(params = {}, = {}) req = build_request(:list_assets, params) req.send_request() end |
#list_capacity_tasks(params = {}) ⇒ Types::ListCapacityTasksOutput
Lists the capacity tasks for your Amazon Web Services account.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1332 1333 1334 1335 |
# File 'lib/aws-sdk-outposts/client.rb', line 1332 def list_capacity_tasks(params = {}, = {}) req = build_request(:list_capacity_tasks, params) req.send_request() end |
#list_catalog_items(params = {}) ⇒ Types::ListCatalogItemsOutput
Lists the items in the catalog.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1398 1399 1400 1401 |
# File 'lib/aws-sdk-outposts/client.rb', line 1398 def list_catalog_items(params = {}, = {}) req = build_request(:list_catalog_items, params) req.send_request() end |
#list_orders(params = {}) ⇒ Types::ListOrdersOutput
Lists the Outpost orders for your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1446 1447 1448 1449 |
# File 'lib/aws-sdk-outposts/client.rb', line 1446 def list_orders(params = {}, = {}) req = build_request(:list_orders, params) req.send_request() end |
#list_outposts(params = {}) ⇒ Types::ListOutpostsOutput
Lists the Outposts for your Amazon Web Services account.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1513 1514 1515 1516 |
# File 'lib/aws-sdk-outposts/client.rb', line 1513 def list_outposts(params = {}, = {}) req = build_request(:list_outposts, params) req.send_request() end |
#list_sites(params = {}) ⇒ Types::ListSitesOutput
Lists the Outpost sites for your Amazon Web Services account. Use filters to return specific results.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1588 1589 1590 1591 |
# File 'lib/aws-sdk-outposts/client.rb', line 1588 def list_sites(params = {}, = {}) req = build_request(:list_sites, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
1617 1618 1619 1620 |
# File 'lib/aws-sdk-outposts/client.rb', line 1617 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#start_capacity_task(params = {}) ⇒ Types::StartCapacityTaskOutput
Starts the specified capacity task. You can have one active capacity task for an order.
1688 1689 1690 1691 |
# File 'lib/aws-sdk-outposts/client.rb', line 1688 def start_capacity_task(params = {}, = {}) req = build_request(:start_capacity_task, params) req.send_request() end |
#start_connection(params = {}) ⇒ Types::StartConnectionResponse
<note markdown=“1”> Amazon Web Services uses this action to install Outpost servers.
</note>
Starts the connection required for Outpost server installation.
Use CloudTrail to monitor this action or Amazon Web Services managed policy for Amazon Web Services Outposts to secure it. For more information, see [ Amazon Web Services managed policies for Amazon Web Services Outposts] and [ Logging Amazon Web Services Outposts API calls with Amazon Web Services CloudTrail] in the *Amazon Web Services Outposts User Guide*.
[1]: docs.aws.amazon.com/outposts/latest/userguide/security-iam-awsmanpol.html [2]: docs.aws.amazon.com/outposts/latest/userguide/logging-using-cloudtrail.html
1746 1747 1748 1749 |
# File 'lib/aws-sdk-outposts/client.rb', line 1746 def start_connection(params = {}, = {}) req = build_request(:start_connection, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
1774 1775 1776 1777 |
# File 'lib/aws-sdk-outposts/client.rb', line 1774 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
1800 1801 1802 1803 |
# File 'lib/aws-sdk-outposts/client.rb', line 1800 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_outpost(params = {}) ⇒ Types::UpdateOutpostOutput
Updates an Outpost.
1852 1853 1854 1855 |
# File 'lib/aws-sdk-outposts/client.rb', line 1852 def update_outpost(params = {}, = {}) req = build_request(:update_outpost, params) req.send_request() end |
#update_site(params = {}) ⇒ Types::UpdateSiteOutput
Updates the specified site.
1911 1912 1913 1914 |
# File 'lib/aws-sdk-outposts/client.rb', line 1911 def update_site(params = {}, = {}) req = build_request(:update_site, params) req.send_request() end |
#update_site_address(params = {}) ⇒ Types::UpdateSiteAddressOutput
Updates the address of the specified site.
You can’t update a site address if there is an order in progress. You must wait for the order to complete or cancel the order.
You can update the operating address before you place an order at the site, or after all Outposts that belong to the site have been deactivated.
1978 1979 1980 1981 |
# File 'lib/aws-sdk-outposts/client.rb', line 1978 def update_site_address(params = {}, = {}) req = build_request(:update_site_address, params) req.send_request() end |
#update_site_rack_physical_properties(params = {}) ⇒ Types::UpdateSiteRackPhysicalPropertiesOutput
Update the physical and logistical details for a rack at a site. For more information about hardware requirements for racks, see [Network readiness checklist] in the Amazon Web Services Outposts User Guide.
To update a rack at a site with an order of ‘IN_PROGRESS`, you must wait for the order to complete or cancel the order.
[1]: docs.aws.amazon.com/outposts/latest/userguide/outposts-requirements.html#checklist
2138 2139 2140 2141 |
# File 'lib/aws-sdk-outposts/client.rb', line 2138 def update_site_rack_physical_properties(params = {}, = {}) req = build_request(:update_site_rack_physical_properties, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2167 2168 2169 |
# File 'lib/aws-sdk-outposts/client.rb', line 2167 def waiter_names [] end |