Class: Aws::Outposts::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Outposts::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-outposts/client.rb
Overview
An API client for Outposts. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Outposts::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_capacity_task(params = {}) ⇒ Struct
Cancels the capacity task.
-
#cancel_order(params = {}) ⇒ Struct
Cancels the specified order for an Outpost.
-
#create_order(params = {}) ⇒ Types::CreateOrderOutput
Creates an order for an Outpost.
-
#create_outpost(params = {}) ⇒ Types::CreateOutpostOutput
Creates an Outpost.
-
#create_site(params = {}) ⇒ Types::CreateSiteOutput
Creates a site for an Outpost.
-
#delete_outpost(params = {}) ⇒ Struct
Deletes the specified Outpost.
-
#delete_site(params = {}) ⇒ Struct
Deletes the specified site.
-
#get_capacity_task(params = {}) ⇒ Types::GetCapacityTaskOutput
Gets details of the specified capacity task.
-
#get_catalog_item(params = {}) ⇒ Types::GetCatalogItemOutput
Gets information about the specified catalog item.
-
#get_connection(params = {}) ⇒ Types::GetConnectionResponse
<note markdown=“1”> Amazon Web Services uses this action to install Outpost servers.
-
#get_order(params = {}) ⇒ Types::GetOrderOutput
Gets information about the specified order.
-
#get_outpost(params = {}) ⇒ Types::GetOutpostOutput
Gets information about the specified Outpost.
-
#get_outpost_instance_types(params = {}) ⇒ Types::GetOutpostInstanceTypesOutput
Gets the instance types for the specified Outpost.
-
#get_outpost_supported_instance_types(params = {}) ⇒ Types::GetOutpostSupportedInstanceTypesOutput
Gets the instance types that an Outpost can support in ‘InstanceTypeCapacity`.
-
#get_site(params = {}) ⇒ Types::GetSiteOutput
Gets information about the specified Outpost site.
-
#get_site_address(params = {}) ⇒ Types::GetSiteAddressOutput
Gets the site address of the specified site.
-
#list_assets(params = {}) ⇒ Types::ListAssetsOutput
Lists the hardware assets for the specified Outpost.
-
#list_capacity_tasks(params = {}) ⇒ Types::ListCapacityTasksOutput
Lists the capacity tasks for your Amazon Web Services account.
-
#list_catalog_items(params = {}) ⇒ Types::ListCatalogItemsOutput
Lists the items in the catalog.
-
#list_orders(params = {}) ⇒ Types::ListOrdersOutput
Lists the Outpost orders for your Amazon Web Services account.
-
#list_outposts(params = {}) ⇒ Types::ListOutpostsOutput
Lists the Outposts for your Amazon Web Services account.
-
#list_sites(params = {}) ⇒ Types::ListSitesOutput
Lists the Outpost sites for your Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#start_capacity_task(params = {}) ⇒ Types::StartCapacityTaskOutput
Starts the specified capacity task.
-
#start_connection(params = {}) ⇒ Types::StartConnectionResponse
<note markdown=“1”> Amazon Web Services uses this action to install Outpost servers.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
-
#update_outpost(params = {}) ⇒ Types::UpdateOutpostOutput
Updates an Outpost.
-
#update_site(params = {}) ⇒ Types::UpdateSiteOutput
Updates the specified site.
-
#update_site_address(params = {}) ⇒ Types::UpdateSiteAddressOutput
Updates the address of the specified site.
-
#update_site_rack_physical_properties(params = {}) ⇒ Types::UpdateSiteRackPhysicalPropertiesOutput
Update the physical and logistical details for a rack at a site.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
413 414 415 |
# File 'lib/aws-sdk-outposts/client.rb', line 413 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2134 2135 2136 |
# File 'lib/aws-sdk-outposts/client.rb', line 2134 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2137 2138 2139 |
# File 'lib/aws-sdk-outposts/client.rb', line 2137 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2112 2113 2114 2115 2116 2117 2118 2119 2120 2121 2122 2123 |
# File 'lib/aws-sdk-outposts/client.rb', line 2112 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-outposts' context[:gem_version] = '1.61.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_capacity_task(params = {}) ⇒ Struct
Cancels the capacity task.
441 442 443 444 |
# File 'lib/aws-sdk-outposts/client.rb', line 441 def cancel_capacity_task(params = {}, = {}) req = build_request(:cancel_capacity_task, params) req.send_request() end |
#cancel_order(params = {}) ⇒ Struct
Cancels the specified order for an Outpost.
463 464 465 466 |
# File 'lib/aws-sdk-outposts/client.rb', line 463 def cancel_order(params = {}, = {}) req = build_request(:cancel_order, params) req.send_request() end |
#create_order(params = {}) ⇒ Types::CreateOrderOutput
Creates an order for an Outpost.
528 529 530 531 |
# File 'lib/aws-sdk-outposts/client.rb', line 528 def create_order(params = {}, = {}) req = build_request(:create_order, params) req.send_request() end |
#create_outpost(params = {}) ⇒ Types::CreateOutpostOutput
Creates an Outpost.
You can specify either an Availability one or an AZ ID.
596 597 598 599 |
# File 'lib/aws-sdk-outposts/client.rb', line 596 def create_outpost(params = {}, = {}) req = build_request(:create_outpost, params) req.send_request() end |
#create_site(params = {}) ⇒ Types::CreateSiteOutput
Creates a site for an Outpost.
715 716 717 718 |
# File 'lib/aws-sdk-outposts/client.rb', line 715 def create_site(params = {}, = {}) req = build_request(:create_site, params) req.send_request() end |
#delete_outpost(params = {}) ⇒ Struct
Deletes the specified Outpost.
737 738 739 740 |
# File 'lib/aws-sdk-outposts/client.rb', line 737 def delete_outpost(params = {}, = {}) req = build_request(:delete_outpost, params) req.send_request() end |
#delete_site(params = {}) ⇒ Struct
Deletes the specified site.
759 760 761 762 |
# File 'lib/aws-sdk-outposts/client.rb', line 759 def delete_site(params = {}, = {}) req = build_request(:delete_site, params) req.send_request() end |
#get_capacity_task(params = {}) ⇒ Types::GetCapacityTaskOutput
Gets details of the specified capacity task.
812 813 814 815 |
# File 'lib/aws-sdk-outposts/client.rb', line 812 def get_capacity_task(params = {}, = {}) req = build_request(:get_capacity_task, params) req.send_request() end |
#get_catalog_item(params = {}) ⇒ Types::GetCatalogItemOutput
Gets information about the specified catalog item.
851 852 853 854 |
# File 'lib/aws-sdk-outposts/client.rb', line 851 def get_catalog_item(params = {}, = {}) req = build_request(:get_catalog_item, params) req.send_request() end |
#get_connection(params = {}) ⇒ Types::GetConnectionResponse
<note markdown=“1”> Amazon Web Services uses this action to install Outpost servers.
</note>
Gets information about the specified connection.
Use CloudTrail to monitor this action or Amazon Web Services managed policy for Amazon Web Services Outposts to secure it. For more information, see [ Amazon Web Services managed policies for Amazon Web Services Outposts] and [ Logging Amazon Web Services Outposts API calls with Amazon Web Services CloudTrail] in the *Amazon Web Services Outposts User Guide*.
[1]: docs.aws.amazon.com/outposts/latest/userguide/security-iam-awsmanpol.html [2]: docs.aws.amazon.com/outposts/latest/userguide/logging-using-cloudtrail.html
903 904 905 906 |
# File 'lib/aws-sdk-outposts/client.rb', line 903 def get_connection(params = {}, = {}) req = build_request(:get_connection, params) req.send_request() end |
#get_order(params = {}) ⇒ Types::GetOrderOutput
Gets information about the specified order.
951 952 953 954 |
# File 'lib/aws-sdk-outposts/client.rb', line 951 def get_order(params = {}, = {}) req = build_request(:get_order, params) req.send_request() end |
#get_outpost(params = {}) ⇒ Types::GetOutpostOutput
Gets information about the specified Outpost.
991 992 993 994 |
# File 'lib/aws-sdk-outposts/client.rb', line 991 def get_outpost(params = {}, = {}) req = build_request(:get_outpost, params) req.send_request() end |
#get_outpost_instance_types(params = {}) ⇒ Types::GetOutpostInstanceTypesOutput
Gets the instance types for the specified Outpost.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1036 1037 1038 1039 |
# File 'lib/aws-sdk-outposts/client.rb', line 1036 def get_outpost_instance_types(params = {}, = {}) req = build_request(:get_outpost_instance_types, params) req.send_request() end |
#get_outpost_supported_instance_types(params = {}) ⇒ Types::GetOutpostSupportedInstanceTypesOutput
Gets the instance types that an Outpost can support in ‘InstanceTypeCapacity`. This will generally include instance types that are not currently configured and therefore cannot be launched with the current Outpost capacity configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1084 1085 1086 1087 |
# File 'lib/aws-sdk-outposts/client.rb', line 1084 def get_outpost_supported_instance_types(params = {}, = {}) req = build_request(:get_outpost_supported_instance_types, params) req.send_request() end |
#get_site(params = {}) ⇒ Types::GetSiteOutput
Gets information about the specified Outpost site.
1131 1132 1133 1134 |
# File 'lib/aws-sdk-outposts/client.rb', line 1131 def get_site(params = {}, = {}) req = build_request(:get_site, params) req.send_request() end |
#get_site_address(params = {}) ⇒ Types::GetSiteAddressOutput
Gets the site address of the specified site.
1177 1178 1179 1180 |
# File 'lib/aws-sdk-outposts/client.rb', line 1177 def get_site_address(params = {}, = {}) req = build_request(:get_site_address, params) req.send_request() end |
#list_assets(params = {}) ⇒ Types::ListAssetsOutput
Lists the hardware assets for the specified Outpost.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1239 1240 1241 1242 |
# File 'lib/aws-sdk-outposts/client.rb', line 1239 def list_assets(params = {}, = {}) req = build_request(:list_assets, params) req.send_request() end |
#list_capacity_tasks(params = {}) ⇒ Types::ListCapacityTasksOutput
Lists the capacity tasks for your Amazon Web Services account.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1297 1298 1299 1300 |
# File 'lib/aws-sdk-outposts/client.rb', line 1297 def list_capacity_tasks(params = {}, = {}) req = build_request(:list_capacity_tasks, params) req.send_request() end |
#list_catalog_items(params = {}) ⇒ Types::ListCatalogItemsOutput
Lists the items in the catalog.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1363 1364 1365 1366 |
# File 'lib/aws-sdk-outposts/client.rb', line 1363 def list_catalog_items(params = {}, = {}) req = build_request(:list_catalog_items, params) req.send_request() end |
#list_orders(params = {}) ⇒ Types::ListOrdersOutput
Lists the Outpost orders for your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1411 1412 1413 1414 |
# File 'lib/aws-sdk-outposts/client.rb', line 1411 def list_orders(params = {}, = {}) req = build_request(:list_orders, params) req.send_request() end |
#list_outposts(params = {}) ⇒ Types::ListOutpostsOutput
Lists the Outposts for your Amazon Web Services account.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1478 1479 1480 1481 |
# File 'lib/aws-sdk-outposts/client.rb', line 1478 def list_outposts(params = {}, = {}) req = build_request(:list_outposts, params) req.send_request() end |
#list_sites(params = {}) ⇒ Types::ListSitesOutput
Lists the Outpost sites for your Amazon Web Services account. Use filters to return specific results.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1553 1554 1555 1556 |
# File 'lib/aws-sdk-outposts/client.rb', line 1553 def list_sites(params = {}, = {}) req = build_request(:list_sites, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
1582 1583 1584 1585 |
# File 'lib/aws-sdk-outposts/client.rb', line 1582 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#start_capacity_task(params = {}) ⇒ Types::StartCapacityTaskOutput
Starts the specified capacity task. You can have one active capacity task for an order.
1653 1654 1655 1656 |
# File 'lib/aws-sdk-outposts/client.rb', line 1653 def start_capacity_task(params = {}, = {}) req = build_request(:start_capacity_task, params) req.send_request() end |
#start_connection(params = {}) ⇒ Types::StartConnectionResponse
<note markdown=“1”> Amazon Web Services uses this action to install Outpost servers.
</note>
Starts the connection required for Outpost server installation.
Use CloudTrail to monitor this action or Amazon Web Services managed policy for Amazon Web Services Outposts to secure it. For more information, see [ Amazon Web Services managed policies for Amazon Web Services Outposts] and [ Logging Amazon Web Services Outposts API calls with Amazon Web Services CloudTrail] in the *Amazon Web Services Outposts User Guide*.
[1]: docs.aws.amazon.com/outposts/latest/userguide/security-iam-awsmanpol.html [2]: docs.aws.amazon.com/outposts/latest/userguide/logging-using-cloudtrail.html
1711 1712 1713 1714 |
# File 'lib/aws-sdk-outposts/client.rb', line 1711 def start_connection(params = {}, = {}) req = build_request(:start_connection, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
1739 1740 1741 1742 |
# File 'lib/aws-sdk-outposts/client.rb', line 1739 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
1765 1766 1767 1768 |
# File 'lib/aws-sdk-outposts/client.rb', line 1765 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_outpost(params = {}) ⇒ Types::UpdateOutpostOutput
Updates an Outpost.
1817 1818 1819 1820 |
# File 'lib/aws-sdk-outposts/client.rb', line 1817 def update_outpost(params = {}, = {}) req = build_request(:update_outpost, params) req.send_request() end |
#update_site(params = {}) ⇒ Types::UpdateSiteOutput
Updates the specified site.
1876 1877 1878 1879 |
# File 'lib/aws-sdk-outposts/client.rb', line 1876 def update_site(params = {}, = {}) req = build_request(:update_site, params) req.send_request() end |
#update_site_address(params = {}) ⇒ Types::UpdateSiteAddressOutput
Updates the address of the specified site.
You can’t update a site address if there is an order in progress. You must wait for the order to complete or cancel the order.
You can update the operating address before you place an order at the site, or after all Outposts that belong to the site have been deactivated.
1943 1944 1945 1946 |
# File 'lib/aws-sdk-outposts/client.rb', line 1943 def update_site_address(params = {}, = {}) req = build_request(:update_site_address, params) req.send_request() end |
#update_site_rack_physical_properties(params = {}) ⇒ Types::UpdateSiteRackPhysicalPropertiesOutput
Update the physical and logistical details for a rack at a site. For more information about hardware requirements for racks, see [Network readiness checklist] in the Amazon Web Services Outposts User Guide.
To update a rack at a site with an order of ‘IN_PROGRESS`, you must wait for the order to complete or cancel the order.
[1]: docs.aws.amazon.com/outposts/latest/userguide/outposts-requirements.html#checklist
2103 2104 2105 2106 |
# File 'lib/aws-sdk-outposts/client.rb', line 2103 def update_site_rack_physical_properties(params = {}, = {}) req = build_request(:update_site_rack_physical_properties, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2127 2128 2129 |
# File 'lib/aws-sdk-outposts/client.rb', line 2127 def waiter_names [] end |