Class: Aws::Outposts::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Outposts::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-outposts/client.rb
Overview
An API client for Outposts. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Outposts::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_order(params = {}) ⇒ Struct
Cancels the specified order for an Outpost.
-
#create_order(params = {}) ⇒ Types::CreateOrderOutput
Creates an order for an Outpost.
-
#create_outpost(params = {}) ⇒ Types::CreateOutpostOutput
Creates an Outpost.
-
#create_site(params = {}) ⇒ Types::CreateSiteOutput
Creates a site for an Outpost.
-
#delete_outpost(params = {}) ⇒ Struct
Deletes the specified Outpost.
-
#delete_site(params = {}) ⇒ Struct
Deletes the specified site.
-
#get_catalog_item(params = {}) ⇒ Types::GetCatalogItemOutput
Gets information about the specified catalog item.
-
#get_connection(params = {}) ⇒ Types::GetConnectionResponse
<note markdown=“1”> Amazon Web Services uses this action to install Outpost servers.
-
#get_order(params = {}) ⇒ Types::GetOrderOutput
Gets information about the specified order.
-
#get_outpost(params = {}) ⇒ Types::GetOutpostOutput
Gets information about the specified Outpost.
-
#get_outpost_instance_types(params = {}) ⇒ Types::GetOutpostInstanceTypesOutput
Gets the instance types for the specified Outpost.
-
#get_site(params = {}) ⇒ Types::GetSiteOutput
Gets information about the specified Outpost site.
-
#get_site_address(params = {}) ⇒ Types::GetSiteAddressOutput
Gets the site address of the specified site.
-
#list_assets(params = {}) ⇒ Types::ListAssetsOutput
Lists the hardware assets for the specified Outpost.
-
#list_catalog_items(params = {}) ⇒ Types::ListCatalogItemsOutput
Lists the items in the catalog.
-
#list_orders(params = {}) ⇒ Types::ListOrdersOutput
Lists the Outpost orders for your Amazon Web Services account.
-
#list_outposts(params = {}) ⇒ Types::ListOutpostsOutput
Lists the Outposts for your Amazon Web Services account.
-
#list_sites(params = {}) ⇒ Types::ListSitesOutput
Lists the Outpost sites for your Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#start_connection(params = {}) ⇒ Types::StartConnectionResponse
<note markdown=“1”> Amazon Web Services uses this action to install Outpost servers.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
-
#update_outpost(params = {}) ⇒ Types::UpdateOutpostOutput
Updates an Outpost.
-
#update_site(params = {}) ⇒ Types::UpdateSiteOutput
Updates the specified site.
-
#update_site_address(params = {}) ⇒ Types::UpdateSiteAddressOutput
Updates the address of the specified site.
-
#update_site_rack_physical_properties(params = {}) ⇒ Types::UpdateSiteRackPhysicalPropertiesOutput
Update the physical and logistical details for a rack at a site.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
370 371 372 |
# File 'lib/aws-sdk-outposts/client.rb', line 370 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1832 1833 1834 |
# File 'lib/aws-sdk-outposts/client.rb', line 1832 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1835 1836 1837 |
# File 'lib/aws-sdk-outposts/client.rb', line 1835 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1810 1811 1812 1813 1814 1815 1816 1817 1818 1819 1820 1821 |
# File 'lib/aws-sdk-outposts/client.rb', line 1810 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-outposts' context[:gem_version] = '1.44.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_order(params = {}) ⇒ Struct
Cancels the specified order for an Outpost.
393 394 395 396 |
# File 'lib/aws-sdk-outposts/client.rb', line 393 def cancel_order(params = {}, = {}) req = build_request(:cancel_order, params) req.send_request() end |
#create_order(params = {}) ⇒ Types::CreateOrderOutput
Creates an order for an Outpost.
458 459 460 461 |
# File 'lib/aws-sdk-outposts/client.rb', line 458 def create_order(params = {}, = {}) req = build_request(:create_order, params) req.send_request() end |
#create_outpost(params = {}) ⇒ Types::CreateOutpostOutput
Creates an Outpost.
You can specify either an Availability one or an AZ ID.
526 527 528 529 |
# File 'lib/aws-sdk-outposts/client.rb', line 526 def create_outpost(params = {}, = {}) req = build_request(:create_outpost, params) req.send_request() end |
#create_site(params = {}) ⇒ Types::CreateSiteOutput
Creates a site for an Outpost.
645 646 647 648 |
# File 'lib/aws-sdk-outposts/client.rb', line 645 def create_site(params = {}, = {}) req = build_request(:create_site, params) req.send_request() end |
#delete_outpost(params = {}) ⇒ Struct
Deletes the specified Outpost.
667 668 669 670 |
# File 'lib/aws-sdk-outposts/client.rb', line 667 def delete_outpost(params = {}, = {}) req = build_request(:delete_outpost, params) req.send_request() end |
#delete_site(params = {}) ⇒ Struct
Deletes the specified site.
689 690 691 692 |
# File 'lib/aws-sdk-outposts/client.rb', line 689 def delete_site(params = {}, = {}) req = build_request(:delete_site, params) req.send_request() end |
#get_catalog_item(params = {}) ⇒ Types::GetCatalogItemOutput
Gets information about the specified catalog item.
728 729 730 731 |
# File 'lib/aws-sdk-outposts/client.rb', line 728 def get_catalog_item(params = {}, = {}) req = build_request(:get_catalog_item, params) req.send_request() end |
#get_connection(params = {}) ⇒ Types::GetConnectionResponse
<note markdown=“1”> Amazon Web Services uses this action to install Outpost servers.
</note>
Gets information about the specified connection.
Use CloudTrail to monitor this action or Amazon Web Services managed policy for Amazon Web Services Outposts to secure it. For more information, see [ Amazon Web Services managed policies for Amazon Web Services Outposts] and [ Logging Amazon Web Services Outposts API calls with Amazon Web Services CloudTrail] in the *Amazon Web Services Outposts User Guide*.
[1]: docs.aws.amazon.com/outposts/latest/userguide/security-iam-awsmanpol.html [2]: docs.aws.amazon.com/outposts/latest/userguide/logging-using-cloudtrail.html
780 781 782 783 |
# File 'lib/aws-sdk-outposts/client.rb', line 780 def get_connection(params = {}, = {}) req = build_request(:get_connection, params) req.send_request() end |
#get_order(params = {}) ⇒ Types::GetOrderOutput
Gets information about the specified order.
828 829 830 831 |
# File 'lib/aws-sdk-outposts/client.rb', line 828 def get_order(params = {}, = {}) req = build_request(:get_order, params) req.send_request() end |
#get_outpost(params = {}) ⇒ Types::GetOutpostOutput
Gets information about the specified Outpost.
868 869 870 871 |
# File 'lib/aws-sdk-outposts/client.rb', line 868 def get_outpost(params = {}, = {}) req = build_request(:get_outpost, params) req.send_request() end |
#get_outpost_instance_types(params = {}) ⇒ Types::GetOutpostInstanceTypesOutput
Gets the instance types for the specified Outpost.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
913 914 915 916 |
# File 'lib/aws-sdk-outposts/client.rb', line 913 def get_outpost_instance_types(params = {}, = {}) req = build_request(:get_outpost_instance_types, params) req.send_request() end |
#get_site(params = {}) ⇒ Types::GetSiteOutput
Gets information about the specified Outpost site.
960 961 962 963 |
# File 'lib/aws-sdk-outposts/client.rb', line 960 def get_site(params = {}, = {}) req = build_request(:get_site, params) req.send_request() end |
#get_site_address(params = {}) ⇒ Types::GetSiteAddressOutput
Gets the site address of the specified site.
1006 1007 1008 1009 |
# File 'lib/aws-sdk-outposts/client.rb', line 1006 def get_site_address(params = {}, = {}) req = build_request(:get_site_address, params) req.send_request() end |
#list_assets(params = {}) ⇒ Types::ListAssetsOutput
Lists the hardware assets for the specified Outpost.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1066 1067 1068 1069 |
# File 'lib/aws-sdk-outposts/client.rb', line 1066 def list_assets(params = {}, = {}) req = build_request(:list_assets, params) req.send_request() end |
#list_catalog_items(params = {}) ⇒ Types::ListCatalogItemsOutput
Lists the items in the catalog.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1132 1133 1134 1135 |
# File 'lib/aws-sdk-outposts/client.rb', line 1132 def list_catalog_items(params = {}, = {}) req = build_request(:list_catalog_items, params) req.send_request() end |
#list_orders(params = {}) ⇒ Types::ListOrdersOutput
Lists the Outpost orders for your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1180 1181 1182 1183 |
# File 'lib/aws-sdk-outposts/client.rb', line 1180 def list_orders(params = {}, = {}) req = build_request(:list_orders, params) req.send_request() end |
#list_outposts(params = {}) ⇒ Types::ListOutpostsOutput
Lists the Outposts for your Amazon Web Services account.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1247 1248 1249 1250 |
# File 'lib/aws-sdk-outposts/client.rb', line 1247 def list_outposts(params = {}, = {}) req = build_request(:list_outposts, params) req.send_request() end |
#list_sites(params = {}) ⇒ Types::ListSitesOutput
Lists the Outpost sites for your Amazon Web Services account. Use filters to return specific results.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1322 1323 1324 1325 |
# File 'lib/aws-sdk-outposts/client.rb', line 1322 def list_sites(params = {}, = {}) req = build_request(:list_sites, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
1351 1352 1353 1354 |
# File 'lib/aws-sdk-outposts/client.rb', line 1351 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#start_connection(params = {}) ⇒ Types::StartConnectionResponse
<note markdown=“1”> Amazon Web Services uses this action to install Outpost servers.
</note>
Starts the connection required for Outpost server installation.
Use CloudTrail to monitor this action or Amazon Web Services managed policy for Amazon Web Services Outposts to secure it. For more information, see [ Amazon Web Services managed policies for Amazon Web Services Outposts] and [ Logging Amazon Web Services Outposts API calls with Amazon Web Services CloudTrail] in the *Amazon Web Services Outposts User Guide*.
[1]: docs.aws.amazon.com/outposts/latest/userguide/security-iam-awsmanpol.html [2]: docs.aws.amazon.com/outposts/latest/userguide/logging-using-cloudtrail.html
1409 1410 1411 1412 |
# File 'lib/aws-sdk-outposts/client.rb', line 1409 def start_connection(params = {}, = {}) req = build_request(:start_connection, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
1437 1438 1439 1440 |
# File 'lib/aws-sdk-outposts/client.rb', line 1437 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
1463 1464 1465 1466 |
# File 'lib/aws-sdk-outposts/client.rb', line 1463 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_outpost(params = {}) ⇒ Types::UpdateOutpostOutput
Updates an Outpost.
1515 1516 1517 1518 |
# File 'lib/aws-sdk-outposts/client.rb', line 1515 def update_outpost(params = {}, = {}) req = build_request(:update_outpost, params) req.send_request() end |
#update_site(params = {}) ⇒ Types::UpdateSiteOutput
Updates the specified site.
1574 1575 1576 1577 |
# File 'lib/aws-sdk-outposts/client.rb', line 1574 def update_site(params = {}, = {}) req = build_request(:update_site, params) req.send_request() end |
#update_site_address(params = {}) ⇒ Types::UpdateSiteAddressOutput
Updates the address of the specified site.
You can’t update a site address if there is an order in progress. You must wait for the order to complete or cancel the order.
You can update the operating address before you place an order at the site, or after all Outposts that belong to the site have been deactivated.
1641 1642 1643 1644 |
# File 'lib/aws-sdk-outposts/client.rb', line 1641 def update_site_address(params = {}, = {}) req = build_request(:update_site_address, params) req.send_request() end |
#update_site_rack_physical_properties(params = {}) ⇒ Types::UpdateSiteRackPhysicalPropertiesOutput
Update the physical and logistical details for a rack at a site. For more information about hardware requirements for racks, see [Network readiness checklist] in the Amazon Web Services Outposts User Guide.
To update a rack at a site with an order of ‘IN_PROGRESS`, you must wait for the order to complete or cancel the order.
[1]: docs.aws.amazon.com/outposts/latest/userguide/outposts-requirements.html#checklist
1801 1802 1803 1804 |
# File 'lib/aws-sdk-outposts/client.rb', line 1801 def update_site_rack_physical_properties(params = {}, = {}) req = build_request(:update_site_rack_physical_properties, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1825 1826 1827 |
# File 'lib/aws-sdk-outposts/client.rb', line 1825 def waiter_names [] end |