Class: Aws::Outposts::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Outposts::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-outposts/client.rb
Overview
An API client for Outposts. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Outposts::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_order(params = {}) ⇒ Struct
Cancels the specified order for an Outpost.
-
#create_order(params = {}) ⇒ Types::CreateOrderOutput
Creates an order for an Outpost.
-
#create_outpost(params = {}) ⇒ Types::CreateOutpostOutput
Creates an Outpost.
-
#create_site(params = {}) ⇒ Types::CreateSiteOutput
Creates a site for an Outpost.
-
#delete_outpost(params = {}) ⇒ Struct
Deletes the specified Outpost.
-
#delete_site(params = {}) ⇒ Struct
Deletes the specified site.
-
#get_catalog_item(params = {}) ⇒ Types::GetCatalogItemOutput
Gets information about the specified catalog item.
-
#get_connection(params = {}) ⇒ Types::GetConnectionResponse
<note markdown=“1”> Amazon Web Services uses this action to install Outpost servers.
-
#get_order(params = {}) ⇒ Types::GetOrderOutput
Gets information about the specified order.
-
#get_outpost(params = {}) ⇒ Types::GetOutpostOutput
Gets information about the specified Outpost.
-
#get_outpost_instance_types(params = {}) ⇒ Types::GetOutpostInstanceTypesOutput
Gets the instance types for the specified Outpost.
-
#get_site(params = {}) ⇒ Types::GetSiteOutput
Gets information about the specified Outpost site.
-
#get_site_address(params = {}) ⇒ Types::GetSiteAddressOutput
Gets the site address of the specified site.
-
#list_assets(params = {}) ⇒ Types::ListAssetsOutput
Lists the hardware assets for the specified Outpost.
-
#list_catalog_items(params = {}) ⇒ Types::ListCatalogItemsOutput
Lists the items in the catalog.
-
#list_orders(params = {}) ⇒ Types::ListOrdersOutput
Lists the Outpost orders for your Amazon Web Services account.
-
#list_outposts(params = {}) ⇒ Types::ListOutpostsOutput
Lists the Outposts for your Amazon Web Services account.
-
#list_sites(params = {}) ⇒ Types::ListSitesOutput
Lists the Outpost sites for your Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#start_connection(params = {}) ⇒ Types::StartConnectionResponse
<note markdown=“1”> Amazon Web Services uses this action to install Outpost servers.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
-
#update_outpost(params = {}) ⇒ Types::UpdateOutpostOutput
Updates an Outpost.
-
#update_site(params = {}) ⇒ Types::UpdateSiteOutput
Updates the specified site.
-
#update_site_address(params = {}) ⇒ Types::UpdateSiteAddressOutput
Updates the address of the specified site.
-
#update_site_rack_physical_properties(params = {}) ⇒ Types::UpdateSiteRackPhysicalPropertiesOutput
Update the physical and logistical details for a rack at a site.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
365 366 367 |
# File 'lib/aws-sdk-outposts/client.rb', line 365 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1821 1822 1823 |
# File 'lib/aws-sdk-outposts/client.rb', line 1821 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1824 1825 1826 |
# File 'lib/aws-sdk-outposts/client.rb', line 1824 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 |
# File 'lib/aws-sdk-outposts/client.rb', line 1799 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-outposts' context[:gem_version] = '1.41.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_order(params = {}) ⇒ Struct
Cancels the specified order for an Outpost.
388 389 390 391 |
# File 'lib/aws-sdk-outposts/client.rb', line 388 def cancel_order(params = {}, = {}) req = build_request(:cancel_order, params) req.send_request() end |
#create_order(params = {}) ⇒ Types::CreateOrderOutput
Creates an order for an Outpost.
450 451 452 453 |
# File 'lib/aws-sdk-outposts/client.rb', line 450 def create_order(params = {}, = {}) req = build_request(:create_order, params) req.send_request() end |
#create_outpost(params = {}) ⇒ Types::CreateOutpostOutput
Creates an Outpost.
You can specify either an Availability one or an AZ ID.
518 519 520 521 |
# File 'lib/aws-sdk-outposts/client.rb', line 518 def create_outpost(params = {}, = {}) req = build_request(:create_outpost, params) req.send_request() end |
#create_site(params = {}) ⇒ Types::CreateSiteOutput
Creates a site for an Outpost.
637 638 639 640 |
# File 'lib/aws-sdk-outposts/client.rb', line 637 def create_site(params = {}, = {}) req = build_request(:create_site, params) req.send_request() end |
#delete_outpost(params = {}) ⇒ Struct
Deletes the specified Outpost.
659 660 661 662 |
# File 'lib/aws-sdk-outposts/client.rb', line 659 def delete_outpost(params = {}, = {}) req = build_request(:delete_outpost, params) req.send_request() end |
#delete_site(params = {}) ⇒ Struct
Deletes the specified site.
681 682 683 684 |
# File 'lib/aws-sdk-outposts/client.rb', line 681 def delete_site(params = {}, = {}) req = build_request(:delete_site, params) req.send_request() end |
#get_catalog_item(params = {}) ⇒ Types::GetCatalogItemOutput
Gets information about the specified catalog item.
720 721 722 723 |
# File 'lib/aws-sdk-outposts/client.rb', line 720 def get_catalog_item(params = {}, = {}) req = build_request(:get_catalog_item, params) req.send_request() end |
#get_connection(params = {}) ⇒ Types::GetConnectionResponse
<note markdown=“1”> Amazon Web Services uses this action to install Outpost servers.
</note>
Gets information about the specified connection.
Use CloudTrail to monitor this action or Amazon Web Services managed policy for Amazon Web Services Outposts to secure it. For more information, see [ Amazon Web Services managed policies for Amazon Web Services Outposts] and [ Logging Amazon Web Services Outposts API calls with Amazon Web Services CloudTrail] in the *Amazon Web Services Outposts User Guide*.
[1]: docs.aws.amazon.com/outposts/latest/userguide/security-iam-awsmanpol.html [2]: docs.aws.amazon.com/outposts/latest/userguide/logging-using-cloudtrail.html
772 773 774 775 |
# File 'lib/aws-sdk-outposts/client.rb', line 772 def get_connection(params = {}, = {}) req = build_request(:get_connection, params) req.send_request() end |
#get_order(params = {}) ⇒ Types::GetOrderOutput
Gets information about the specified order.
817 818 819 820 |
# File 'lib/aws-sdk-outposts/client.rb', line 817 def get_order(params = {}, = {}) req = build_request(:get_order, params) req.send_request() end |
#get_outpost(params = {}) ⇒ Types::GetOutpostOutput
Gets information about the specified Outpost.
857 858 859 860 |
# File 'lib/aws-sdk-outposts/client.rb', line 857 def get_outpost(params = {}, = {}) req = build_request(:get_outpost, params) req.send_request() end |
#get_outpost_instance_types(params = {}) ⇒ Types::GetOutpostInstanceTypesOutput
Gets the instance types for the specified Outpost.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
902 903 904 905 |
# File 'lib/aws-sdk-outposts/client.rb', line 902 def get_outpost_instance_types(params = {}, = {}) req = build_request(:get_outpost_instance_types, params) req.send_request() end |
#get_site(params = {}) ⇒ Types::GetSiteOutput
Gets information about the specified Outpost site.
949 950 951 952 |
# File 'lib/aws-sdk-outposts/client.rb', line 949 def get_site(params = {}, = {}) req = build_request(:get_site, params) req.send_request() end |
#get_site_address(params = {}) ⇒ Types::GetSiteAddressOutput
Gets the site address of the specified site.
995 996 997 998 |
# File 'lib/aws-sdk-outposts/client.rb', line 995 def get_site_address(params = {}, = {}) req = build_request(:get_site_address, params) req.send_request() end |
#list_assets(params = {}) ⇒ Types::ListAssetsOutput
Lists the hardware assets for the specified Outpost.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1055 1056 1057 1058 |
# File 'lib/aws-sdk-outposts/client.rb', line 1055 def list_assets(params = {}, = {}) req = build_request(:list_assets, params) req.send_request() end |
#list_catalog_items(params = {}) ⇒ Types::ListCatalogItemsOutput
Lists the items in the catalog.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1121 1122 1123 1124 |
# File 'lib/aws-sdk-outposts/client.rb', line 1121 def list_catalog_items(params = {}, = {}) req = build_request(:list_catalog_items, params) req.send_request() end |
#list_orders(params = {}) ⇒ Types::ListOrdersOutput
Lists the Outpost orders for your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1169 1170 1171 1172 |
# File 'lib/aws-sdk-outposts/client.rb', line 1169 def list_orders(params = {}, = {}) req = build_request(:list_orders, params) req.send_request() end |
#list_outposts(params = {}) ⇒ Types::ListOutpostsOutput
Lists the Outposts for your Amazon Web Services account.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1236 1237 1238 1239 |
# File 'lib/aws-sdk-outposts/client.rb', line 1236 def list_outposts(params = {}, = {}) req = build_request(:list_outposts, params) req.send_request() end |
#list_sites(params = {}) ⇒ Types::ListSitesOutput
Lists the Outpost sites for your Amazon Web Services account. Use filters to return specific results.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1311 1312 1313 1314 |
# File 'lib/aws-sdk-outposts/client.rb', line 1311 def list_sites(params = {}, = {}) req = build_request(:list_sites, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
1340 1341 1342 1343 |
# File 'lib/aws-sdk-outposts/client.rb', line 1340 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#start_connection(params = {}) ⇒ Types::StartConnectionResponse
<note markdown=“1”> Amazon Web Services uses this action to install Outpost servers.
</note>
Starts the connection required for Outpost server installation.
Use CloudTrail to monitor this action or Amazon Web Services managed policy for Amazon Web Services Outposts to secure it. For more information, see [ Amazon Web Services managed policies for Amazon Web Services Outposts] and [ Logging Amazon Web Services Outposts API calls with Amazon Web Services CloudTrail] in the *Amazon Web Services Outposts User Guide*.
[1]: docs.aws.amazon.com/outposts/latest/userguide/security-iam-awsmanpol.html [2]: docs.aws.amazon.com/outposts/latest/userguide/logging-using-cloudtrail.html
1398 1399 1400 1401 |
# File 'lib/aws-sdk-outposts/client.rb', line 1398 def start_connection(params = {}, = {}) req = build_request(:start_connection, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
1426 1427 1428 1429 |
# File 'lib/aws-sdk-outposts/client.rb', line 1426 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
1452 1453 1454 1455 |
# File 'lib/aws-sdk-outposts/client.rb', line 1452 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_outpost(params = {}) ⇒ Types::UpdateOutpostOutput
Updates an Outpost.
1504 1505 1506 1507 |
# File 'lib/aws-sdk-outposts/client.rb', line 1504 def update_outpost(params = {}, = {}) req = build_request(:update_outpost, params) req.send_request() end |
#update_site(params = {}) ⇒ Types::UpdateSiteOutput
Updates the specified site.
1563 1564 1565 1566 |
# File 'lib/aws-sdk-outposts/client.rb', line 1563 def update_site(params = {}, = {}) req = build_request(:update_site, params) req.send_request() end |
#update_site_address(params = {}) ⇒ Types::UpdateSiteAddressOutput
Updates the address of the specified site.
You can’t update a site address if there is an order in progress. You must wait for the order to complete or cancel the order.
You can update the operating address before you place an order at the site, or after all Outposts that belong to the site have been deactivated.
1630 1631 1632 1633 |
# File 'lib/aws-sdk-outposts/client.rb', line 1630 def update_site_address(params = {}, = {}) req = build_request(:update_site_address, params) req.send_request() end |
#update_site_rack_physical_properties(params = {}) ⇒ Types::UpdateSiteRackPhysicalPropertiesOutput
Update the physical and logistical details for a rack at a site. For more information about hardware requirements for racks, see [Network readiness checklist] in the Amazon Web Services Outposts User Guide.
To update a rack at a site with an order of ‘IN_PROGRESS`, you must wait for the order to complete or cancel the order.
[1]: docs.aws.amazon.com/outposts/latest/userguide/outposts-requirements.html#checklist
1790 1791 1792 1793 |
# File 'lib/aws-sdk-outposts/client.rb', line 1790 def update_site_rack_physical_properties(params = {}, = {}) req = build_request(:update_site_rack_physical_properties, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1814 1815 1816 |
# File 'lib/aws-sdk-outposts/client.rb', line 1814 def waiter_names [] end |