Class: Aws::Outposts::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Outposts::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-outposts/client.rb
Overview
An API client for Outposts. To construct a client, you need to configure a `:region` and `:credentials`.
client = Aws::Outposts::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_order(params = {}) ⇒ Struct
Cancels the specified order for an Outpost.
-
#create_order(params = {}) ⇒ Types::CreateOrderOutput
Creates an order for an Outpost.
-
#create_outpost(params = {}) ⇒ Types::CreateOutpostOutput
Creates an Outpost.
-
#create_site(params = {}) ⇒ Types::CreateSiteOutput
Creates a site for an Outpost.
-
#delete_outpost(params = {}) ⇒ Struct
Deletes the specified Outpost.
-
#delete_site(params = {}) ⇒ Struct
Deletes the specified site.
-
#get_catalog_item(params = {}) ⇒ Types::GetCatalogItemOutput
Gets information about the specified catalog item.
-
#get_connection(params = {}) ⇒ Types::GetConnectionResponse
<note markdown=“1”> Amazon Web Services uses this action to install Outpost servers.
-
#get_order(params = {}) ⇒ Types::GetOrderOutput
Gets information about the specified order.
-
#get_outpost(params = {}) ⇒ Types::GetOutpostOutput
Gets information about the specified Outpost.
-
#get_outpost_instance_types(params = {}) ⇒ Types::GetOutpostInstanceTypesOutput
Gets the instance types for the specified Outpost.
-
#get_site(params = {}) ⇒ Types::GetSiteOutput
Gets information about the specified Outpost site.
-
#get_site_address(params = {}) ⇒ Types::GetSiteAddressOutput
Gets the site address of the specified site.
-
#list_assets(params = {}) ⇒ Types::ListAssetsOutput
Lists the hardware assets for the specified Outpost.
-
#list_catalog_items(params = {}) ⇒ Types::ListCatalogItemsOutput
Lists the items in the catalog.
-
#list_orders(params = {}) ⇒ Types::ListOrdersOutput
Lists the Outpost orders for your Amazon Web Services account.
-
#list_outposts(params = {}) ⇒ Types::ListOutpostsOutput
Lists the Outposts for your Amazon Web Services account.
-
#list_sites(params = {}) ⇒ Types::ListSitesOutput
Lists the Outpost sites for your Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#start_connection(params = {}) ⇒ Types::StartConnectionResponse
<note markdown=“1”> Amazon Web Services uses this action to install Outpost servers.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
-
#update_outpost(params = {}) ⇒ Types::UpdateOutpostOutput
Updates an Outpost.
-
#update_site(params = {}) ⇒ Types::UpdateSiteOutput
Updates the specified site.
-
#update_site_address(params = {}) ⇒ Types::UpdateSiteAddressOutput
Updates the address of the specified site.
-
#update_site_rack_physical_properties(params = {}) ⇒ Types::UpdateSiteRackPhysicalPropertiesOutput
Update the physical and logistical details for a rack at a site.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
348 349 350 |
# File 'lib/aws-sdk-outposts/client.rb', line 348 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1802 1803 1804 |
# File 'lib/aws-sdk-outposts/client.rb', line 1802 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1805 1806 1807 |
# File 'lib/aws-sdk-outposts/client.rb', line 1805 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 |
# File 'lib/aws-sdk-outposts/client.rb', line 1780 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-outposts' context[:gem_version] = '1.36.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_order(params = {}) ⇒ Struct
Cancels the specified order for an Outpost.
371 372 373 374 |
# File 'lib/aws-sdk-outposts/client.rb', line 371 def cancel_order(params = {}, = {}) req = build_request(:cancel_order, params) req.send_request() end |
#create_order(params = {}) ⇒ Types::CreateOrderOutput
Creates an order for an Outpost.
432 433 434 435 |
# File 'lib/aws-sdk-outposts/client.rb', line 432 def create_order(params = {}, = {}) req = build_request(:create_order, params) req.send_request() end |
#create_outpost(params = {}) ⇒ Types::CreateOutpostOutput
Creates an Outpost.
You can specify either an Availability one or an AZ ID.
500 501 502 503 |
# File 'lib/aws-sdk-outposts/client.rb', line 500 def create_outpost(params = {}, = {}) req = build_request(:create_outpost, params) req.send_request() end |
#create_site(params = {}) ⇒ Types::CreateSiteOutput
Creates a site for an Outpost.
619 620 621 622 |
# File 'lib/aws-sdk-outposts/client.rb', line 619 def create_site(params = {}, = {}) req = build_request(:create_site, params) req.send_request() end |
#delete_outpost(params = {}) ⇒ Struct
Deletes the specified Outpost.
641 642 643 644 |
# File 'lib/aws-sdk-outposts/client.rb', line 641 def delete_outpost(params = {}, = {}) req = build_request(:delete_outpost, params) req.send_request() end |
#delete_site(params = {}) ⇒ Struct
Deletes the specified site.
663 664 665 666 |
# File 'lib/aws-sdk-outposts/client.rb', line 663 def delete_site(params = {}, = {}) req = build_request(:delete_site, params) req.send_request() end |
#get_catalog_item(params = {}) ⇒ Types::GetCatalogItemOutput
Gets information about the specified catalog item.
702 703 704 705 |
# File 'lib/aws-sdk-outposts/client.rb', line 702 def get_catalog_item(params = {}, = {}) req = build_request(:get_catalog_item, params) req.send_request() end |
#get_connection(params = {}) ⇒ Types::GetConnectionResponse
<note markdown=“1”> Amazon Web Services uses this action to install Outpost servers.
</note>
Gets information about the specified connection.
Use CloudTrail to monitor this action or Amazon Web Services managed policy for Amazon Web Services Outposts to secure it. For more information, see [ Amazon Web Services managed policies for Amazon Web Services Outposts] and [ Logging Amazon Web Services Outposts API calls with Amazon Web Services CloudTrail] in the *Amazon Web Services Outposts User Guide*.
[1]: docs.aws.amazon.com/outposts/latest/userguide/security-iam-awsmanpol.html [2]: docs.aws.amazon.com/outposts/latest/userguide/logging-using-cloudtrail.html
754 755 756 757 |
# File 'lib/aws-sdk-outposts/client.rb', line 754 def get_connection(params = {}, = {}) req = build_request(:get_connection, params) req.send_request() end |
#get_order(params = {}) ⇒ Types::GetOrderOutput
Gets information about the specified order.
798 799 800 801 |
# File 'lib/aws-sdk-outposts/client.rb', line 798 def get_order(params = {}, = {}) req = build_request(:get_order, params) req.send_request() end |
#get_outpost(params = {}) ⇒ Types::GetOutpostOutput
Gets information about the specified Outpost.
838 839 840 841 |
# File 'lib/aws-sdk-outposts/client.rb', line 838 def get_outpost(params = {}, = {}) req = build_request(:get_outpost, params) req.send_request() end |
#get_outpost_instance_types(params = {}) ⇒ Types::GetOutpostInstanceTypesOutput
Gets the instance types for the specified Outpost.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
883 884 885 886 |
# File 'lib/aws-sdk-outposts/client.rb', line 883 def get_outpost_instance_types(params = {}, = {}) req = build_request(:get_outpost_instance_types, params) req.send_request() end |
#get_site(params = {}) ⇒ Types::GetSiteOutput
Gets information about the specified Outpost site.
930 931 932 933 |
# File 'lib/aws-sdk-outposts/client.rb', line 930 def get_site(params = {}, = {}) req = build_request(:get_site, params) req.send_request() end |
#get_site_address(params = {}) ⇒ Types::GetSiteAddressOutput
Gets the site address of the specified site.
976 977 978 979 |
# File 'lib/aws-sdk-outposts/client.rb', line 976 def get_site_address(params = {}, = {}) req = build_request(:get_site_address, params) req.send_request() end |
#list_assets(params = {}) ⇒ Types::ListAssetsOutput
Lists the hardware assets for the specified Outpost.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1036 1037 1038 1039 |
# File 'lib/aws-sdk-outposts/client.rb', line 1036 def list_assets(params = {}, = {}) req = build_request(:list_assets, params) req.send_request() end |
#list_catalog_items(params = {}) ⇒ Types::ListCatalogItemsOutput
Lists the items in the catalog.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1102 1103 1104 1105 |
# File 'lib/aws-sdk-outposts/client.rb', line 1102 def list_catalog_items(params = {}, = {}) req = build_request(:list_catalog_items, params) req.send_request() end |
#list_orders(params = {}) ⇒ Types::ListOrdersOutput
Lists the Outpost orders for your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1150 1151 1152 1153 |
# File 'lib/aws-sdk-outposts/client.rb', line 1150 def list_orders(params = {}, = {}) req = build_request(:list_orders, params) req.send_request() end |
#list_outposts(params = {}) ⇒ Types::ListOutpostsOutput
Lists the Outposts for your Amazon Web Services account.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1217 1218 1219 1220 |
# File 'lib/aws-sdk-outposts/client.rb', line 1217 def list_outposts(params = {}, = {}) req = build_request(:list_outposts, params) req.send_request() end |
#list_sites(params = {}) ⇒ Types::ListSitesOutput
Lists the Outpost sites for your Amazon Web Services account. Use filters to return specific results.
Use filters to return specific results. If you specify multiple filters, the results include only the resources that match all of the specified filters. For a filter where you can specify multiple values, the results include items that match any of the values that you specify for the filter.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1292 1293 1294 1295 |
# File 'lib/aws-sdk-outposts/client.rb', line 1292 def list_sites(params = {}, = {}) req = build_request(:list_sites, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
1321 1322 1323 1324 |
# File 'lib/aws-sdk-outposts/client.rb', line 1321 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#start_connection(params = {}) ⇒ Types::StartConnectionResponse
<note markdown=“1”> Amazon Web Services uses this action to install Outpost servers.
</note>
Starts the connection required for Outpost server installation.
Use CloudTrail to monitor this action or Amazon Web Services managed policy for Amazon Web Services Outposts to secure it. For more information, see [ Amazon Web Services managed policies for Amazon Web Services Outposts] and [ Logging Amazon Web Services Outposts API calls with Amazon Web Services CloudTrail] in the *Amazon Web Services Outposts User Guide*.
[1]: docs.aws.amazon.com/outposts/latest/userguide/security-iam-awsmanpol.html [2]: docs.aws.amazon.com/outposts/latest/userguide/logging-using-cloudtrail.html
1379 1380 1381 1382 |
# File 'lib/aws-sdk-outposts/client.rb', line 1379 def start_connection(params = {}, = {}) req = build_request(:start_connection, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
1407 1408 1409 1410 |
# File 'lib/aws-sdk-outposts/client.rb', line 1407 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
1433 1434 1435 1436 |
# File 'lib/aws-sdk-outposts/client.rb', line 1433 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_outpost(params = {}) ⇒ Types::UpdateOutpostOutput
Updates an Outpost.
1485 1486 1487 1488 |
# File 'lib/aws-sdk-outposts/client.rb', line 1485 def update_outpost(params = {}, = {}) req = build_request(:update_outpost, params) req.send_request() end |
#update_site(params = {}) ⇒ Types::UpdateSiteOutput
Updates the specified site.
1544 1545 1546 1547 |
# File 'lib/aws-sdk-outposts/client.rb', line 1544 def update_site(params = {}, = {}) req = build_request(:update_site, params) req.send_request() end |
#update_site_address(params = {}) ⇒ Types::UpdateSiteAddressOutput
Updates the address of the specified site.
You can't update a site address if there is an order in progress. You must wait for the order to complete or cancel the order.
You can update the operating address before you place an order at the site, or after all Outposts that belong to the site have been deactivated.
1611 1612 1613 1614 |
# File 'lib/aws-sdk-outposts/client.rb', line 1611 def update_site_address(params = {}, = {}) req = build_request(:update_site_address, params) req.send_request() end |
#update_site_rack_physical_properties(params = {}) ⇒ Types::UpdateSiteRackPhysicalPropertiesOutput
Update the physical and logistical details for a rack at a site. For more information about hardware requirements for racks, see [Network readiness checklist] in the Amazon Web Services Outposts User Guide.
To update a rack at a site with an order of `IN_PROGRESS`, you must wait for the order to complete or cancel the order.
[1]: docs.aws.amazon.com/outposts/latest/userguide/outposts-requirements.html#checklist
1771 1772 1773 1774 |
# File 'lib/aws-sdk-outposts/client.rb', line 1771 def update_site_rack_physical_properties(params = {}, = {}) req = build_request(:update_site_rack_physical_properties, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1795 1796 1797 |
# File 'lib/aws-sdk-outposts/client.rb', line 1795 def waiter_names [] end |