Class: Aws::Outposts::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Outposts::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-outposts/client.rb
Overview
An API client for Outposts. To construct a client, you need to configure a `:region` and `:credentials`.
client = Aws::Outposts::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_order(params = {}) ⇒ Struct
Cancels an order for an Outpost.
-
#create_order(params = {}) ⇒ Types::CreateOrderOutput
Creates an order for an Outpost.
-
#create_outpost(params = {}) ⇒ Types::CreateOutpostOutput
Creates an Outpost.
-
#create_site(params = {}) ⇒ Types::CreateSiteOutput
Creates a site for an Outpost.
-
#delete_outpost(params = {}) ⇒ Struct
Deletes the Outpost.
-
#delete_site(params = {}) ⇒ Struct
Deletes the site.
-
#get_catalog_item(params = {}) ⇒ Types::GetCatalogItemOutput
Gets information about a catalog item.
-
#get_order(params = {}) ⇒ Types::GetOrderOutput
Gets an order.
-
#get_outpost(params = {}) ⇒ Types::GetOutpostOutput
Gets information about the specified Outpost.
-
#get_outpost_instance_types(params = {}) ⇒ Types::GetOutpostInstanceTypesOutput
Gets the instance types for the specified Outpost.
-
#get_site(params = {}) ⇒ Types::GetSiteOutput
Gets information about the specified Outpost site.
-
#get_site_address(params = {}) ⇒ Types::GetSiteAddressOutput
Gets the site address.
-
#list_assets(params = {}) ⇒ Types::ListAssetsOutput
Lists the hardware assets in an Outpost.
-
#list_catalog_items(params = {}) ⇒ Types::ListCatalogItemsOutput
Lists the items in the catalog.
-
#list_orders(params = {}) ⇒ Types::ListOrdersOutput
Lists the Outpost orders for your Amazon Web Services account.
-
#list_outposts(params = {}) ⇒ Types::ListOutpostsOutput
Lists the Outposts for your Amazon Web Services account.
-
#list_sites(params = {}) ⇒ Types::ListSitesOutput
Lists the Outpost sites for your Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
-
#update_outpost(params = {}) ⇒ Types::UpdateOutpostOutput
Updates an Outpost.
-
#update_site(params = {}) ⇒ Types::UpdateSiteOutput
Updates the site.
-
#update_site_address(params = {}) ⇒ Types::UpdateSiteAddressOutput
Updates the site address.
-
#update_site_rack_physical_properties(params = {}) ⇒ Types::UpdateSiteRackPhysicalPropertiesOutput
Update the physical and logistical details for a rack at a site.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
348 349 350 |
# File 'lib/aws-sdk-outposts/client.rb', line 348 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1802 1803 1804 |
# File 'lib/aws-sdk-outposts/client.rb', line 1802 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1805 1806 1807 |
# File 'lib/aws-sdk-outposts/client.rb', line 1805 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1780 1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 |
# File 'lib/aws-sdk-outposts/client.rb', line 1780 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-outposts' context[:gem_version] = '1.32.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_order(params = {}) ⇒ Struct
Cancels an order for an Outpost.
371 372 373 374 |
# File 'lib/aws-sdk-outposts/client.rb', line 371 def cancel_order(params = {}, = {}) req = build_request(:cancel_order, params) req.send_request() end |
#create_order(params = {}) ⇒ Types::CreateOrderOutput
Creates an order for an Outpost.
426 427 428 429 |
# File 'lib/aws-sdk-outposts/client.rb', line 426 def create_order(params = {}, = {}) req = build_request(:create_order, params) req.send_request() end |
#create_outpost(params = {}) ⇒ Types::CreateOutpostOutput
Creates an Outpost.
You can specify `AvailabilityZone` or `AvailabilityZoneId`.
502 503 504 505 |
# File 'lib/aws-sdk-outposts/client.rb', line 502 def create_outpost(params = {}, = {}) req = build_request(:create_outpost, params) req.send_request() end |
#create_site(params = {}) ⇒ Types::CreateSiteOutput
Creates a site for an Outpost.
621 622 623 624 |
# File 'lib/aws-sdk-outposts/client.rb', line 621 def create_site(params = {}, = {}) req = build_request(:create_site, params) req.send_request() end |
#delete_outpost(params = {}) ⇒ Struct
Deletes the Outpost.
651 652 653 654 |
# File 'lib/aws-sdk-outposts/client.rb', line 651 def delete_outpost(params = {}, = {}) req = build_request(:delete_outpost, params) req.send_request() end |
#delete_site(params = {}) ⇒ Struct
Deletes the site.
681 682 683 684 |
# File 'lib/aws-sdk-outposts/client.rb', line 681 def delete_site(params = {}, = {}) req = build_request(:delete_site, params) req.send_request() end |
#get_catalog_item(params = {}) ⇒ Types::GetCatalogItemOutput
Gets information about a catalog item.
720 721 722 723 |
# File 'lib/aws-sdk-outposts/client.rb', line 720 def get_catalog_item(params = {}, = {}) req = build_request(:get_catalog_item, params) req.send_request() end |
#get_order(params = {}) ⇒ Types::GetOrderOutput
Gets an order.
758 759 760 761 |
# File 'lib/aws-sdk-outposts/client.rb', line 758 def get_order(params = {}, = {}) req = build_request(:get_order, params) req.send_request() end |
#get_outpost(params = {}) ⇒ Types::GetOutpostOutput
Gets information about the specified Outpost.
806 807 808 809 |
# File 'lib/aws-sdk-outposts/client.rb', line 806 def get_outpost(params = {}, = {}) req = build_request(:get_outpost, params) req.send_request() end |
#get_outpost_instance_types(params = {}) ⇒ Types::GetOutpostInstanceTypesOutput
Gets the instance types for the specified Outpost.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
859 860 861 862 |
# File 'lib/aws-sdk-outposts/client.rb', line 859 def get_outpost_instance_types(params = {}, = {}) req = build_request(:get_outpost_instance_types, params) req.send_request() end |
#get_site(params = {}) ⇒ Types::GetSiteOutput
Gets information about the specified Outpost site.
914 915 916 917 |
# File 'lib/aws-sdk-outposts/client.rb', line 914 def get_site(params = {}, = {}) req = build_request(:get_site, params) req.send_request() end |
#get_site_address(params = {}) ⇒ Types::GetSiteAddressOutput
Gets the site address.
968 969 970 971 |
# File 'lib/aws-sdk-outposts/client.rb', line 968 def get_site_address(params = {}, = {}) req = build_request(:get_site_address, params) req.send_request() end |
#list_assets(params = {}) ⇒ Types::ListAssetsOutput
Lists the hardware assets in an Outpost. If you are using Dedicated Hosts on Amazon Web Services Outposts, you can filter your request by host ID to return a list of hardware assets that allocate resources for Dedicated Hosts.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1023 1024 1025 1026 |
# File 'lib/aws-sdk-outposts/client.rb', line 1023 def list_assets(params = {}, = {}) req = build_request(:list_assets, params) req.send_request() end |
#list_catalog_items(params = {}) ⇒ Types::ListCatalogItemsOutput
Lists the items in the catalog. Add filters to your request to return a more specific list of results. Use filters to match an item class, storage option, or EC2 family.
If you specify multiple filters, the filters are joined with an `AND`, and the request returns only results that match all of the specified filters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1101 1102 1103 1104 |
# File 'lib/aws-sdk-outposts/client.rb', line 1101 def list_catalog_items(params = {}, = {}) req = build_request(:list_catalog_items, params) req.send_request() end |
#list_orders(params = {}) ⇒ Types::ListOrdersOutput
Lists the Outpost orders for your Amazon Web Services account. You can filter your request by Outpost to return a more specific list of results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1151 1152 1153 1154 |
# File 'lib/aws-sdk-outposts/client.rb', line 1151 def list_orders(params = {}, = {}) req = build_request(:list_orders, params) req.send_request() end |
#list_outposts(params = {}) ⇒ Types::ListOutpostsOutput
Lists the Outposts for your Amazon Web Services account. Add filters to your request to return a more specific list of results. Use filters to match an Outpost lifecycle status, Availability Zone (`us-east-1a`), and AZ ID (`use1-az1`).
If you specify multiple filters, the filters are joined with an `AND`, and the request returns only results that match all of the specified filters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1231 1232 1233 1234 |
# File 'lib/aws-sdk-outposts/client.rb', line 1231 def list_outposts(params = {}, = {}) req = build_request(:list_outposts, params) req.send_request() end |
#list_sites(params = {}) ⇒ Types::ListSitesOutput
Lists the Outpost sites for your Amazon Web Services account. Add operating address filters to your request to return a more specific list of results. Use filters to match site city, country code, or state/region of the operating address.
If you specify multiple filters, the filters are joined with an `AND`, and the request returns only results that match all of the specified filters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1318 1319 1320 1321 |
# File 'lib/aws-sdk-outposts/client.rb', line 1318 def list_sites(params = {}, = {}) req = build_request(:list_sites, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
1347 1348 1349 1350 |
# File 'lib/aws-sdk-outposts/client.rb', line 1347 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
1375 1376 1377 1378 |
# File 'lib/aws-sdk-outposts/client.rb', line 1375 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
1401 1402 1403 1404 |
# File 'lib/aws-sdk-outposts/client.rb', line 1401 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_outpost(params = {}) ⇒ Types::UpdateOutpostOutput
Updates an Outpost.
1461 1462 1463 1464 |
# File 'lib/aws-sdk-outposts/client.rb', line 1461 def update_outpost(params = {}, = {}) req = build_request(:update_outpost, params) req.send_request() end |
#update_site(params = {}) ⇒ Types::UpdateSiteOutput
Updates the site.
1528 1529 1530 1531 |
# File 'lib/aws-sdk-outposts/client.rb', line 1528 def update_site(params = {}, = {}) req = build_request(:update_site, params) req.send_request() end |
#update_site_address(params = {}) ⇒ Types::UpdateSiteAddressOutput
Updates the site address.
To update a site address with an order `IN_PROGRESS`, you must wait for the order to complete or cancel the order.
You can update the operating address before you place an order at the site, or after all Outposts that belong to the site have been deactivated.
1603 1604 1605 1606 |
# File 'lib/aws-sdk-outposts/client.rb', line 1603 def update_site_address(params = {}, = {}) req = build_request(:update_site_address, params) req.send_request() end |
#update_site_rack_physical_properties(params = {}) ⇒ Types::UpdateSiteRackPhysicalPropertiesOutput
Update the physical and logistical details for a rack at a site. For more information about hardware requirements for racks, see [Network readiness checklist] in the Amazon Web Services Outposts User Guide.
To update a rack at a site with an order of `IN_PROGRESS`, you must wait for the order to complete or cancel the order.
[1]: docs.aws.amazon.com/outposts/latest/userguide/outposts-requirements.html#checklist
1771 1772 1773 1774 |
# File 'lib/aws-sdk-outposts/client.rb', line 1771 def update_site_rack_physical_properties(params = {}, = {}) req = build_request(:update_site_rack_physical_properties, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1795 1796 1797 |
# File 'lib/aws-sdk-outposts/client.rb', line 1795 def waiter_names [] end |