Class: Aws::Outposts::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Outposts::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-outposts/client.rb
Overview
An API client for Outposts. To construct a client, you need to configure a `:region` and `:credentials`.
client = Aws::Outposts::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_order(params = {}) ⇒ Struct
Cancels an order for an Outpost.
-
#create_order(params = {}) ⇒ Types::CreateOrderOutput
Creates an order for an Outpost.
-
#create_outpost(params = {}) ⇒ Types::CreateOutpostOutput
Creates an Outpost.
-
#create_site(params = {}) ⇒ Types::CreateSiteOutput
Creates a site for an Outpost.
-
#delete_outpost(params = {}) ⇒ Struct
Deletes the Outpost.
-
#delete_site(params = {}) ⇒ Struct
Deletes the site.
-
#get_catalog_item(params = {}) ⇒ Types::GetCatalogItemOutput
Gets information about a catalog item.
-
#get_order(params = {}) ⇒ Types::GetOrderOutput
Gets an order.
-
#get_outpost(params = {}) ⇒ Types::GetOutpostOutput
Gets information about the specified Outpost.
-
#get_outpost_instance_types(params = {}) ⇒ Types::GetOutpostInstanceTypesOutput
Lists the instance types for the specified Outpost.
-
#get_site(params = {}) ⇒ Types::GetSiteOutput
Gets information about the specified Outpost site.
-
#get_site_address(params = {}) ⇒ Types::GetSiteAddressOutput
Gets the site address.
-
#list_catalog_items(params = {}) ⇒ Types::ListCatalogItemsOutput
Use to create a list of every item in the catalog.
-
#list_orders(params = {}) ⇒ Types::ListOrdersOutput
Create a list of the Outpost orders for your Amazon Web Services account.
-
#list_outposts(params = {}) ⇒ Types::ListOutpostsOutput
Create a list of the Outposts for your Amazon Web Services account.
-
#list_sites(params = {}) ⇒ Types::ListSitesOutput
Lists the sites for your Amazon Web Services account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
-
#update_outpost(params = {}) ⇒ Types::UpdateOutpostOutput
Updates an Outpost.
-
#update_site(params = {}) ⇒ Types::UpdateSiteOutput
Updates the site.
-
#update_site_address(params = {}) ⇒ Types::UpdateSiteAddressOutput
Updates the site address.
-
#update_site_rack_physical_properties(params = {}) ⇒ Types::UpdateSiteRackPhysicalPropertiesOutput
Update the physical and logistical details for a rack at a site.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
346 347 348 |
# File 'lib/aws-sdk-outposts/client.rb', line 346 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1624 1625 1626 |
# File 'lib/aws-sdk-outposts/client.rb', line 1624 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1627 1628 1629 |
# File 'lib/aws-sdk-outposts/client.rb', line 1627 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1602 1603 1604 1605 1606 1607 1608 1609 1610 1611 1612 1613 |
# File 'lib/aws-sdk-outposts/client.rb', line 1602 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-outposts' context[:gem_version] = '1.28.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_order(params = {}) ⇒ Struct
Cancels an order for an Outpost.
369 370 371 372 |
# File 'lib/aws-sdk-outposts/client.rb', line 369 def cancel_order(params = {}, = {}) req = build_request(:cancel_order, params) req.send_request() end |
#create_order(params = {}) ⇒ Types::CreateOrderOutput
Creates an order for an Outpost.
424 425 426 427 |
# File 'lib/aws-sdk-outposts/client.rb', line 424 def create_order(params = {}, = {}) req = build_request(:create_order, params) req.send_request() end |
#create_outpost(params = {}) ⇒ Types::CreateOutpostOutput
Creates an Outpost.
You can specify `AvailabilityZone` or `AvailabilityZoneId`.
492 493 494 495 |
# File 'lib/aws-sdk-outposts/client.rb', line 492 def create_outpost(params = {}, = {}) req = build_request(:create_outpost, params) req.send_request() end |
#create_site(params = {}) ⇒ Types::CreateSiteOutput
Creates a site for an Outpost.
611 612 613 614 |
# File 'lib/aws-sdk-outposts/client.rb', line 611 def create_site(params = {}, = {}) req = build_request(:create_site, params) req.send_request() end |
#delete_outpost(params = {}) ⇒ Struct
Deletes the Outpost.
633 634 635 636 |
# File 'lib/aws-sdk-outposts/client.rb', line 633 def delete_outpost(params = {}, = {}) req = build_request(:delete_outpost, params) req.send_request() end |
#delete_site(params = {}) ⇒ Struct
Deletes the site.
655 656 657 658 |
# File 'lib/aws-sdk-outposts/client.rb', line 655 def delete_site(params = {}, = {}) req = build_request(:delete_site, params) req.send_request() end |
#get_catalog_item(params = {}) ⇒ Types::GetCatalogItemOutput
Gets information about a catalog item.
694 695 696 697 |
# File 'lib/aws-sdk-outposts/client.rb', line 694 def get_catalog_item(params = {}, = {}) req = build_request(:get_catalog_item, params) req.send_request() end |
#get_order(params = {}) ⇒ Types::GetOrderOutput
Gets an order.
732 733 734 735 |
# File 'lib/aws-sdk-outposts/client.rb', line 732 def get_order(params = {}, = {}) req = build_request(:get_order, params) req.send_request() end |
#get_outpost(params = {}) ⇒ Types::GetOutpostOutput
Gets information about the specified Outpost.
772 773 774 775 |
# File 'lib/aws-sdk-outposts/client.rb', line 772 def get_outpost(params = {}, = {}) req = build_request(:get_outpost, params) req.send_request() end |
#get_outpost_instance_types(params = {}) ⇒ Types::GetOutpostInstanceTypesOutput
Lists the instance types for the specified Outpost.
815 816 817 818 |
# File 'lib/aws-sdk-outposts/client.rb', line 815 def get_outpost_instance_types(params = {}, = {}) req = build_request(:get_outpost_instance_types, params) req.send_request() end |
#get_site(params = {}) ⇒ Types::GetSiteOutput
Gets information about the specified Outpost site.
862 863 864 865 |
# File 'lib/aws-sdk-outposts/client.rb', line 862 def get_site(params = {}, = {}) req = build_request(:get_site, params) req.send_request() end |
#get_site_address(params = {}) ⇒ Types::GetSiteAddressOutput
Gets the site address.
908 909 910 911 |
# File 'lib/aws-sdk-outposts/client.rb', line 908 def get_site_address(params = {}, = {}) req = build_request(:get_site_address, params) req.send_request() end |
#list_catalog_items(params = {}) ⇒ Types::ListCatalogItemsOutput
Use to create a list of every item in the catalog. Add filters to your request to return a more specific list of results. Use filters to match an item class, storage option, or EC2 family.
If you specify multiple filters, the filters are joined with an `AND`, and the request returns only results that match all of the specified filters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
986 987 988 989 |
# File 'lib/aws-sdk-outposts/client.rb', line 986 def list_catalog_items(params = {}, = {}) req = build_request(:list_catalog_items, params) req.send_request() end |
#list_orders(params = {}) ⇒ Types::ListOrdersOutput
Create a list of the Outpost orders for your Amazon Web Services account. You can filter your request by Outpost to return a more specific list of results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1036 1037 1038 1039 |
# File 'lib/aws-sdk-outposts/client.rb', line 1036 def list_orders(params = {}, = {}) req = build_request(:list_orders, params) req.send_request() end |
#list_outposts(params = {}) ⇒ Types::ListOutpostsOutput
Create a list of the Outposts for your Amazon Web Services account. Add filters to your request to return a more specific list of results. Use filters to match an Outpost lifecycle status, Availability Zone (`us-east-1a`), and AZ ID (`use1-az1`).
If you specify multiple filters, the filters are joined with an `AND`, and the request returns only results that match all of the specified filters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1116 1117 1118 1119 |
# File 'lib/aws-sdk-outposts/client.rb', line 1116 def list_outposts(params = {}, = {}) req = build_request(:list_outposts, params) req.send_request() end |
#list_sites(params = {}) ⇒ Types::ListSitesOutput
Lists the sites for your Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1172 1173 1174 1175 |
# File 'lib/aws-sdk-outposts/client.rb', line 1172 def list_sites(params = {}, = {}) req = build_request(:list_sites, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for the specified resource.
1201 1202 1203 1204 |
# File 'lib/aws-sdk-outposts/client.rb', line 1201 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to the specified resource.
1229 1230 1231 1232 |
# File 'lib/aws-sdk-outposts/client.rb', line 1229 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from the specified resource.
1255 1256 1257 1258 |
# File 'lib/aws-sdk-outposts/client.rb', line 1255 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_outpost(params = {}) ⇒ Types::UpdateOutpostOutput
Updates an Outpost.
1307 1308 1309 1310 |
# File 'lib/aws-sdk-outposts/client.rb', line 1307 def update_outpost(params = {}, = {}) req = build_request(:update_outpost, params) req.send_request() end |
#update_site(params = {}) ⇒ Types::UpdateSiteOutput
Updates the site.
1366 1367 1368 1369 |
# File 'lib/aws-sdk-outposts/client.rb', line 1366 def update_site(params = {}, = {}) req = build_request(:update_site, params) req.send_request() end |
#update_site_address(params = {}) ⇒ Types::UpdateSiteAddressOutput
Updates the site address.
To update a site address with an order `IN_PROGRESS`, you must wait for the order to complete or cancel the order.
You can update the operating address before you place an order at the site, or after all Outposts that belong to the site have been deactivated.
1433 1434 1435 1436 |
# File 'lib/aws-sdk-outposts/client.rb', line 1433 def update_site_address(params = {}, = {}) req = build_request(:update_site_address, params) req.send_request() end |
#update_site_rack_physical_properties(params = {}) ⇒ Types::UpdateSiteRackPhysicalPropertiesOutput
Update the physical and logistical details for a rack at a site. For more information about hardware requirements for racks, see [Network readiness checklist] in the Amazon Web Services Outposts User Guide.
To update a rack at a site with an order of `IN_PROGRESS`, you must wait for the order to complete or cancel the order.
[1]: docs.aws.amazon.com/outposts/latest/userguide/outposts-requirements.html#checklist
1593 1594 1595 1596 |
# File 'lib/aws-sdk-outposts/client.rb', line 1593 def update_site_rack_physical_properties(params = {}, = {}) req = build_request(:update_site_rack_physical_properties, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1617 1618 1619 |
# File 'lib/aws-sdk-outposts/client.rb', line 1617 def waiter_names [] end |