Class: Aws::Outposts::Types::CapacitySummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::CapacitySummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
A summary of the capacity changes for a quote option.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_change ⇒ Array<Types::QuoteCapacity>
The change in capacity between the existing and final state.
-
#existing_capacities ⇒ Array<Types::QuoteCapacity>
The existing capacities on the Outpost before the quote is fulfilled.
-
#final_capacities ⇒ Array<Types::QuoteCapacity>
The final capacities on the Outpost after the quote is fulfilled.
Instance Attribute Details
#capacity_change ⇒ Array<Types::QuoteCapacity>
The change in capacity between the existing and final state.
274 275 276 277 278 279 280 |
# File 'lib/aws-sdk-outposts/types.rb', line 274 class CapacitySummary < Struct.new( :existing_capacities, :final_capacities, :capacity_change) SENSITIVE = [] include Aws::Structure end |
#existing_capacities ⇒ Array<Types::QuoteCapacity>
The existing capacities on the Outpost before the quote is fulfilled.
274 275 276 277 278 279 280 |
# File 'lib/aws-sdk-outposts/types.rb', line 274 class CapacitySummary < Struct.new( :existing_capacities, :final_capacities, :capacity_change) SENSITIVE = [] include Aws::Structure end |
#final_capacities ⇒ Array<Types::QuoteCapacity>
The final capacities on the Outpost after the quote is fulfilled.
274 275 276 277 278 279 280 |
# File 'lib/aws-sdk-outposts/types.rb', line 274 class CapacitySummary < Struct.new( :existing_capacities, :final_capacities, :capacity_change) SENSITIVE = [] include Aws::Structure end |