Class: Aws::Outposts::Types::CatalogItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::CatalogItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Information about a catalog item.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#catalog_item_id ⇒ String
The ID of the catalog item.
-
#ec2_capacities ⇒ Array<Types::EC2Capacity>
Information about the EC2 capacity of an item.
-
#item_status ⇒ String
The status of a catalog item.
-
#power_kva ⇒ Float
Information about the power draw of an item.
-
#rack_scaling_type ⇒ String
The rack scaling type supported by the catalog item.
-
#supported_storage ⇒ Array<String>
The supported storage options for the catalog item.
-
#supported_uplink_gbps ⇒ Array<Integer>
The uplink speed this catalog item requires for the connection to the Region.
-
#weight_lbs ⇒ Integer
The weight of the item in pounds.
Instance Attribute Details
#catalog_item_id ⇒ String
The ID of the catalog item.
391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/aws-sdk-outposts/types.rb', line 391 class CatalogItem < Struct.new( :catalog_item_id, :item_status, :ec2_capacities, :power_kva, :weight_lbs, :supported_uplink_gbps, :supported_storage, :rack_scaling_type) SENSITIVE = [] include Aws::Structure end |
#ec2_capacities ⇒ Array<Types::EC2Capacity>
Information about the EC2 capacity of an item.
391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/aws-sdk-outposts/types.rb', line 391 class CatalogItem < Struct.new( :catalog_item_id, :item_status, :ec2_capacities, :power_kva, :weight_lbs, :supported_uplink_gbps, :supported_storage, :rack_scaling_type) SENSITIVE = [] include Aws::Structure end |
#item_status ⇒ String
The status of a catalog item.
391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/aws-sdk-outposts/types.rb', line 391 class CatalogItem < Struct.new( :catalog_item_id, :item_status, :ec2_capacities, :power_kva, :weight_lbs, :supported_uplink_gbps, :supported_storage, :rack_scaling_type) SENSITIVE = [] include Aws::Structure end |
#power_kva ⇒ Float
Information about the power draw of an item.
391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/aws-sdk-outposts/types.rb', line 391 class CatalogItem < Struct.new( :catalog_item_id, :item_status, :ec2_capacities, :power_kva, :weight_lbs, :supported_uplink_gbps, :supported_storage, :rack_scaling_type) SENSITIVE = [] include Aws::Structure end |
#rack_scaling_type ⇒ String
The rack scaling type supported by the catalog item. Valid values
are SINGLE_RACK and MULTI_RACK.
391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/aws-sdk-outposts/types.rb', line 391 class CatalogItem < Struct.new( :catalog_item_id, :item_status, :ec2_capacities, :power_kva, :weight_lbs, :supported_uplink_gbps, :supported_storage, :rack_scaling_type) SENSITIVE = [] include Aws::Structure end |
#supported_storage ⇒ Array<String>
The supported storage options for the catalog item.
391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/aws-sdk-outposts/types.rb', line 391 class CatalogItem < Struct.new( :catalog_item_id, :item_status, :ec2_capacities, :power_kva, :weight_lbs, :supported_uplink_gbps, :supported_storage, :rack_scaling_type) SENSITIVE = [] include Aws::Structure end |
#supported_uplink_gbps ⇒ Array<Integer>
The uplink speed this catalog item requires for the connection to the Region.
391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/aws-sdk-outposts/types.rb', line 391 class CatalogItem < Struct.new( :catalog_item_id, :item_status, :ec2_capacities, :power_kva, :weight_lbs, :supported_uplink_gbps, :supported_storage, :rack_scaling_type) SENSITIVE = [] include Aws::Structure end |
#weight_lbs ⇒ Integer
The weight of the item in pounds.
391 392 393 394 395 396 397 398 399 400 401 402 |
# File 'lib/aws-sdk-outposts/types.rb', line 391 class CatalogItem < Struct.new( :catalog_item_id, :item_status, :ec2_capacities, :power_kva, :weight_lbs, :supported_uplink_gbps, :supported_storage, :rack_scaling_type) SENSITIVE = [] include Aws::Structure end |