Class: Aws::Outposts::Types::ComputeAttributes
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::ComputeAttributes
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Information about compute hardware assets.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#host_id ⇒ String
The host ID of the Dedicated Host on the asset.
-
#instance_families ⇒ Array<String>
A list of the names of instance families that are currently associated with a given asset.
-
#instance_type_capacities ⇒ Array<Types::AssetInstanceTypeCapacity>
The instance type capacities configured for this asset.
-
#max_vcpus ⇒ Integer
The maximum number of vCPUs possible for the specified asset.
-
#state ⇒ String
The state.
Instance Attribute Details
#host_id ⇒ String
The host ID of the Dedicated Host on the asset.
438 439 440 441 442 443 444 445 446 |
# File 'lib/aws-sdk-outposts/types.rb', line 438 class ComputeAttributes < Struct.new( :host_id, :state, :instance_families, :instance_type_capacities, :max_vcpus) SENSITIVE = [] include Aws::Structure end |
#instance_families ⇒ Array<String>
A list of the names of instance families that are currently associated with a given asset.
438 439 440 441 442 443 444 445 446 |
# File 'lib/aws-sdk-outposts/types.rb', line 438 class ComputeAttributes < Struct.new( :host_id, :state, :instance_families, :instance_type_capacities, :max_vcpus) SENSITIVE = [] include Aws::Structure end |
#instance_type_capacities ⇒ Array<Types::AssetInstanceTypeCapacity>
The instance type capacities configured for this asset. This can be changed through a capacity task.
438 439 440 441 442 443 444 445 446 |
# File 'lib/aws-sdk-outposts/types.rb', line 438 class ComputeAttributes < Struct.new( :host_id, :state, :instance_families, :instance_type_capacities, :max_vcpus) SENSITIVE = [] include Aws::Structure end |
#max_vcpus ⇒ Integer
The maximum number of vCPUs possible for the specified asset.
438 439 440 441 442 443 444 445 446 |
# File 'lib/aws-sdk-outposts/types.rb', line 438 class ComputeAttributes < Struct.new( :host_id, :state, :instance_families, :instance_type_capacities, :max_vcpus) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state.
-
ACTIVE - The asset is available and can provide capacity for new compute resources.
-
ISOLATED - The asset is undergoing maintenance and can’t provide capacity for new compute resources. Existing compute resources on the asset are not affected.
-
RETIRING - The underlying hardware for the asset is degraded. Capacity for new compute resources is reduced. Amazon Web Services sends notifications for resources that must be stopped before the asset can be replaced.
-
INSTALLING - The asset is being installed and can’t yet provide capacity for new compute resources.
438 439 440 441 442 443 444 445 446 |
# File 'lib/aws-sdk-outposts/types.rb', line 438 class ComputeAttributes < Struct.new( :host_id, :state, :instance_families, :instance_type_capacities, :max_vcpus) SENSITIVE = [] include Aws::Structure end |