Class: Aws::Outposts::Types::ComputeAttributes
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::ComputeAttributes
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Information about compute hardware assets.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#host_id ⇒ String
The host ID of the Dedicated Host on the asset.
-
#state ⇒ String
The state.
Instance Attribute Details
#host_id ⇒ String
The host ID of the Dedicated Host on the asset.
223 224 225 226 227 228 |
# File 'lib/aws-sdk-outposts/types.rb', line 223 class ComputeAttributes < Struct.new( :host_id, :state) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state.
-
ACTIVE - The asset is available and can provide capacity for new compute resources.
-
ISOLATED - The asset is undergoing maintenance and can't provide capacity for new compute resources. Existing compute resources on the asset are not affected.
-
RETIRING - The underlying hardware for the asset is degraded. Capacity for new compute resources is reduced. Amazon Web Services sends notifications for resources that must be stopped before the asset can be replaced.
223 224 225 226 227 228 |
# File 'lib/aws-sdk-outposts/types.rb', line 223 class ComputeAttributes < Struct.new( :host_id, :state) SENSITIVE = [] include Aws::Structure end |