Class: Aws::Outposts::Types::CreateOrderInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::CreateOrderInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#line_items ⇒ Array<Types::LineItemRequest>
The line items that make up the order.
-
#outpost_identifier ⇒ String
The ID or the Amazon Resource Name (ARN) of the Outpost.
-
#payment_option ⇒ String
The payment option.
-
#payment_term ⇒ String
The payment terms.
-
#quote_identifier ⇒ String
The ID of the quote to use for the order.
-
#quote_option_identifier ⇒ String
The ID of the quote option to use for the order.
Instance Attribute Details
#line_items ⇒ Array<Types::LineItemRequest>
The line items that make up the order.
536 537 538 539 540 541 542 543 544 545 |
# File 'lib/aws-sdk-outposts/types.rb', line 536 class CreateOrderInput < Struct.new( :outpost_identifier, :quote_identifier, :quote_option_identifier, :line_items, :payment_option, :payment_term) SENSITIVE = [] include Aws::Structure end |
#outpost_identifier ⇒ String
The ID or the Amazon Resource Name (ARN) of the Outpost.
536 537 538 539 540 541 542 543 544 545 |
# File 'lib/aws-sdk-outposts/types.rb', line 536 class CreateOrderInput < Struct.new( :outpost_identifier, :quote_identifier, :quote_option_identifier, :line_items, :payment_option, :payment_term) SENSITIVE = [] include Aws::Structure end |
#payment_option ⇒ String
The payment option.
536 537 538 539 540 541 542 543 544 545 |
# File 'lib/aws-sdk-outposts/types.rb', line 536 class CreateOrderInput < Struct.new( :outpost_identifier, :quote_identifier, :quote_option_identifier, :line_items, :payment_option, :payment_term) SENSITIVE = [] include Aws::Structure end |
#payment_term ⇒ String
The payment terms.
536 537 538 539 540 541 542 543 544 545 |
# File 'lib/aws-sdk-outposts/types.rb', line 536 class CreateOrderInput < Struct.new( :outpost_identifier, :quote_identifier, :quote_option_identifier, :line_items, :payment_option, :payment_term) SENSITIVE = [] include Aws::Structure end |
#quote_identifier ⇒ String
The ID of the quote to use for the order.
536 537 538 539 540 541 542 543 544 545 |
# File 'lib/aws-sdk-outposts/types.rb', line 536 class CreateOrderInput < Struct.new( :outpost_identifier, :quote_identifier, :quote_option_identifier, :line_items, :payment_option, :payment_term) SENSITIVE = [] include Aws::Structure end |
#quote_option_identifier ⇒ String
The ID of the quote option to use for the order.
536 537 538 539 540 541 542 543 544 545 |
# File 'lib/aws-sdk-outposts/types.rb', line 536 class CreateOrderInput < Struct.new( :outpost_identifier, :quote_identifier, :quote_option_identifier, :line_items, :payment_option, :payment_term) SENSITIVE = [] include Aws::Structure end |