Class: Aws::Outposts::Types::CreateOutpostInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::CreateOutpostInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
When making an API call, you may pass CreateOutpostInput data as a hash:
{
name: "OutpostName", # required
description: "OutpostDescription",
site_id: "SiteId", # required
availability_zone: "AvailabilityZone",
availability_zone_id: "AvailabilityZoneId",
tags: {
"TagKey" => "TagValue",
},
supported_hardware_type: "RACK", # accepts RACK, SERVER
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone ⇒ String
The Availability Zone.
-
#availability_zone_id ⇒ String
The ID of the Availability Zone.
-
#description ⇒ String
The description of the Outpost.
-
#name ⇒ String
The name of the Outpost.
-
#site_id ⇒ String
The ID or the Amazon Resource Name (ARN) of the site.
-
#supported_hardware_type ⇒ String
The type of hardware for this Outpost.
-
#tags ⇒ Hash<String,String>
The tags to apply to the Outpost.
Instance Attribute Details
#availability_zone ⇒ String
The Availability Zone.
387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-outposts/types.rb', line 387 class CreateOutpostInput < Struct.new( :name, :description, :site_id, :availability_zone, :availability_zone_id, :tags, :supported_hardware_type) SENSITIVE = [] include Aws::Structure end |
#availability_zone_id ⇒ String
The ID of the Availability Zone.
387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-outposts/types.rb', line 387 class CreateOutpostInput < Struct.new( :name, :description, :site_id, :availability_zone, :availability_zone_id, :tags, :supported_hardware_type) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the Outpost.
387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-outposts/types.rb', line 387 class CreateOutpostInput < Struct.new( :name, :description, :site_id, :availability_zone, :availability_zone_id, :tags, :supported_hardware_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Outpost.
387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-outposts/types.rb', line 387 class CreateOutpostInput < Struct.new( :name, :description, :site_id, :availability_zone, :availability_zone_id, :tags, :supported_hardware_type) SENSITIVE = [] include Aws::Structure end |
#site_id ⇒ String
The ID or the Amazon Resource Name (ARN) of the site.
<note markdown=“1”> In requests, Amazon Web Services Outposts accepts the Amazon Resource Name (ARN) or an ID for Outposts and sites throughout the Outposts Query API. To address backwards compatibility, the parameter names `OutpostID` or `SiteID` remain in use. Despite the parameter name, you can make the request with an ARN.
</note>
387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-outposts/types.rb', line 387 class CreateOutpostInput < Struct.new( :name, :description, :site_id, :availability_zone, :availability_zone_id, :tags, :supported_hardware_type) SENSITIVE = [] include Aws::Structure end |
#supported_hardware_type ⇒ String
The type of hardware for this Outpost.
387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-outposts/types.rb', line 387 class CreateOutpostInput < Struct.new( :name, :description, :site_id, :availability_zone, :availability_zone_id, :tags, :supported_hardware_type) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to apply to the Outpost.
387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/aws-sdk-outposts/types.rb', line 387 class CreateOutpostInput < Struct.new( :name, :description, :site_id, :availability_zone, :availability_zone_id, :tags, :supported_hardware_type) SENSITIVE = [] include Aws::Structure end |