Class: Aws::Outposts::Types::CreateQuoteInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#country_codeString

The country code for the Outpost site location.

Returns:

  • (String)


651
652
653
654
655
656
657
658
659
660
661
# File 'lib/aws-sdk-outposts/types.rb', line 651

class CreateQuoteInput < Struct.new(
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

A description for the quote.

Returns:

  • (String)


651
652
653
654
655
656
657
658
659
660
661
# File 'lib/aws-sdk-outposts/types.rb', line 651

class CreateQuoteInput < Struct.new(
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#outpost_identifierString

The ID or ARN of the Outpost to associate with the quote. If not specified, the quote is created without an Outpost association.

Returns:

  • (String)


651
652
653
654
655
656
657
658
659
660
661
# File 'lib/aws-sdk-outposts/types.rb', line 651

class CreateQuoteInput < Struct.new(
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#requested_capacitiesArray<Types::QuoteCapacity>

The capacity requirements for the quote. Each entry specifies a capacity type (such as Amazon EC2), the unit, and the quantity. For Amazon EC2, the quantity is the number of additional instances to add to the Outpost. For Amazon EBS and Amazon S3, the quantity is the total desired end-state capacity of the Outpost.

Returns:



651
652
653
654
655
656
657
658
659
660
661
# File 'lib/aws-sdk-outposts/types.rb', line 651

class CreateQuoteInput < Struct.new(
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#requested_constraintsArray<Types::QuoteConstraint>

The physical constraints for the quote, such as maximum number of racks, maximum power draw per rack, or maximum weight per rack.

Returns:



651
652
653
654
655
656
657
658
659
660
661
# File 'lib/aws-sdk-outposts/types.rb', line 651

class CreateQuoteInput < Struct.new(
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#requested_payment_optionsArray<String>

The payment options to include in the quote pricing. If not specified, all available payment options are returned.

Returns:

  • (Array<String>)


651
652
653
654
655
656
657
658
659
660
661
# File 'lib/aws-sdk-outposts/types.rb', line 651

class CreateQuoteInput < Struct.new(
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#requested_payment_termsArray<String>

The payment terms to include in the quote pricing. If not specified, all available payment terms are returned.

Returns:

  • (Array<String>)


651
652
653
654
655
656
657
658
659
660
661
# File 'lib/aws-sdk-outposts/types.rb', line 651

class CreateQuoteInput < Struct.new(
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end