Class: Aws::Outposts::Types::CreateSiteInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:operating_address, :shipping_address]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

The description of the site.

Returns:

  • (String)


822
823
824
825
826
827
828
829
830
831
832
# File 'lib/aws-sdk-outposts/types.rb', line 822

class CreateSiteInput < Struct.new(
  :name,
  :description,
  :notes,
  :tags,
  :operating_address,
  :shipping_address,
  :rack_physical_properties)
  SENSITIVE = [:operating_address, :shipping_address]
  include Aws::Structure
end

#nameString

The name of the site.

Returns:

  • (String)


822
823
824
825
826
827
828
829
830
831
832
# File 'lib/aws-sdk-outposts/types.rb', line 822

class CreateSiteInput < Struct.new(
  :name,
  :description,
  :notes,
  :tags,
  :operating_address,
  :shipping_address,
  :rack_physical_properties)
  SENSITIVE = [:operating_address, :shipping_address]
  include Aws::Structure
end

#notesString

Additional information that you provide about site access requirements, electrician scheduling, personal protective equipment, or regulation of equipment materials that could affect your installation process.

Returns:

  • (String)


822
823
824
825
826
827
828
829
830
831
832
# File 'lib/aws-sdk-outposts/types.rb', line 822

class CreateSiteInput < Struct.new(
  :name,
  :description,
  :notes,
  :tags,
  :operating_address,
  :shipping_address,
  :rack_physical_properties)
  SENSITIVE = [:operating_address, :shipping_address]
  include Aws::Structure
end

#operating_addressTypes::Address

The location to install and power on the hardware. This address might be different from the shipping address.

Returns:



822
823
824
825
826
827
828
829
830
831
832
# File 'lib/aws-sdk-outposts/types.rb', line 822

class CreateSiteInput < Struct.new(
  :name,
  :description,
  :notes,
  :tags,
  :operating_address,
  :shipping_address,
  :rack_physical_properties)
  SENSITIVE = [:operating_address, :shipping_address]
  include Aws::Structure
end

#rack_physical_propertiesTypes::RackPhysicalProperties

Information about the physical and logistical details for the rack at this site. For more information about hardware requirements for racks, see Network readiness checklist in the Amazon Web Services Outposts User Guide.



822
823
824
825
826
827
828
829
830
831
832
# File 'lib/aws-sdk-outposts/types.rb', line 822

class CreateSiteInput < Struct.new(
  :name,
  :description,
  :notes,
  :tags,
  :operating_address,
  :shipping_address,
  :rack_physical_properties)
  SENSITIVE = [:operating_address, :shipping_address]
  include Aws::Structure
end

#shipping_addressTypes::Address

The location to ship the hardware. This address might be different from the operating address.

Returns:



822
823
824
825
826
827
828
829
830
831
832
# File 'lib/aws-sdk-outposts/types.rb', line 822

class CreateSiteInput < Struct.new(
  :name,
  :description,
  :notes,
  :tags,
  :operating_address,
  :shipping_address,
  :rack_physical_properties)
  SENSITIVE = [:operating_address, :shipping_address]
  include Aws::Structure
end

#tagsHash<String,String>

The tags to apply to a site.

Returns:

  • (Hash<String,String>)


822
823
824
825
826
827
828
829
830
831
832
# File 'lib/aws-sdk-outposts/types.rb', line 822

class CreateSiteInput < Struct.new(
  :name,
  :description,
  :notes,
  :tags,
  :operating_address,
  :shipping_address,
  :rack_physical_properties)
  SENSITIVE = [:operating_address, :shipping_address]
  include Aws::Structure
end