Class: Aws::Outposts::Types::CreateSiteInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::CreateSiteInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the site.
-
#name ⇒ String
The name of the site.
-
#notes ⇒ String
Additional information that you provide about site access requirements, electrician scheduling, personal protective equipment, or regulation of equipment materials that could affect your installation process.
-
#operating_address ⇒ Types::Address
The location to install and power on the hardware.
-
#rack_physical_properties ⇒ Types::RackPhysicalProperties
Information about the physical and logistical details for the rack at this site.
-
#shipping_address ⇒ Types::Address
The location to ship the hardware.
-
#tags ⇒ Hash<String,String>
The tags to apply to a site.
Instance Attribute Details
#description ⇒ String
The description of the site.
775 776 777 778 779 780 781 782 783 784 785 |
# File 'lib/aws-sdk-outposts/types.rb', line 775 class CreateSiteInput < Struct.new( :name, :description, :notes, :tags, :operating_address, :shipping_address, :rack_physical_properties) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the site.
775 776 777 778 779 780 781 782 783 784 785 |
# File 'lib/aws-sdk-outposts/types.rb', line 775 class CreateSiteInput < Struct.new( :name, :description, :notes, :tags, :operating_address, :shipping_address, :rack_physical_properties) SENSITIVE = [] include Aws::Structure end |
#notes ⇒ String
Additional information that you provide about site access requirements, electrician scheduling, personal protective equipment, or regulation of equipment materials that could affect your installation process.
775 776 777 778 779 780 781 782 783 784 785 |
# File 'lib/aws-sdk-outposts/types.rb', line 775 class CreateSiteInput < Struct.new( :name, :description, :notes, :tags, :operating_address, :shipping_address, :rack_physical_properties) SENSITIVE = [] include Aws::Structure end |
#operating_address ⇒ Types::Address
The location to install and power on the hardware. This address might be different from the shipping address.
775 776 777 778 779 780 781 782 783 784 785 |
# File 'lib/aws-sdk-outposts/types.rb', line 775 class CreateSiteInput < Struct.new( :name, :description, :notes, :tags, :operating_address, :shipping_address, :rack_physical_properties) SENSITIVE = [] include Aws::Structure end |
#rack_physical_properties ⇒ Types::RackPhysicalProperties
Information about the physical and logistical details for the rack at this site. For more information about hardware requirements for racks, see [Network readiness checklist] in the Amazon Web Services Outposts User Guide.
[1]: docs.aws.amazon.com/outposts/latest/userguide/outposts-requirements.html#checklist
775 776 777 778 779 780 781 782 783 784 785 |
# File 'lib/aws-sdk-outposts/types.rb', line 775 class CreateSiteInput < Struct.new( :name, :description, :notes, :tags, :operating_address, :shipping_address, :rack_physical_properties) SENSITIVE = [] include Aws::Structure end |
#shipping_address ⇒ Types::Address
The location to ship the hardware. This address might be different from the operating address.
775 776 777 778 779 780 781 782 783 784 785 |
# File 'lib/aws-sdk-outposts/types.rb', line 775 class CreateSiteInput < Struct.new( :name, :description, :notes, :tags, :operating_address, :shipping_address, :rack_physical_properties) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to apply to a site.
775 776 777 778 779 780 781 782 783 784 785 |
# File 'lib/aws-sdk-outposts/types.rb', line 775 class CreateSiteInput < Struct.new( :name, :description, :notes, :tags, :operating_address, :shipping_address, :rack_physical_properties) SENSITIVE = [] include Aws::Structure end |