Class: Aws::Outposts::Types::CreateSiteInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::CreateSiteInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
When making an API call, you may pass CreateSiteInput data as a hash:
{
name: "SiteName", # required
description: "SiteDescription",
notes: "SiteNotes",
tags: {
"TagKey" => "TagValue",
},
operating_address: {
contact_name: "ContactName",
contact_phone_number: "ContactPhoneNumber",
address_line_1: "AddressLine1", # required
address_line_2: "AddressLine2",
address_line_3: "AddressLine3",
city: "City", # required
state_or_region: "StateOrRegion", # required
district_or_county: "DistrictOrCounty",
postal_code: "PostalCode", # required
country_code: "CountryCode", # required
municipality: "Municipality",
},
shipping_address: {
contact_name: "ContactName",
contact_phone_number: "ContactPhoneNumber",
address_line_1: "AddressLine1", # required
address_line_2: "AddressLine2",
address_line_3: "AddressLine3",
city: "City", # required
state_or_region: "StateOrRegion", # required
district_or_county: "DistrictOrCounty",
postal_code: "PostalCode", # required
country_code: "CountryCode", # required
municipality: "Municipality",
},
rack_physical_properties: {
power_draw_kva: "POWER_5_KVA", # accepts POWER_5_KVA, POWER_10_KVA, POWER_15_KVA
power_phase: "SINGLE_PHASE", # accepts SINGLE_PHASE, THREE_PHASE
power_connector: "L6_30P", # accepts L6_30P, IEC309, AH530P7W, AH532P6W
power_feed_drop: "ABOVE_RACK", # accepts ABOVE_RACK, BELOW_RACK
uplink_gbps: "UPLINK_1G", # accepts UPLINK_1G, UPLINK_10G, UPLINK_40G, UPLINK_100G
uplink_count: "UPLINK_COUNT_1", # accepts UPLINK_COUNT_1, UPLINK_COUNT_2, UPLINK_COUNT_3, UPLINK_COUNT_4, UPLINK_COUNT_5, UPLINK_COUNT_6, UPLINK_COUNT_7, UPLINK_COUNT_8, UPLINK_COUNT_12, UPLINK_COUNT_16
fiber_optic_cable_type: "SINGLE_MODE", # accepts SINGLE_MODE, MULTI_MODE
optical_standard: "OPTIC_10GBASE_SR", # accepts OPTIC_10GBASE_SR, OPTIC_10GBASE_IR, OPTIC_10GBASE_LR, OPTIC_40GBASE_SR, OPTIC_40GBASE_ESR, OPTIC_40GBASE_IR4_LR4L, OPTIC_40GBASE_LR4, OPTIC_100GBASE_SR4, OPTIC_100GBASE_CWDM4, OPTIC_100GBASE_LR4, OPTIC_100G_PSM4_MSA, OPTIC_1000BASE_LX, OPTIC_1000BASE_SX
maximum_supported_weight_lbs: "NO_LIMIT", # accepts NO_LIMIT, MAX_1400_LBS, MAX_1600_LBS, MAX_1800_LBS, MAX_2000_LBS
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the site.
-
#name ⇒ String
The name of the site.
-
#notes ⇒ String
Additional information that you provide about site access requirements, electrician scheduling, personal protective equipment, or regulation of equipment materials that could affect your installation process.
-
#operating_address ⇒ Types::Address
The location to install and power on the hardware.
-
#rack_physical_properties ⇒ Types::RackPhysicalProperties
Information about the physical and logistical details for the rack at this site.
-
#shipping_address ⇒ Types::Address
The location to ship the hardware.
-
#tags ⇒ Hash<String,String>
The tags to apply to a site.
Instance Attribute Details
#description ⇒ String
The description of the site.
502 503 504 505 506 507 508 509 510 511 512 |
# File 'lib/aws-sdk-outposts/types.rb', line 502 class CreateSiteInput < Struct.new( :name, :description, :notes, :tags, :operating_address, :shipping_address, :rack_physical_properties) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the site.
502 503 504 505 506 507 508 509 510 511 512 |
# File 'lib/aws-sdk-outposts/types.rb', line 502 class CreateSiteInput < Struct.new( :name, :description, :notes, :tags, :operating_address, :shipping_address, :rack_physical_properties) SENSITIVE = [] include Aws::Structure end |
#notes ⇒ String
Additional information that you provide about site access requirements, electrician scheduling, personal protective equipment, or regulation of equipment materials that could affect your installation process.
502 503 504 505 506 507 508 509 510 511 512 |
# File 'lib/aws-sdk-outposts/types.rb', line 502 class CreateSiteInput < Struct.new( :name, :description, :notes, :tags, :operating_address, :shipping_address, :rack_physical_properties) SENSITIVE = [] include Aws::Structure end |
#operating_address ⇒ Types::Address
The location to install and power on the hardware. This address might be different from the shipping address.
502 503 504 505 506 507 508 509 510 511 512 |
# File 'lib/aws-sdk-outposts/types.rb', line 502 class CreateSiteInput < Struct.new( :name, :description, :notes, :tags, :operating_address, :shipping_address, :rack_physical_properties) SENSITIVE = [] include Aws::Structure end |
#rack_physical_properties ⇒ Types::RackPhysicalProperties
Information about the physical and logistical details for the rack at this site. For more information about hardware requirements for racks, see [Network readiness checklist] in the Amazon Web Services Outposts User Guide.
[1]: docs.aws.amazon.com/outposts/latest/userguide/outposts-requirements.html#checklist
502 503 504 505 506 507 508 509 510 511 512 |
# File 'lib/aws-sdk-outposts/types.rb', line 502 class CreateSiteInput < Struct.new( :name, :description, :notes, :tags, :operating_address, :shipping_address, :rack_physical_properties) SENSITIVE = [] include Aws::Structure end |
#shipping_address ⇒ Types::Address
The location to ship the hardware. This address might be different from the operating address.
502 503 504 505 506 507 508 509 510 511 512 |
# File 'lib/aws-sdk-outposts/types.rb', line 502 class CreateSiteInput < Struct.new( :name, :description, :notes, :tags, :operating_address, :shipping_address, :rack_physical_properties) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to apply to a site.
502 503 504 505 506 507 508 509 510 511 512 |
# File 'lib/aws-sdk-outposts/types.rb', line 502 class CreateSiteInput < Struct.new( :name, :description, :notes, :tags, :operating_address, :shipping_address, :rack_physical_properties) SENSITIVE = [] include Aws::Structure end |