Class: Aws::Outposts::Types::DetailedInstanceTypeItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Information about an instance type that can be ordered for an Outpost, including hardware specifications and supported form factors.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#form_factor_configsArray<Types::FormFactorConfig>

The supported form factor and Outpost generation configurations for the instance type.

Returns:



873
874
875
876
877
878
879
880
881
# File 'lib/aws-sdk-outposts/types.rb', line 873

class DetailedInstanceTypeItem < Struct.new(
  :instance_type,
  :vcp_us,
  :memory_in_mib,
  :network_performance,
  :form_factor_configs)
  SENSITIVE = []
  include Aws::Structure
end

#instance_typeString

The instance type.

Returns:

  • (String)


873
874
875
876
877
878
879
880
881
# File 'lib/aws-sdk-outposts/types.rb', line 873

class DetailedInstanceTypeItem < Struct.new(
  :instance_type,
  :vcp_us,
  :memory_in_mib,
  :network_performance,
  :form_factor_configs)
  SENSITIVE = []
  include Aws::Structure
end

#memory_in_mibInteger

The memory size of the instance type, in MiB.

Returns:

  • (Integer)


873
874
875
876
877
878
879
880
881
# File 'lib/aws-sdk-outposts/types.rb', line 873

class DetailedInstanceTypeItem < Struct.new(
  :instance_type,
  :vcp_us,
  :memory_in_mib,
  :network_performance,
  :form_factor_configs)
  SENSITIVE = []
  include Aws::Structure
end

#network_performanceString

The network performance of the instance type.

Returns:

  • (String)


873
874
875
876
877
878
879
880
881
# File 'lib/aws-sdk-outposts/types.rb', line 873

class DetailedInstanceTypeItem < Struct.new(
  :instance_type,
  :vcp_us,
  :memory_in_mib,
  :network_performance,
  :form_factor_configs)
  SENSITIVE = []
  include Aws::Structure
end

#vcp_usInteger

The number of default VCPUs in the instance type.

Returns:

  • (Integer)


873
874
875
876
877
878
879
880
881
# File 'lib/aws-sdk-outposts/types.rb', line 873

class DetailedInstanceTypeItem < Struct.new(
  :instance_type,
  :vcp_us,
  :memory_in_mib,
  :network_performance,
  :form_factor_configs)
  SENSITIVE = []
  include Aws::Structure
end