Class: Aws::Outposts::Types::DetailedInstanceTypeItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::DetailedInstanceTypeItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Information about an instance type that can be ordered for an Outpost, including hardware specifications and supported form factors.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#form_factor_configs ⇒ Array<Types::FormFactorConfig>
The supported form factor and Outpost generation configurations for the instance type.
-
#instance_type ⇒ String
The instance type.
-
#memory_in_mib ⇒ Integer
The memory size of the instance type, in MiB.
-
#network_performance ⇒ String
The network performance of the instance type.
-
#vcp_us ⇒ Integer
The number of default VCPUs in the instance type.
Instance Attribute Details
#form_factor_configs ⇒ Array<Types::FormFactorConfig>
The supported form factor and Outpost generation configurations for the instance type.
873 874 875 876 877 878 879 880 881 |
# File 'lib/aws-sdk-outposts/types.rb', line 873 class DetailedInstanceTypeItem < Struct.new( :instance_type, :vcp_us, :memory_in_mib, :network_performance, :form_factor_configs) SENSITIVE = [] include Aws::Structure end |
#instance_type ⇒ String
The instance type.
873 874 875 876 877 878 879 880 881 |
# File 'lib/aws-sdk-outposts/types.rb', line 873 class DetailedInstanceTypeItem < Struct.new( :instance_type, :vcp_us, :memory_in_mib, :network_performance, :form_factor_configs) SENSITIVE = [] include Aws::Structure end |
#memory_in_mib ⇒ Integer
The memory size of the instance type, in MiB.
873 874 875 876 877 878 879 880 881 |
# File 'lib/aws-sdk-outposts/types.rb', line 873 class DetailedInstanceTypeItem < Struct.new( :instance_type, :vcp_us, :memory_in_mib, :network_performance, :form_factor_configs) SENSITIVE = [] include Aws::Structure end |
#network_performance ⇒ String
The network performance of the instance type.
873 874 875 876 877 878 879 880 881 |
# File 'lib/aws-sdk-outposts/types.rb', line 873 class DetailedInstanceTypeItem < Struct.new( :instance_type, :vcp_us, :memory_in_mib, :network_performance, :form_factor_configs) SENSITIVE = [] include Aws::Structure end |
#vcp_us ⇒ Integer
The number of default VCPUs in the instance type.
873 874 875 876 877 878 879 880 881 |
# File 'lib/aws-sdk-outposts/types.rb', line 873 class DetailedInstanceTypeItem < Struct.new( :instance_type, :vcp_us, :memory_in_mib, :network_performance, :form_factor_configs) SENSITIVE = [] include Aws::Structure end |