Class: Aws::Outposts::Types::GetOutpostBillingInformationOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contract_end_dateString

The date the current contract term ends for the specified Outpost. You must start the renewal or decommission process at least 5 business days before the current term for your Amazon Web Services Outposts ends. Failing to complete these steps at least 5 business days before the current term ends might result in unanticipated charges.

Returns:

  • (String)


1011
1012
1013
1014
1015
1016
1017
1018
1019
# File 'lib/aws-sdk-outposts/types.rb', line 1011

class GetOutpostBillingInformationOutput < Struct.new(
  :next_token,
  :subscriptions,
  :contract_end_date,
  :payment_term,
  :payment_option)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token.

Returns:

  • (String)


1011
1012
1013
1014
1015
1016
1017
1018
1019
# File 'lib/aws-sdk-outposts/types.rb', line 1011

class GetOutpostBillingInformationOutput < Struct.new(
  :next_token,
  :subscriptions,
  :contract_end_date,
  :payment_term,
  :payment_option)
  SENSITIVE = []
  include Aws::Structure
end

#payment_optionString

The payment option.

Returns:

  • (String)


1011
1012
1013
1014
1015
1016
1017
1018
1019
# File 'lib/aws-sdk-outposts/types.rb', line 1011

class GetOutpostBillingInformationOutput < Struct.new(
  :next_token,
  :subscriptions,
  :contract_end_date,
  :payment_term,
  :payment_option)
  SENSITIVE = []
  include Aws::Structure
end

#payment_termString

The payment term.

Returns:

  • (String)


1011
1012
1013
1014
1015
1016
1017
1018
1019
# File 'lib/aws-sdk-outposts/types.rb', line 1011

class GetOutpostBillingInformationOutput < Struct.new(
  :next_token,
  :subscriptions,
  :contract_end_date,
  :payment_term,
  :payment_option)
  SENSITIVE = []
  include Aws::Structure
end

#subscriptionsArray<Types::Subscription>

The subscription details for the specified Outpost.

Returns:



1011
1012
1013
1014
1015
1016
1017
1018
1019
# File 'lib/aws-sdk-outposts/types.rb', line 1011

class GetOutpostBillingInformationOutput < Struct.new(
  :next_token,
  :subscriptions,
  :contract_end_date,
  :payment_term,
  :payment_option)
  SENSITIVE = []
  include Aws::Structure
end