Class: Aws::Outposts::Types::GetOutpostInstanceTypesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::GetOutpostInstanceTypesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Note:
When making an API call, you may pass GetOutpostInstanceTypesInput data as a hash:
{
outpost_id: "OutpostId", # required
next_token: "Token",
max_results: 1,
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum page size.
-
#next_token ⇒ String
The pagination token.
-
#outpost_id ⇒ String
The ID or the Amazon Resource Name (ARN) of the Outpost.
Instance Attribute Details
#max_results ⇒ Integer
The maximum page size.
693 694 695 696 697 698 699 |
# File 'lib/aws-sdk-outposts/types.rb', line 693 class GetOutpostInstanceTypesInput < Struct.new( :outpost_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token.
693 694 695 696 697 698 699 |
# File 'lib/aws-sdk-outposts/types.rb', line 693 class GetOutpostInstanceTypesInput < Struct.new( :outpost_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#outpost_id ⇒ String
The ID or the Amazon Resource Name (ARN) of the Outpost.
<note markdown=“1”> In requests, Amazon Web Services Outposts accepts the Amazon Resource Name (ARN) or an ID for Outposts and sites throughout the Outposts Query API. To address backwards compatibility, the parameter names `OutpostID` or `SiteID` remain in use. Despite the parameter name, you can make the request with an ARN.
</note>
693 694 695 696 697 698 699 |
# File 'lib/aws-sdk-outposts/types.rb', line 693 class GetOutpostInstanceTypesInput < Struct.new( :outpost_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |