Class: Aws::Outposts::Types::InstancesToExclude
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::InstancesToExclude
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
User-specified instances that must not be stopped. These instances will not appear in the list of instances that Amazon Web Services recommends to stop in order to free up capacity.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_ids ⇒ Array<String>
IDs of the accounts that own each instance that must not be stopped.
-
#instances ⇒ Array<String>
List of user-specified instances that must not be stopped.
-
#services ⇒ Array<String>
Names of the services that own each instance that must not be stopped in order to free up the capacity needed to run the capacity task.
Instance Attribute Details
#account_ids ⇒ Array<String>
IDs of the accounts that own each instance that must not be stopped.
1558 1559 1560 1561 1562 1563 1564 |
# File 'lib/aws-sdk-outposts/types.rb', line 1558 class InstancesToExclude < Struct.new( :instances, :account_ids, :services) SENSITIVE = [] include Aws::Structure end |
#instances ⇒ Array<String>
List of user-specified instances that must not be stopped.
1558 1559 1560 1561 1562 1563 1564 |
# File 'lib/aws-sdk-outposts/types.rb', line 1558 class InstancesToExclude < Struct.new( :instances, :account_ids, :services) SENSITIVE = [] include Aws::Structure end |
#services ⇒ Array<String>
Names of the services that own each instance that must not be stopped in order to free up the capacity needed to run the capacity task.
1558 1559 1560 1561 1562 1563 1564 |
# File 'lib/aws-sdk-outposts/types.rb', line 1558 class InstancesToExclude < Struct.new( :instances, :account_ids, :services) SENSITIVE = [] include Aws::Structure end |