Class: Aws::Outposts::Types::InstancesToExclude
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::InstancesToExclude
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
User-specified instances that must not be stopped. These instances will not appear in the list of instances that Amazon Web Services recommends to stop in order to free up capacity.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_ids ⇒ Array<String>
IDs of the accounts that own each instance that must not be stopped.
-
#instances ⇒ Array<String>
List of user-specified instances that must not be stopped.
-
#services ⇒ Array<String>
Names of the services that own each instance that must not be stopped in order to free up the capacity needed to run the capacity task.
Instance Attribute Details
#account_ids ⇒ Array<String>
IDs of the accounts that own each instance that must not be stopped.
1487 1488 1489 1490 1491 1492 1493 |
# File 'lib/aws-sdk-outposts/types.rb', line 1487 class InstancesToExclude < Struct.new( :instances, :account_ids, :services) SENSITIVE = [] include Aws::Structure end |
#instances ⇒ Array<String>
List of user-specified instances that must not be stopped.
1487 1488 1489 1490 1491 1492 1493 |
# File 'lib/aws-sdk-outposts/types.rb', line 1487 class InstancesToExclude < Struct.new( :instances, :account_ids, :services) SENSITIVE = [] include Aws::Structure end |
#services ⇒ Array<String>
Names of the services that own each instance that must not be stopped in order to free up the capacity needed to run the capacity task.
1487 1488 1489 1490 1491 1492 1493 |
# File 'lib/aws-sdk-outposts/types.rb', line 1487 class InstancesToExclude < Struct.new( :instances, :account_ids, :services) SENSITIVE = [] include Aws::Structure end |