Class: Aws::Outposts::Types::PrivateConnectivityConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::PrivateConnectivityConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Information about the private connectivity configuration for an Outpost.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#private_connectivity_status ⇒ String
The status of private connectivity for the Outpost.
-
#provisioning_role_arn ⇒ String
The Amazon Resource Name (ARN) of the provisioning role in your account that Amazon Web Services Outposts uses to establish the service link connection during Outpost installation.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the service-linked role that Amazon Web Services Outposts creates and uses to provision and attach the network interfaces for private connectivity in your VPC.
-
#vpc_information_list ⇒ Array<Types::VpcInformation>
Information about the VPC used for private connectivity.
Instance Attribute Details
#private_connectivity_status ⇒ String
The status of private connectivity for the Outpost. Valid values are
ENABLED and DISABLED.
2518 2519 2520 2521 2522 2523 2524 2525 |
# File 'lib/aws-sdk-outposts/types.rb', line 2518 class PrivateConnectivityConfig < Struct.new( :role_arn, :private_connectivity_status, :vpc_information_list, :provisioning_role_arn) SENSITIVE = [] include Aws::Structure end |
#provisioning_role_arn ⇒ String
The Amazon Resource Name (ARN) of the provisioning role in your account that Amazon Web Services Outposts uses to establish the service link connection during Outpost installation. This field is present only when VPC endpoint-based provisioning is configured.
2518 2519 2520 2521 2522 2523 2524 2525 |
# File 'lib/aws-sdk-outposts/types.rb', line 2518 class PrivateConnectivityConfig < Struct.new( :role_arn, :private_connectivity_status, :vpc_information_list, :provisioning_role_arn) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the service-linked role that Amazon Web Services Outposts creates and uses to provision and attach the network interfaces for private connectivity in your VPC. The role's permissions are scoped to the specific Outpost and VPC.
2518 2519 2520 2521 2522 2523 2524 2525 |
# File 'lib/aws-sdk-outposts/types.rb', line 2518 class PrivateConnectivityConfig < Struct.new( :role_arn, :private_connectivity_status, :vpc_information_list, :provisioning_role_arn) SENSITIVE = [] include Aws::Structure end |
#vpc_information_list ⇒ Array<Types::VpcInformation>
Information about the VPC used for private connectivity.
2518 2519 2520 2521 2522 2523 2524 2525 |
# File 'lib/aws-sdk-outposts/types.rb', line 2518 class PrivateConnectivityConfig < Struct.new( :role_arn, :private_connectivity_status, :vpc_information_list, :provisioning_role_arn) SENSITIVE = [] include Aws::Structure end |