Class: Aws::Outposts::Types::Quote
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::Quote
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Information about a quote for an Outpost. A quote provides pricing and configuration options based on the requested capacity.
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The ID of the account that owns the quote.
-
#country_code ⇒ String
The country code for the Outpost site location.
-
#created_date ⇒ Time
The date the quote was created.
-
#description ⇒ String
The description of the quote.
-
#expiration_date ⇒ Time
The date the quote expires.
-
#ordering_requirements ⇒ Array<Types::OrderingRequirement>
The requirements that must be met before an order can be submitted for the quote.
-
#outpost_arn ⇒ String
The ARN of the Outpost associated with the quote.
-
#quote_id ⇒ String
The ID of the quote.
-
#quote_options ⇒ Array<Types::QuoteOption>
The configuration and pricing options for the quote.
-
#quote_status ⇒ String
The status of the quote.
-
#requested_capacities ⇒ Array<Types::QuoteCapacity>
The capacity requirements specified in the quote request.
-
#requested_constraints ⇒ Array<Types::QuoteConstraint>
The physical constraints specified in the quote request.
-
#requested_payment_options ⇒ Array<String>
The payment options specified in the quote request.
-
#requested_payment_terms ⇒ Array<String>
The payment terms specified in the quote request.
-
#status_message ⇒ String
A message about the status of the quote.
-
#submitted_order_id ⇒ String
The ID of the order submitted for the quote.
Instance Attribute Details
#account_id ⇒ String
The ID of the account that owns the quote.
2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 |
# File 'lib/aws-sdk-outposts/types.rb', line 2509 class Quote < Struct.new( :quote_id, :account_id, :quote_status, :status_message, :outpost_arn, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :quote_options, :ordering_requirements, :submitted_order_id, :created_date, :expiration_date, :description) SENSITIVE = [:description] include Aws::Structure end |
#country_code ⇒ String
The country code for the Outpost site location.
2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 |
# File 'lib/aws-sdk-outposts/types.rb', line 2509 class Quote < Struct.new( :quote_id, :account_id, :quote_status, :status_message, :outpost_arn, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :quote_options, :ordering_requirements, :submitted_order_id, :created_date, :expiration_date, :description) SENSITIVE = [:description] include Aws::Structure end |
#created_date ⇒ Time
The date the quote was created.
2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 |
# File 'lib/aws-sdk-outposts/types.rb', line 2509 class Quote < Struct.new( :quote_id, :account_id, :quote_status, :status_message, :outpost_arn, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :quote_options, :ordering_requirements, :submitted_order_id, :created_date, :expiration_date, :description) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
The description of the quote.
2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 |
# File 'lib/aws-sdk-outposts/types.rb', line 2509 class Quote < Struct.new( :quote_id, :account_id, :quote_status, :status_message, :outpost_arn, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :quote_options, :ordering_requirements, :submitted_order_id, :created_date, :expiration_date, :description) SENSITIVE = [:description] include Aws::Structure end |
#expiration_date ⇒ Time
The date the quote expires.
2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 |
# File 'lib/aws-sdk-outposts/types.rb', line 2509 class Quote < Struct.new( :quote_id, :account_id, :quote_status, :status_message, :outpost_arn, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :quote_options, :ordering_requirements, :submitted_order_id, :created_date, :expiration_date, :description) SENSITIVE = [:description] include Aws::Structure end |
#ordering_requirements ⇒ Array<Types::OrderingRequirement>
The requirements that must be met before an order can be submitted for the quote.
2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 |
# File 'lib/aws-sdk-outposts/types.rb', line 2509 class Quote < Struct.new( :quote_id, :account_id, :quote_status, :status_message, :outpost_arn, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :quote_options, :ordering_requirements, :submitted_order_id, :created_date, :expiration_date, :description) SENSITIVE = [:description] include Aws::Structure end |
#outpost_arn ⇒ String
The ARN of the Outpost associated with the quote.
2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 |
# File 'lib/aws-sdk-outposts/types.rb', line 2509 class Quote < Struct.new( :quote_id, :account_id, :quote_status, :status_message, :outpost_arn, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :quote_options, :ordering_requirements, :submitted_order_id, :created_date, :expiration_date, :description) SENSITIVE = [:description] include Aws::Structure end |
#quote_id ⇒ String
The ID of the quote.
2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 |
# File 'lib/aws-sdk-outposts/types.rb', line 2509 class Quote < Struct.new( :quote_id, :account_id, :quote_status, :status_message, :outpost_arn, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :quote_options, :ordering_requirements, :submitted_order_id, :created_date, :expiration_date, :description) SENSITIVE = [:description] include Aws::Structure end |
#quote_options ⇒ Array<Types::QuoteOption>
The configuration and pricing options for the quote. Each option includes capacity details, physical specifications, and pricing information.
2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 |
# File 'lib/aws-sdk-outposts/types.rb', line 2509 class Quote < Struct.new( :quote_id, :account_id, :quote_status, :status_message, :outpost_arn, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :quote_options, :ordering_requirements, :submitted_order_id, :created_date, :expiration_date, :description) SENSITIVE = [:description] include Aws::Structure end |
#quote_status ⇒ String
The status of the quote.
-
‘CREATED` - The quote has been created and is available for review.
-
‘ORDER_SUBMITTED` - An order has been submitted for the quote.
-
‘EXPIRED` - The quote has expired and can no longer be used to submit an order.
2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 |
# File 'lib/aws-sdk-outposts/types.rb', line 2509 class Quote < Struct.new( :quote_id, :account_id, :quote_status, :status_message, :outpost_arn, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :quote_options, :ordering_requirements, :submitted_order_id, :created_date, :expiration_date, :description) SENSITIVE = [:description] include Aws::Structure end |
#requested_capacities ⇒ Array<Types::QuoteCapacity>
The capacity requirements specified in the quote request.
2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 |
# File 'lib/aws-sdk-outposts/types.rb', line 2509 class Quote < Struct.new( :quote_id, :account_id, :quote_status, :status_message, :outpost_arn, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :quote_options, :ordering_requirements, :submitted_order_id, :created_date, :expiration_date, :description) SENSITIVE = [:description] include Aws::Structure end |
#requested_constraints ⇒ Array<Types::QuoteConstraint>
The physical constraints specified in the quote request.
2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 |
# File 'lib/aws-sdk-outposts/types.rb', line 2509 class Quote < Struct.new( :quote_id, :account_id, :quote_status, :status_message, :outpost_arn, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :quote_options, :ordering_requirements, :submitted_order_id, :created_date, :expiration_date, :description) SENSITIVE = [:description] include Aws::Structure end |
#requested_payment_options ⇒ Array<String>
The payment options specified in the quote request.
2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 |
# File 'lib/aws-sdk-outposts/types.rb', line 2509 class Quote < Struct.new( :quote_id, :account_id, :quote_status, :status_message, :outpost_arn, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :quote_options, :ordering_requirements, :submitted_order_id, :created_date, :expiration_date, :description) SENSITIVE = [:description] include Aws::Structure end |
#requested_payment_terms ⇒ Array<String>
The payment terms specified in the quote request.
2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 |
# File 'lib/aws-sdk-outposts/types.rb', line 2509 class Quote < Struct.new( :quote_id, :account_id, :quote_status, :status_message, :outpost_arn, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :quote_options, :ordering_requirements, :submitted_order_id, :created_date, :expiration_date, :description) SENSITIVE = [:description] include Aws::Structure end |
#status_message ⇒ String
A message about the status of the quote.
2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 |
# File 'lib/aws-sdk-outposts/types.rb', line 2509 class Quote < Struct.new( :quote_id, :account_id, :quote_status, :status_message, :outpost_arn, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :quote_options, :ordering_requirements, :submitted_order_id, :created_date, :expiration_date, :description) SENSITIVE = [:description] include Aws::Structure end |
#submitted_order_id ⇒ String
The ID of the order submitted for the quote.
2509 2510 2511 2512 2513 2514 2515 2516 2517 2518 2519 2520 2521 2522 2523 2524 2525 2526 2527 2528 |
# File 'lib/aws-sdk-outposts/types.rb', line 2509 class Quote < Struct.new( :quote_id, :account_id, :quote_status, :status_message, :outpost_arn, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :quote_options, :ordering_requirements, :submitted_order_id, :created_date, :expiration_date, :description) SENSITIVE = [:description] include Aws::Structure end |