Class: Aws::Outposts::Types::QuoteCapacity
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::QuoteCapacity
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
A capacity requirement for a quote. Specifies the type of capacity, the unit, and the quantity.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#quantity ⇒ Float
The quantity of the specified capacity unit.
-
#quote_capacity_type ⇒ String
The type of capacity.
-
#unit ⇒ String
The unit of measurement for the capacity.
Instance Attribute Details
#quantity ⇒ Float
The quantity of the specified capacity unit. For Amazon EC2, this is the number of additional instances to add to the Outpost. For Amazon EBS and Amazon S3, this is the total desired end-state capacity of the Outpost.
2533 2534 2535 2536 2537 2538 2539 |
# File 'lib/aws-sdk-outposts/types.rb', line 2533 class QuoteCapacity < Struct.new( :quote_capacity_type, :unit, :quantity) SENSITIVE = [] include Aws::Structure end |
#quote_capacity_type ⇒ String
The type of capacity. Valid values are ‘EC2`, `EBS`, and `S3`.
2533 2534 2535 2536 2537 2538 2539 |
# File 'lib/aws-sdk-outposts/types.rb', line 2533 class QuoteCapacity < Struct.new( :quote_capacity_type, :unit, :quantity) SENSITIVE = [] include Aws::Structure end |
#unit ⇒ String
The unit of measurement for the capacity. For Amazon EC2, this is the instance type (for example, ‘c5.24xlarge`). For Amazon EBS and Amazon S3, this is the storage unit (for example, `TiB` for tebibytes).
2533 2534 2535 2536 2537 2538 2539 |
# File 'lib/aws-sdk-outposts/types.rb', line 2533 class QuoteCapacity < Struct.new( :quote_capacity_type, :unit, :quantity) SENSITIVE = [] include Aws::Structure end |