Class: Aws::Outposts::Types::QuoteSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::QuoteSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
A physical specification for a quote option. Describes the rack or server configuration that would be deployed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#existing_rack_specification_details ⇒ Types::RackSpecificationDetails
The existing rack specification details, if the specification type is ‘UPDATED_RACK` or `EXISTING_RACK`.
-
#final_rack_specification_details ⇒ Types::RackSpecificationDetails
The final rack specification details after the quote is fulfilled.
-
#quote_specification_type ⇒ String
The type of specification.
-
#server_specification_details ⇒ Types::ServerSpecificationDetails
The server specification details, if the specification type is ‘SERVER`.
Instance Attribute Details
#existing_rack_specification_details ⇒ Types::RackSpecificationDetails
The existing rack specification details, if the specification type is ‘UPDATED_RACK` or `EXISTING_RACK`.
2623 2624 2625 2626 2627 2628 2629 2630 |
# File 'lib/aws-sdk-outposts/types.rb', line 2623 class QuoteSpecification < Struct.new( :quote_specification_type, :existing_rack_specification_details, :final_rack_specification_details, :server_specification_details) SENSITIVE = [] include Aws::Structure end |
#final_rack_specification_details ⇒ Types::RackSpecificationDetails
The final rack specification details after the quote is fulfilled.
2623 2624 2625 2626 2627 2628 2629 2630 |
# File 'lib/aws-sdk-outposts/types.rb', line 2623 class QuoteSpecification < Struct.new( :quote_specification_type, :existing_rack_specification_details, :final_rack_specification_details, :server_specification_details) SENSITIVE = [] include Aws::Structure end |
#quote_specification_type ⇒ String
The type of specification. Valid values are ‘NEW_RACK`, `UPDATED_RACK`, `EXISTING_RACK`, and `SERVER`.
2623 2624 2625 2626 2627 2628 2629 2630 |
# File 'lib/aws-sdk-outposts/types.rb', line 2623 class QuoteSpecification < Struct.new( :quote_specification_type, :existing_rack_specification_details, :final_rack_specification_details, :server_specification_details) SENSITIVE = [] include Aws::Structure end |
#server_specification_details ⇒ Types::ServerSpecificationDetails
The server specification details, if the specification type is ‘SERVER`.
2623 2624 2625 2626 2627 2628 2629 2630 |
# File 'lib/aws-sdk-outposts/types.rb', line 2623 class QuoteSpecification < Struct.new( :quote_specification_type, :existing_rack_specification_details, :final_rack_specification_details, :server_specification_details) SENSITIVE = [] include Aws::Structure end |