Class: Aws::Outposts::Types::RackPhysicalProperties

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Information about the physical and logistical details for racks at sites. For more information about hardware requirements for racks, see

Network readiness checklist][1

in the Amazon Web Services Outposts

User Guide.

[1]: docs.aws.amazon.com/outposts/latest/userguide/outposts-requirements.html#checklist

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fiber_optic_cable_typeString

The type of fiber used to attach the Outpost to the network.

Returns:

  • (String)


2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
# File 'lib/aws-sdk-outposts/types.rb', line 2793

class RackPhysicalProperties < Struct.new(
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_supported_weight_lbsString

The maximum rack weight that this site can support. ‘NO_LIMIT` is over 2000 lbs (907 kg).

Returns:

  • (String)


2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
# File 'lib/aws-sdk-outposts/types.rb', line 2793

class RackPhysicalProperties < Struct.new(
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

#optical_standardString

The type of optical standard used to attach the Outpost to the network. This field is dependent on uplink speed, fiber type, and distance to the upstream device. For more information about networking requirements for racks, see [Network] in the Amazon Web Services Outposts User Guide.

[1]: docs.aws.amazon.com/outposts/latest/userguide/outposts-requirements.html#facility-networking

Returns:

  • (String)


2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
# File 'lib/aws-sdk-outposts/types.rb', line 2793

class RackPhysicalProperties < Struct.new(
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

#power_connectorString

The power connector for the hardware.

Returns:

  • (String)


2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
# File 'lib/aws-sdk-outposts/types.rb', line 2793

class RackPhysicalProperties < Struct.new(
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

#power_draw_kvaString

The power draw available at the hardware placement position for the rack.

Returns:

  • (String)


2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
# File 'lib/aws-sdk-outposts/types.rb', line 2793

class RackPhysicalProperties < Struct.new(
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

#power_feed_dropString

The position of the power feed.

Returns:

  • (String)


2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
# File 'lib/aws-sdk-outposts/types.rb', line 2793

class RackPhysicalProperties < Struct.new(
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

#power_phaseString

The power option that you can provide for hardware.

Returns:

  • (String)


2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
# File 'lib/aws-sdk-outposts/types.rb', line 2793

class RackPhysicalProperties < Struct.new(
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

The number of uplinks each Outpost network device.

Returns:

  • (String)


2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
# File 'lib/aws-sdk-outposts/types.rb', line 2793

class RackPhysicalProperties < Struct.new(
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

The uplink speed the rack supports for the connection to the Region.

Returns:

  • (String)


2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
# File 'lib/aws-sdk-outposts/types.rb', line 2793

class RackPhysicalProperties < Struct.new(
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end