Class: Aws::Outposts::Types::RackPhysicalProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::RackPhysicalProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Information about the physical and logistical details for racks at sites. For more information about hardware requirements for racks, see
- Network readiness checklist][1
-
in the Amazon Web Services Outposts
User Guide.
[1]: docs.aws.amazon.com/outposts/latest/userguide/outposts-requirements.html#checklist
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fiber_optic_cable_type ⇒ String
The type of fiber used to attach the Outpost to the network.
-
#maximum_supported_weight_lbs ⇒ String
The maximum rack weight that this site can support.
-
#optical_standard ⇒ String
The type of optical standard used to attach the Outpost to the network.
-
#power_connector ⇒ String
The power connector for the hardware.
-
#power_draw_kva ⇒ String
The power draw available at the hardware placement position for the rack.
-
#power_feed_drop ⇒ String
The position of the power feed.
-
#power_phase ⇒ String
The power option that you can provide for hardware.
-
#uplink_count ⇒ String
The number of uplinks each Outpost network device.
-
#uplink_gbps ⇒ String
The uplink speed the rack supports for the connection to the Region.
Instance Attribute Details
#fiber_optic_cable_type ⇒ String
The type of fiber used to attach the Outpost to the network.
2793 2794 2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/aws-sdk-outposts/types.rb', line 2793 class RackPhysicalProperties < Struct.new( :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#maximum_supported_weight_lbs ⇒ String
The maximum rack weight that this site can support. ‘NO_LIMIT` is over 2000 lbs (907 kg).
2793 2794 2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/aws-sdk-outposts/types.rb', line 2793 class RackPhysicalProperties < Struct.new( :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#optical_standard ⇒ String
The type of optical standard used to attach the Outpost to the network. This field is dependent on uplink speed, fiber type, and distance to the upstream device. For more information about networking requirements for racks, see [Network] in the Amazon Web Services Outposts User Guide.
[1]: docs.aws.amazon.com/outposts/latest/userguide/outposts-requirements.html#facility-networking
2793 2794 2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/aws-sdk-outposts/types.rb', line 2793 class RackPhysicalProperties < Struct.new( :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#power_connector ⇒ String
The power connector for the hardware.
2793 2794 2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/aws-sdk-outposts/types.rb', line 2793 class RackPhysicalProperties < Struct.new( :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#power_draw_kva ⇒ String
The power draw available at the hardware placement position for the rack.
2793 2794 2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/aws-sdk-outposts/types.rb', line 2793 class RackPhysicalProperties < Struct.new( :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#power_feed_drop ⇒ String
The position of the power feed.
2793 2794 2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/aws-sdk-outposts/types.rb', line 2793 class RackPhysicalProperties < Struct.new( :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#power_phase ⇒ String
The power option that you can provide for hardware.
2793 2794 2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/aws-sdk-outposts/types.rb', line 2793 class RackPhysicalProperties < Struct.new( :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#uplink_count ⇒ String
The number of uplinks each Outpost network device.
2793 2794 2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/aws-sdk-outposts/types.rb', line 2793 class RackPhysicalProperties < Struct.new( :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#uplink_gbps ⇒ String
The uplink speed the rack supports for the connection to the Region.
2793 2794 2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 |
# File 'lib/aws-sdk-outposts/types.rb', line 2793 class RackPhysicalProperties < Struct.new( :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |