Class: Aws::Outposts::Types::RackPhysicalProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::RackPhysicalProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
When making an API call, you may pass RackPhysicalProperties data as a hash:
{
power_draw_kva: "POWER_5_KVA", # accepts POWER_5_KVA, POWER_10_KVA, POWER_15_KVA
power_phase: "SINGLE_PHASE", # accepts SINGLE_PHASE, THREE_PHASE
power_connector: "L6_30P", # accepts L6_30P, IEC309, AH530P7W, AH532P6W
power_feed_drop: "ABOVE_RACK", # accepts ABOVE_RACK, BELOW_RACK
uplink_gbps: "UPLINK_1G", # accepts UPLINK_1G, UPLINK_10G, UPLINK_40G, UPLINK_100G
uplink_count: "UPLINK_COUNT_1", # accepts UPLINK_COUNT_1, UPLINK_COUNT_2, UPLINK_COUNT_3, UPLINK_COUNT_4, UPLINK_COUNT_5, UPLINK_COUNT_6, UPLINK_COUNT_7, UPLINK_COUNT_8, UPLINK_COUNT_12, UPLINK_COUNT_16
fiber_optic_cable_type: "SINGLE_MODE", # accepts SINGLE_MODE, MULTI_MODE
optical_standard: "OPTIC_10GBASE_SR", # accepts OPTIC_10GBASE_SR, OPTIC_10GBASE_IR, OPTIC_10GBASE_LR, OPTIC_40GBASE_SR, OPTIC_40GBASE_ESR, OPTIC_40GBASE_IR4_LR4L, OPTIC_40GBASE_LR4, OPTIC_100GBASE_SR4, OPTIC_100GBASE_CWDM4, OPTIC_100GBASE_LR4, OPTIC_100G_PSM4_MSA, OPTIC_1000BASE_LX, OPTIC_1000BASE_SX
maximum_supported_weight_lbs: "NO_LIMIT", # accepts NO_LIMIT, MAX_1400_LBS, MAX_1600_LBS, MAX_1800_LBS, MAX_2000_LBS
}
Information about the physical and logistical details for racks at sites. For more information about hardware requirements for racks, see
- Network readiness checklist][1
-
in the Amazon Web Services Outposts
User Guide.
[1]: docs.aws.amazon.com/outposts/latest/userguide/outposts-requirements.html#checklist
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fiber_optic_cable_type ⇒ String
The type of fiber used to attach the Outpost to the network.
-
#maximum_supported_weight_lbs ⇒ String
The maximum rack weight that this site can support.
-
#optical_standard ⇒ String
The type of optical standard used to attach the Outpost to the network.
-
#power_connector ⇒ String
The power connector for the hardware.
-
#power_draw_kva ⇒ String
The power draw available at the hardware placement position for the rack.
-
#power_feed_drop ⇒ String
The position of the power feed.
-
#power_phase ⇒ String
The power option that you can provide for hardware.
-
#uplink_count ⇒ String
The number of uplinks each Outpost network device.
-
#uplink_gbps ⇒ String
The uplink speed the rack supports for the connection to the Region.
Instance Attribute Details
#fiber_optic_cable_type ⇒ String
The type of fiber used to attach the Outpost to the network.
1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 |
# File 'lib/aws-sdk-outposts/types.rb', line 1357 class RackPhysicalProperties < Struct.new( :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#maximum_supported_weight_lbs ⇒ String
The maximum rack weight that this site can support. `NO_LIMIT` is over 2000 lbs (907 kg).
1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 |
# File 'lib/aws-sdk-outposts/types.rb', line 1357 class RackPhysicalProperties < Struct.new( :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#optical_standard ⇒ String
The type of optical standard used to attach the Outpost to the network. This field is dependent on uplink speed, fiber type, and distance to the upstream device. For more information about networking requirements for racks, see [Network] in the Amazon Web Services Outposts User Guide.
[1]: docs.aws.amazon.com/outposts/latest/userguide/outposts-requirements.html#facility-networking
1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 |
# File 'lib/aws-sdk-outposts/types.rb', line 1357 class RackPhysicalProperties < Struct.new( :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#power_connector ⇒ String
The power connector for the hardware.
1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 |
# File 'lib/aws-sdk-outposts/types.rb', line 1357 class RackPhysicalProperties < Struct.new( :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#power_draw_kva ⇒ String
The power draw available at the hardware placement position for the rack.
1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 |
# File 'lib/aws-sdk-outposts/types.rb', line 1357 class RackPhysicalProperties < Struct.new( :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#power_feed_drop ⇒ String
The position of the power feed.
1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 |
# File 'lib/aws-sdk-outposts/types.rb', line 1357 class RackPhysicalProperties < Struct.new( :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#power_phase ⇒ String
The power option that you can provide for hardware.
1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 |
# File 'lib/aws-sdk-outposts/types.rb', line 1357 class RackPhysicalProperties < Struct.new( :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#uplink_count ⇒ String
The number of uplinks each Outpost network device.
1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 |
# File 'lib/aws-sdk-outposts/types.rb', line 1357 class RackPhysicalProperties < Struct.new( :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#uplink_gbps ⇒ String
The uplink speed the rack supports for the connection to the Region.
1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 |
# File 'lib/aws-sdk-outposts/types.rb', line 1357 class RackPhysicalProperties < Struct.new( :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |