Class: Aws::Outposts::Types::RackSpecificationDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::RackSpecificationDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
The physical specification details for a rack in a quote option.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ec2_capacities ⇒ Array<Types::EC2Capacity>
The Amazon EC2 capacities for the rack.
-
#rack_depth_inches ⇒ Float
The depth of the rack in inches.
-
#rack_height_inches ⇒ Float
The height of the rack in inches.
-
#rack_id ⇒ String
The ID of the rack.
-
#rack_power_draw_kva ⇒ Float
The maximum power draw of the rack in kVA.
-
#rack_unit_height ⇒ String
The rack unit height.
-
#rack_use ⇒ String
The use of the rack.
-
#rack_weight_lbs ⇒ Float
The weight of the rack in pounds.
-
#rack_width_inches ⇒ Float
The width of the rack in inches.
Instance Attribute Details
#ec2_capacities ⇒ Array<Types::EC2Capacity>
The Amazon EC2 capacities for the rack.
2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 2844 2845 |
# File 'lib/aws-sdk-outposts/types.rb', line 2833 class RackSpecificationDetails < Struct.new( :rack_id, :rack_use, :rack_power_draw_kva, :rack_weight_lbs, :rack_height_inches, :rack_width_inches, :rack_depth_inches, :rack_unit_height, :ec2_capacities) SENSITIVE = [] include Aws::Structure end |
#rack_depth_inches ⇒ Float
The depth of the rack in inches.
2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 2844 2845 |
# File 'lib/aws-sdk-outposts/types.rb', line 2833 class RackSpecificationDetails < Struct.new( :rack_id, :rack_use, :rack_power_draw_kva, :rack_weight_lbs, :rack_height_inches, :rack_width_inches, :rack_depth_inches, :rack_unit_height, :ec2_capacities) SENSITIVE = [] include Aws::Structure end |
#rack_height_inches ⇒ Float
The height of the rack in inches.
2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 2844 2845 |
# File 'lib/aws-sdk-outposts/types.rb', line 2833 class RackSpecificationDetails < Struct.new( :rack_id, :rack_use, :rack_power_draw_kva, :rack_weight_lbs, :rack_height_inches, :rack_width_inches, :rack_depth_inches, :rack_unit_height, :ec2_capacities) SENSITIVE = [] include Aws::Structure end |
#rack_id ⇒ String
The ID of the rack.
2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 2844 2845 |
# File 'lib/aws-sdk-outposts/types.rb', line 2833 class RackSpecificationDetails < Struct.new( :rack_id, :rack_use, :rack_power_draw_kva, :rack_weight_lbs, :rack_height_inches, :rack_width_inches, :rack_depth_inches, :rack_unit_height, :ec2_capacities) SENSITIVE = [] include Aws::Structure end |
#rack_power_draw_kva ⇒ Float
The maximum power draw of the rack in kVA.
2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 2844 2845 |
# File 'lib/aws-sdk-outposts/types.rb', line 2833 class RackSpecificationDetails < Struct.new( :rack_id, :rack_use, :rack_power_draw_kva, :rack_weight_lbs, :rack_height_inches, :rack_width_inches, :rack_depth_inches, :rack_unit_height, :ec2_capacities) SENSITIVE = [] include Aws::Structure end |
#rack_unit_height ⇒ String
The rack unit height.
-
‘HEIGHT_42U` - 42 rack units.
-
‘HEIGHT_2U` - 2 rack units.
-
‘HEIGHT_1U` - 1 rack unit.
2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 2844 2845 |
# File 'lib/aws-sdk-outposts/types.rb', line 2833 class RackSpecificationDetails < Struct.new( :rack_id, :rack_use, :rack_power_draw_kva, :rack_weight_lbs, :rack_height_inches, :rack_width_inches, :rack_depth_inches, :rack_unit_height, :ec2_capacities) SENSITIVE = [] include Aws::Structure end |
#rack_use ⇒ String
The use of the rack. Valid values are ‘COMPUTE` and `NETWORKING`.
2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 2844 2845 |
# File 'lib/aws-sdk-outposts/types.rb', line 2833 class RackSpecificationDetails < Struct.new( :rack_id, :rack_use, :rack_power_draw_kva, :rack_weight_lbs, :rack_height_inches, :rack_width_inches, :rack_depth_inches, :rack_unit_height, :ec2_capacities) SENSITIVE = [] include Aws::Structure end |
#rack_weight_lbs ⇒ Float
The weight of the rack in pounds.
2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 2844 2845 |
# File 'lib/aws-sdk-outposts/types.rb', line 2833 class RackSpecificationDetails < Struct.new( :rack_id, :rack_use, :rack_power_draw_kva, :rack_weight_lbs, :rack_height_inches, :rack_width_inches, :rack_depth_inches, :rack_unit_height, :ec2_capacities) SENSITIVE = [] include Aws::Structure end |
#rack_width_inches ⇒ Float
The width of the rack in inches.
2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 2844 2845 |
# File 'lib/aws-sdk-outposts/types.rb', line 2833 class RackSpecificationDetails < Struct.new( :rack_id, :rack_use, :rack_power_draw_kva, :rack_weight_lbs, :rack_height_inches, :rack_width_inches, :rack_depth_inches, :rack_unit_height, :ec2_capacities) SENSITIVE = [] include Aws::Structure end |