Class: Aws::Outposts::Types::ServerSpecificationDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

The physical specification details for a server in a quote option.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ec2_capacitiesArray<Types::EC2Capacity>

The Amazon EC2 capacities for the server.

Returns:



2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
# File 'lib/aws-sdk-outposts/types.rb', line 2883

class ServerSpecificationDetails < Struct.new(
  :server_power_draw_kva,
  :server_weight_lbs,
  :server_height_inches,
  :server_width_inches,
  :server_depth_inches,
  :rack_unit_height,
  :ec2_capacities)
  SENSITIVE = []
  include Aws::Structure
end

#rack_unit_heightString

The rack unit height of the server.

  • ‘HEIGHT_2U` - 2 rack units.

  • ‘HEIGHT_1U` - 1 rack unit.

Returns:

  • (String)


2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
# File 'lib/aws-sdk-outposts/types.rb', line 2883

class ServerSpecificationDetails < Struct.new(
  :server_power_draw_kva,
  :server_weight_lbs,
  :server_height_inches,
  :server_width_inches,
  :server_depth_inches,
  :rack_unit_height,
  :ec2_capacities)
  SENSITIVE = []
  include Aws::Structure
end

#server_depth_inchesFloat

The depth of the server in inches.

Returns:

  • (Float)


2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
# File 'lib/aws-sdk-outposts/types.rb', line 2883

class ServerSpecificationDetails < Struct.new(
  :server_power_draw_kva,
  :server_weight_lbs,
  :server_height_inches,
  :server_width_inches,
  :server_depth_inches,
  :rack_unit_height,
  :ec2_capacities)
  SENSITIVE = []
  include Aws::Structure
end

#server_height_inchesFloat

The height of the server in inches.

Returns:

  • (Float)


2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
# File 'lib/aws-sdk-outposts/types.rb', line 2883

class ServerSpecificationDetails < Struct.new(
  :server_power_draw_kva,
  :server_weight_lbs,
  :server_height_inches,
  :server_width_inches,
  :server_depth_inches,
  :rack_unit_height,
  :ec2_capacities)
  SENSITIVE = []
  include Aws::Structure
end

#server_power_draw_kvaFloat

The maximum power draw of the server in kVA.

Returns:

  • (Float)


2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
# File 'lib/aws-sdk-outposts/types.rb', line 2883

class ServerSpecificationDetails < Struct.new(
  :server_power_draw_kva,
  :server_weight_lbs,
  :server_height_inches,
  :server_width_inches,
  :server_depth_inches,
  :rack_unit_height,
  :ec2_capacities)
  SENSITIVE = []
  include Aws::Structure
end

#server_weight_lbsFloat

The weight of the server in pounds.

Returns:

  • (Float)


2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
# File 'lib/aws-sdk-outposts/types.rb', line 2883

class ServerSpecificationDetails < Struct.new(
  :server_power_draw_kva,
  :server_weight_lbs,
  :server_height_inches,
  :server_width_inches,
  :server_depth_inches,
  :rack_unit_height,
  :ec2_capacities)
  SENSITIVE = []
  include Aws::Structure
end

#server_width_inchesFloat

The width of the server in inches.

Returns:

  • (Float)


2883
2884
2885
2886
2887
2888
2889
2890
2891
2892
2893
# File 'lib/aws-sdk-outposts/types.rb', line 2883

class ServerSpecificationDetails < Struct.new(
  :server_power_draw_kva,
  :server_weight_lbs,
  :server_height_inches,
  :server_width_inches,
  :server_depth_inches,
  :rack_unit_height,
  :ec2_capacities)
  SENSITIVE = []
  include Aws::Structure
end