Class: Aws::Outposts::Types::ServerSpecificationDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::ServerSpecificationDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
The physical specification details for a server in a quote option.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ec2_capacities ⇒ Array<Types::EC2Capacity>
The Amazon EC2 capacities for the server.
-
#rack_unit_height ⇒ String
The rack unit height of the server.
-
#server_depth_inches ⇒ Float
The depth of the server in inches.
-
#server_height_inches ⇒ Float
The height of the server in inches.
-
#server_power_draw_kva ⇒ Float
The maximum power draw of the server in kVA.
-
#server_weight_lbs ⇒ Float
The weight of the server in pounds.
-
#server_width_inches ⇒ Float
The width of the server in inches.
Instance Attribute Details
#ec2_capacities ⇒ Array<Types::EC2Capacity>
The Amazon EC2 capacities for the server.
2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 |
# File 'lib/aws-sdk-outposts/types.rb', line 2883 class ServerSpecificationDetails < Struct.new( :server_power_draw_kva, :server_weight_lbs, :server_height_inches, :server_width_inches, :server_depth_inches, :rack_unit_height, :ec2_capacities) SENSITIVE = [] include Aws::Structure end |
#rack_unit_height ⇒ String
The rack unit height of the server.
-
‘HEIGHT_2U` - 2 rack units.
-
‘HEIGHT_1U` - 1 rack unit.
2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 |
# File 'lib/aws-sdk-outposts/types.rb', line 2883 class ServerSpecificationDetails < Struct.new( :server_power_draw_kva, :server_weight_lbs, :server_height_inches, :server_width_inches, :server_depth_inches, :rack_unit_height, :ec2_capacities) SENSITIVE = [] include Aws::Structure end |
#server_depth_inches ⇒ Float
The depth of the server in inches.
2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 |
# File 'lib/aws-sdk-outposts/types.rb', line 2883 class ServerSpecificationDetails < Struct.new( :server_power_draw_kva, :server_weight_lbs, :server_height_inches, :server_width_inches, :server_depth_inches, :rack_unit_height, :ec2_capacities) SENSITIVE = [] include Aws::Structure end |
#server_height_inches ⇒ Float
The height of the server in inches.
2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 |
# File 'lib/aws-sdk-outposts/types.rb', line 2883 class ServerSpecificationDetails < Struct.new( :server_power_draw_kva, :server_weight_lbs, :server_height_inches, :server_width_inches, :server_depth_inches, :rack_unit_height, :ec2_capacities) SENSITIVE = [] include Aws::Structure end |
#server_power_draw_kva ⇒ Float
The maximum power draw of the server in kVA.
2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 |
# File 'lib/aws-sdk-outposts/types.rb', line 2883 class ServerSpecificationDetails < Struct.new( :server_power_draw_kva, :server_weight_lbs, :server_height_inches, :server_width_inches, :server_depth_inches, :rack_unit_height, :ec2_capacities) SENSITIVE = [] include Aws::Structure end |
#server_weight_lbs ⇒ Float
The weight of the server in pounds.
2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 |
# File 'lib/aws-sdk-outposts/types.rb', line 2883 class ServerSpecificationDetails < Struct.new( :server_power_draw_kva, :server_weight_lbs, :server_height_inches, :server_width_inches, :server_depth_inches, :rack_unit_height, :ec2_capacities) SENSITIVE = [] include Aws::Structure end |
#server_width_inches ⇒ Float
The width of the server in inches.
2883 2884 2885 2886 2887 2888 2889 2890 2891 2892 2893 |
# File 'lib/aws-sdk-outposts/types.rb', line 2883 class ServerSpecificationDetails < Struct.new( :server_power_draw_kva, :server_weight_lbs, :server_height_inches, :server_width_inches, :server_depth_inches, :rack_unit_height, :ec2_capacities) SENSITIVE = [] include Aws::Structure end |