Class: Aws::Outposts::Types::StartCapacityTaskInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::StartCapacityTaskInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#asset_id ⇒ String
The ID of the Outpost asset.
-
#dry_run ⇒ Boolean
You can request a dry run to determine if the instance type and instance size changes is above or below available instance capacity.
-
#instance_pools ⇒ Array<Types::InstanceTypeCapacity>
The instance pools specified in the capacity task.
-
#instances_to_exclude ⇒ Types::InstancesToExclude
List of user-specified running instances that must not be stopped in order to free up the capacity needed to run the capacity task.
-
#order_id ⇒ String
The ID of the Amazon Web Services Outposts order associated with the specified capacity task.
-
#outpost_identifier ⇒ String
The ID or ARN of the Outposts associated with the specified capacity task.
-
#task_action_on_blocking_instances ⇒ String
Specify one of the following options in case an instance is blocking the capacity task from running.
Instance Attribute Details
#asset_id ⇒ String
The ID of the Outpost asset. An Outpost asset can be a single server within an Outposts rack or an Outposts server configuration.
3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-outposts/types.rb', line 3036 class StartCapacityTaskInput < Struct.new( :outpost_identifier, :order_id, :asset_id, :instance_pools, :instances_to_exclude, :dry_run, :task_action_on_blocking_instances) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
You can request a dry run to determine if the instance type and instance size changes is above or below available instance capacity. Requesting a dry run does not make any changes to your plan.
3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-outposts/types.rb', line 3036 class StartCapacityTaskInput < Struct.new( :outpost_identifier, :order_id, :asset_id, :instance_pools, :instances_to_exclude, :dry_run, :task_action_on_blocking_instances) SENSITIVE = [] include Aws::Structure end |
#instance_pools ⇒ Array<Types::InstanceTypeCapacity>
The instance pools specified in the capacity task.
3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-outposts/types.rb', line 3036 class StartCapacityTaskInput < Struct.new( :outpost_identifier, :order_id, :asset_id, :instance_pools, :instances_to_exclude, :dry_run, :task_action_on_blocking_instances) SENSITIVE = [] include Aws::Structure end |
#instances_to_exclude ⇒ Types::InstancesToExclude
List of user-specified running instances that must not be stopped in order to free up the capacity needed to run the capacity task.
3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-outposts/types.rb', line 3036 class StartCapacityTaskInput < Struct.new( :outpost_identifier, :order_id, :asset_id, :instance_pools, :instances_to_exclude, :dry_run, :task_action_on_blocking_instances) SENSITIVE = [] include Aws::Structure end |
#order_id ⇒ String
The ID of the Amazon Web Services Outposts order associated with the specified capacity task.
3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-outposts/types.rb', line 3036 class StartCapacityTaskInput < Struct.new( :outpost_identifier, :order_id, :asset_id, :instance_pools, :instances_to_exclude, :dry_run, :task_action_on_blocking_instances) SENSITIVE = [] include Aws::Structure end |
#outpost_identifier ⇒ String
The ID or ARN of the Outposts associated with the specified capacity task.
3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-outposts/types.rb', line 3036 class StartCapacityTaskInput < Struct.new( :outpost_identifier, :order_id, :asset_id, :instance_pools, :instances_to_exclude, :dry_run, :task_action_on_blocking_instances) SENSITIVE = [] include Aws::Structure end |
#task_action_on_blocking_instances ⇒ String
Specify one of the following options in case an instance is blocking the capacity task from running.
-
‘WAIT_FOR_EVACUATION` - Checks every 10 minutes over 48 hours to determine if instances have stopped and capacity is available to complete the task.
-
‘FAIL_TASK` - The capacity task fails.
3036 3037 3038 3039 3040 3041 3042 3043 3044 3045 3046 |
# File 'lib/aws-sdk-outposts/types.rb', line 3036 class StartCapacityTaskInput < Struct.new( :outpost_identifier, :order_id, :asset_id, :instance_pools, :instances_to_exclude, :dry_run, :task_action_on_blocking_instances) SENSITIVE = [] include Aws::Structure end |