Class: Aws::Outposts::Types::StartCapacityTaskOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#capacity_task_idString

ID of the capacity task that you want to start.



1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
# File 'lib/aws-sdk-outposts/types.rb', line 1840

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#capacity_task_statusString

Status of the specified capacity task.



1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
# File 'lib/aws-sdk-outposts/types.rb', line 1840

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#completion_dateTime

Date that the specified capacity task ran successfully.



1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
# File 'lib/aws-sdk-outposts/types.rb', line 1840

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateTime

Date that the specified capacity task was created.



1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
# File 'lib/aws-sdk-outposts/types.rb', line 1840

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#dry_runBoolean

Results of the dry run showing if the specified capacity task is above or below the available instance capacity.



1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
# File 'lib/aws-sdk-outposts/types.rb', line 1840

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#failedTypes::CapacityTaskFailure

Reason that the specified capacity task failed.



1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
# File 'lib/aws-sdk-outposts/types.rb', line 1840

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_dateTime

Date that the specified capacity task was last modified.



1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
# File 'lib/aws-sdk-outposts/types.rb', line 1840

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#order_idString

ID of the Amazon Web Services Outposts order of the host associated with the capacity task.



1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
# File 'lib/aws-sdk-outposts/types.rb', line 1840

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#outpost_idString

ID of the Outpost associated with the capacity task.



1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
# File 'lib/aws-sdk-outposts/types.rb', line 1840

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end

#requested_instance_poolsArray<Types::InstanceTypeCapacity>

List of the instance pools requested in the specified capacity task.



1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
1850
1851
1852
1853
# File 'lib/aws-sdk-outposts/types.rb', line 1840

class StartCapacityTaskOutput < Struct.new(
  :capacity_task_id,
  :outpost_id,
  :order_id,
  :requested_instance_pools,
  :dry_run,
  :capacity_task_status,
  :failed,
  :creation_date,
  :completion_date,
  :last_modified_date)
  SENSITIVE = []
  include Aws::Structure
end