Class: Aws::Outposts::Types::UpdateOutpostInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::UpdateOutpostInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Note:
When making an API call, you may pass UpdateOutpostInput data as a hash:
{
outpost_id: "OutpostId", # required
name: "OutpostName",
description: "OutpostDescription",
supported_hardware_type: "RACK", # accepts RACK, SERVER
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the Outpost.
-
#name ⇒ String
The name of the Outpost.
-
#outpost_id ⇒ String
The ID or the Amazon Resource Name (ARN) of the Outpost.
-
#supported_hardware_type ⇒ String
The type of hardware for this Outpost.
Instance Attribute Details
#description ⇒ String
The description of the Outpost.
1870 1871 1872 1873 1874 1875 1876 1877 |
# File 'lib/aws-sdk-outposts/types.rb', line 1870 class UpdateOutpostInput < Struct.new( :outpost_id, :name, :description, :supported_hardware_type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the Outpost.
1870 1871 1872 1873 1874 1875 1876 1877 |
# File 'lib/aws-sdk-outposts/types.rb', line 1870 class UpdateOutpostInput < Struct.new( :outpost_id, :name, :description, :supported_hardware_type) SENSITIVE = [] include Aws::Structure end |
#outpost_id ⇒ String
The ID or the Amazon Resource Name (ARN) of the Outpost.
<note markdown=“1”> In requests, Amazon Web Services Outposts accepts the Amazon Resource Name (ARN) or an ID for Outposts and sites throughout the Outposts Query API. To address backwards compatibility, the parameter names `OutpostID` or `SiteID` remain in use. Despite the parameter name, you can make the request with an ARN.
</note>
1870 1871 1872 1873 1874 1875 1876 1877 |
# File 'lib/aws-sdk-outposts/types.rb', line 1870 class UpdateOutpostInput < Struct.new( :outpost_id, :name, :description, :supported_hardware_type) SENSITIVE = [] include Aws::Structure end |
#supported_hardware_type ⇒ String
The type of hardware for this Outpost.
1870 1871 1872 1873 1874 1875 1876 1877 |
# File 'lib/aws-sdk-outposts/types.rb', line 1870 class UpdateOutpostInput < Struct.new( :outpost_id, :name, :description, :supported_hardware_type) SENSITIVE = [] include Aws::Structure end |