Class: Aws::Outposts::Types::UpdateQuoteInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:description]

Instance Attribute Summary collapse

Instance Attribute Details

#country_codeString

The country code for the Outpost site location.

Returns:

  • (String)


3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
# File 'lib/aws-sdk-outposts/types.rb', line 3457

class UpdateQuoteInput < Struct.new(
  :quote_identifier,
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#descriptionString

A description for the quote.

Returns:

  • (String)


3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
# File 'lib/aws-sdk-outposts/types.rb', line 3457

class UpdateQuoteInput < Struct.new(
  :quote_identifier,
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#outpost_identifierString

The ID or ARN of the Outpost to associate with the quote. Specify an empty string to remove the Outpost association.

Returns:

  • (String)


3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
# File 'lib/aws-sdk-outposts/types.rb', line 3457

class UpdateQuoteInput < Struct.new(
  :quote_identifier,
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#quote_identifierString

The ID of the quote.

Returns:

  • (String)


3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
# File 'lib/aws-sdk-outposts/types.rb', line 3457

class UpdateQuoteInput < Struct.new(
  :quote_identifier,
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#requested_capacitiesArray<Types::QuoteCapacity>

The updated capacity requirements for the quote.

Returns:



3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
# File 'lib/aws-sdk-outposts/types.rb', line 3457

class UpdateQuoteInput < Struct.new(
  :quote_identifier,
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#requested_constraintsArray<Types::QuoteConstraint>

The updated physical constraints for the quote.

Returns:



3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
# File 'lib/aws-sdk-outposts/types.rb', line 3457

class UpdateQuoteInput < Struct.new(
  :quote_identifier,
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#requested_payment_optionsArray<String>

The updated payment options to include in the quote pricing.

Returns:

  • (Array<String>)


3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
# File 'lib/aws-sdk-outposts/types.rb', line 3457

class UpdateQuoteInput < Struct.new(
  :quote_identifier,
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end

#requested_payment_termsArray<String>

The updated payment terms to include in the quote pricing.

Returns:

  • (Array<String>)


3457
3458
3459
3460
3461
3462
3463
3464
3465
3466
3467
3468
# File 'lib/aws-sdk-outposts/types.rb', line 3457

class UpdateQuoteInput < Struct.new(
  :quote_identifier,
  :outpost_identifier,
  :country_code,
  :requested_capacities,
  :requested_constraints,
  :requested_payment_options,
  :requested_payment_terms,
  :description)
  SENSITIVE = [:description]
  include Aws::Structure
end