Class: Aws::Outposts::Types::UpdateQuoteInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::UpdateQuoteInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:description]
Instance Attribute Summary collapse
-
#country_code ⇒ String
The country code for the Outpost site location.
-
#description ⇒ String
A description for the quote.
-
#outpost_identifier ⇒ String
The ID or ARN of the Outpost to associate with the quote.
-
#quote_identifier ⇒ String
The ID or ARN of the quote.
-
#requested_capacities ⇒ Array<Types::QuoteCapacity>
The updated capacity requirements for the quote.
-
#requested_constraints ⇒ Array<Types::QuoteConstraint>
The updated physical constraints for the quote.
-
#requested_payment_options ⇒ Array<String>
The updated payment options to include in the quote pricing.
-
#requested_payment_terms ⇒ Array<String>
The updated payment terms to include in the quote pricing.
Instance Attribute Details
#country_code ⇒ String
The country code for the Outpost site location.
3437 3438 3439 3440 3441 3442 3443 3444 3445 3446 3447 3448 |
# File 'lib/aws-sdk-outposts/types.rb', line 3437 class UpdateQuoteInput < Struct.new( :quote_identifier, :outpost_identifier, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :description) SENSITIVE = [:description] include Aws::Structure end |
#description ⇒ String
A description for the quote.
3437 3438 3439 3440 3441 3442 3443 3444 3445 3446 3447 3448 |
# File 'lib/aws-sdk-outposts/types.rb', line 3437 class UpdateQuoteInput < Struct.new( :quote_identifier, :outpost_identifier, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :description) SENSITIVE = [:description] include Aws::Structure end |
#outpost_identifier ⇒ String
The ID or ARN of the Outpost to associate with the quote. Specify an empty string to remove the Outpost association.
3437 3438 3439 3440 3441 3442 3443 3444 3445 3446 3447 3448 |
# File 'lib/aws-sdk-outposts/types.rb', line 3437 class UpdateQuoteInput < Struct.new( :quote_identifier, :outpost_identifier, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :description) SENSITIVE = [:description] include Aws::Structure end |
#quote_identifier ⇒ String
The ID or ARN of the quote.
3437 3438 3439 3440 3441 3442 3443 3444 3445 3446 3447 3448 |
# File 'lib/aws-sdk-outposts/types.rb', line 3437 class UpdateQuoteInput < Struct.new( :quote_identifier, :outpost_identifier, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :description) SENSITIVE = [:description] include Aws::Structure end |
#requested_capacities ⇒ Array<Types::QuoteCapacity>
The updated capacity requirements for the quote.
3437 3438 3439 3440 3441 3442 3443 3444 3445 3446 3447 3448 |
# File 'lib/aws-sdk-outposts/types.rb', line 3437 class UpdateQuoteInput < Struct.new( :quote_identifier, :outpost_identifier, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :description) SENSITIVE = [:description] include Aws::Structure end |
#requested_constraints ⇒ Array<Types::QuoteConstraint>
The updated physical constraints for the quote.
3437 3438 3439 3440 3441 3442 3443 3444 3445 3446 3447 3448 |
# File 'lib/aws-sdk-outposts/types.rb', line 3437 class UpdateQuoteInput < Struct.new( :quote_identifier, :outpost_identifier, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :description) SENSITIVE = [:description] include Aws::Structure end |
#requested_payment_options ⇒ Array<String>
The updated payment options to include in the quote pricing.
3437 3438 3439 3440 3441 3442 3443 3444 3445 3446 3447 3448 |
# File 'lib/aws-sdk-outposts/types.rb', line 3437 class UpdateQuoteInput < Struct.new( :quote_identifier, :outpost_identifier, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :description) SENSITIVE = [:description] include Aws::Structure end |
#requested_payment_terms ⇒ Array<String>
The updated payment terms to include in the quote pricing.
3437 3438 3439 3440 3441 3442 3443 3444 3445 3446 3447 3448 |
# File 'lib/aws-sdk-outposts/types.rb', line 3437 class UpdateQuoteInput < Struct.new( :quote_identifier, :outpost_identifier, :country_code, :requested_capacities, :requested_constraints, :requested_payment_options, :requested_payment_terms, :description) SENSITIVE = [:description] include Aws::Structure end |