Class: Aws::Outposts::Types::UpdateSiteInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::UpdateSiteInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
Note:
When making an API call, you may pass UpdateSiteInput data as a hash:
{
site_id: "SiteId", # required
name: "SiteName",
description: "SiteDescription",
notes: "SiteNotes",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The description of the site.
-
#name ⇒ String
The name of the site.
-
#notes ⇒ String
Notes about a site.
-
#site_id ⇒ String
The ID or the Amazon Resource Name (ARN) of the site.
Instance Attribute Details
#description ⇒ String
The description of the site.
1995 1996 1997 1998 1999 2000 2001 2002 |
# File 'lib/aws-sdk-outposts/types.rb', line 1995 class UpdateSiteInput < Struct.new( :site_id, :name, :description, :notes) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the site.
1995 1996 1997 1998 1999 2000 2001 2002 |
# File 'lib/aws-sdk-outposts/types.rb', line 1995 class UpdateSiteInput < Struct.new( :site_id, :name, :description, :notes) SENSITIVE = [] include Aws::Structure end |
#notes ⇒ String
Notes about a site.
1995 1996 1997 1998 1999 2000 2001 2002 |
# File 'lib/aws-sdk-outposts/types.rb', line 1995 class UpdateSiteInput < Struct.new( :site_id, :name, :description, :notes) SENSITIVE = [] include Aws::Structure end |
#site_id ⇒ String
The ID or the Amazon Resource Name (ARN) of the site.
<note markdown=“1”> In requests, Amazon Web Services Outposts accepts the Amazon Resource Name (ARN) or an ID for Outposts and sites throughout the Outposts Query API. To address backwards compatibility, the parameter names `OutpostID` or `SiteID` remain in use. Despite the parameter name, you can make the request with an ARN.
</note>
1995 1996 1997 1998 1999 2000 2001 2002 |
# File 'lib/aws-sdk-outposts/types.rb', line 1995 class UpdateSiteInput < Struct.new( :site_id, :name, :description, :notes) SENSITIVE = [] include Aws::Structure end |