Class: Aws::Outposts::Types::UpdateSiteRackPhysicalPropertiesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fiber_optic_cable_typeString

The type of fiber that you will use to attach the Outpost to your network.

Returns:

  • (String)


3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
3660
3661
3662
3663
# File 'lib/aws-sdk-outposts/types.rb', line 3650

class UpdateSiteRackPhysicalPropertiesInput < Struct.new(
  :site_id,
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_supported_weight_lbsString

The maximum rack weight that this site can support. ‘NO_LIMIT` is over 2000lbs.

Returns:

  • (String)


3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
3660
3661
3662
3663
# File 'lib/aws-sdk-outposts/types.rb', line 3650

class UpdateSiteRackPhysicalPropertiesInput < Struct.new(
  :site_id,
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

#optical_standardString

The type of optical standard that you will use to attach the Outpost to your network. This field is dependent on uplink speed, fiber type, and distance to the upstream device. For more information about networking requirements for racks, see [Network] in the Amazon Web Services Outposts User Guide.

  • ‘OPTIC_10GBASE_SR`: 10GBASE-SR

  • ‘OPTIC_10GBASE_IR`: 10GBASE-IR

  • ‘OPTIC_10GBASE_LR`: 10GBASE-LR

  • ‘OPTIC_40GBASE_SR`: 40GBASE-SR

  • ‘OPTIC_40GBASE_ESR`: 40GBASE-ESR

  • ‘OPTIC_40GBASE_IR4_LR4L`: 40GBASE-IR (LR4L)

  • ‘OPTIC_40GBASE_LR4`: 40GBASE-LR4

  • ‘OPTIC_100GBASE_SR4`: 100GBASE-SR4

  • ‘OPTIC_100GBASE_CWDM4`: 100GBASE-CWDM4

  • ‘OPTIC_100GBASE_LR4`: 100GBASE-LR4

  • ‘OPTIC_100G_PSM4_MSA`: 100G PSM4 MSA

  • ‘OPTIC_1000BASE_LX`: 1000Base-LX

  • ‘OPTIC_1000BASE_SX` : 1000Base-SX

[1]: docs.aws.amazon.com/outposts/latest/userguide/outposts-requirements.html#facility-networking

Returns:

  • (String)


3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
3660
3661
3662
3663
# File 'lib/aws-sdk-outposts/types.rb', line 3650

class UpdateSiteRackPhysicalPropertiesInput < Struct.new(
  :site_id,
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

#power_connectorString

The power connector that Amazon Web Services should plan to provide for connections to the hardware. Note the correlation between ‘PowerPhase` and `PowerConnector`.

  • Single-phase AC feed

    • L6-30P – (common in US); 30A; single phase

    • **IEC309 (blue)** – P+N+E, 6hr; 32 A; single phase

  • Three-phase AC feed

    • **AH530P7W (red)** – 3P+N+E, 7hr; 30A; three phase

    • **AH532P6W (red)** – 3P+N+E, 6hr; 32A; three phase

    • CS8365C – (common in US); 3P+E, 50A; three phase

Returns:

  • (String)


3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
3660
3661
3662
3663
# File 'lib/aws-sdk-outposts/types.rb', line 3650

class UpdateSiteRackPhysicalPropertiesInput < Struct.new(
  :site_id,
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

#power_draw_kvaString

The power draw, in kVA, available at the hardware placement position for the rack.

Returns:

  • (String)


3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
3660
3661
3662
3663
# File 'lib/aws-sdk-outposts/types.rb', line 3650

class UpdateSiteRackPhysicalPropertiesInput < Struct.new(
  :site_id,
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

#power_feed_dropString

Indicates whether the power feed comes above or below the rack.

Returns:

  • (String)


3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
3660
3661
3662
3663
# File 'lib/aws-sdk-outposts/types.rb', line 3650

class UpdateSiteRackPhysicalPropertiesInput < Struct.new(
  :site_id,
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

#power_phaseString

The power option that you can provide for hardware.

  • Single-phase AC feed: 200 V to 277 V, 50 Hz or 60 Hz

  • Three-phase AC feed: 346 V to 480 V, 50 Hz or 60 Hz

Returns:

  • (String)


3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
3660
3661
3662
3663
# File 'lib/aws-sdk-outposts/types.rb', line 3650

class UpdateSiteRackPhysicalPropertiesInput < Struct.new(
  :site_id,
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

#site_idString

The ID or the Amazon Resource Name (ARN) of the site.

Returns:

  • (String)


3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
3660
3661
3662
3663
# File 'lib/aws-sdk-outposts/types.rb', line 3650

class UpdateSiteRackPhysicalPropertiesInput < Struct.new(
  :site_id,
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

Racks come with two Outpost network devices. Depending on the supported uplink speed at the site, the Outpost network devices provide a variable number of uplinks. Specify the number of uplinks for each Outpost network device that you intend to use to connect the rack to your network. Note the correlation between ‘UplinkGbps` and `UplinkCount`.

  • 1Gbps - Uplinks available: 1, 2, 4, 6, 8

  • 10Gbps - Uplinks available: 1, 2, 4, 8, 12, 16

  • 40 and 100 Gbps- Uplinks available: 1, 2, 4

Returns:

  • (String)


3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
3660
3661
3662
3663
# File 'lib/aws-sdk-outposts/types.rb', line 3650

class UpdateSiteRackPhysicalPropertiesInput < Struct.new(
  :site_id,
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

The uplink speed the rack should support for the connection to the Region.

Returns:

  • (String)


3650
3651
3652
3653
3654
3655
3656
3657
3658
3659
3660
3661
3662
3663
# File 'lib/aws-sdk-outposts/types.rb', line 3650

class UpdateSiteRackPhysicalPropertiesInput < Struct.new(
  :site_id,
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end