Class: Aws::Outposts::Types::UpdateSiteRackPhysicalPropertiesInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Note:

When making an API call, you may pass UpdateSiteRackPhysicalPropertiesInput data as a hash:

{
  site_id: "SiteId", # required
  power_draw_kva: "POWER_5_KVA", # accepts POWER_5_KVA, POWER_10_KVA, POWER_15_KVA
  power_phase: "SINGLE_PHASE", # accepts SINGLE_PHASE, THREE_PHASE
  power_connector: "L6_30P", # accepts L6_30P, IEC309, AH530P7W, AH532P6W
  power_feed_drop: "ABOVE_RACK", # accepts ABOVE_RACK, BELOW_RACK
  uplink_gbps: "UPLINK_1G", # accepts UPLINK_1G, UPLINK_10G, UPLINK_40G, UPLINK_100G
  uplink_count: "UPLINK_COUNT_1", # accepts UPLINK_COUNT_1, UPLINK_COUNT_2, UPLINK_COUNT_3, UPLINK_COUNT_4, UPLINK_COUNT_5, UPLINK_COUNT_6, UPLINK_COUNT_7, UPLINK_COUNT_8, UPLINK_COUNT_12, UPLINK_COUNT_16
  fiber_optic_cable_type: "SINGLE_MODE", # accepts SINGLE_MODE, MULTI_MODE
  optical_standard: "OPTIC_10GBASE_SR", # accepts OPTIC_10GBASE_SR, OPTIC_10GBASE_IR, OPTIC_10GBASE_LR, OPTIC_40GBASE_SR, OPTIC_40GBASE_ESR, OPTIC_40GBASE_IR4_LR4L, OPTIC_40GBASE_LR4, OPTIC_100GBASE_SR4, OPTIC_100GBASE_CWDM4, OPTIC_100GBASE_LR4, OPTIC_100G_PSM4_MSA, OPTIC_1000BASE_LX, OPTIC_1000BASE_SX
  maximum_supported_weight_lbs: "NO_LIMIT", # accepts NO_LIMIT, MAX_1400_LBS, MAX_1600_LBS, MAX_1800_LBS, MAX_2000_LBS
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#fiber_optic_cable_typeString

Specify the type of fiber that you will use to attach the Outpost to your network.

Returns:

  • (String)


2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'lib/aws-sdk-outposts/types.rb', line 2149

class UpdateSiteRackPhysicalPropertiesInput < Struct.new(
  :site_id,
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_supported_weight_lbsString

Specify the maximum rack weight that this site can support. `NO_LIMIT` is over 2000lbs.

Returns:

  • (String)


2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'lib/aws-sdk-outposts/types.rb', line 2149

class UpdateSiteRackPhysicalPropertiesInput < Struct.new(
  :site_id,
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

#optical_standardString

Specify the type of optical standard that you will use to attach the Outpost to your network. This field is dependent on uplink speed, fiber type, and distance to the upstream device. For more information about networking requirements for racks, see

Network][1

in the Amazon Web Services Outposts User Guide.

  • `OPTIC_10GBASE_SR`: 10GBASE-SR

  • `OPTIC_10GBASE_IR`: 10GBASE-IR

  • `OPTIC_10GBASE_LR`: 10GBASE-LR

  • `OPTIC_40GBASE_SR`: 40GBASE-SR

  • `OPTIC_40GBASE_ESR`: 40GBASE-ESR

  • `OPTIC_40GBASE_IR4_LR4L`: 40GBASE-IR (LR4L)

  • `OPTIC_40GBASE_LR4`: 40GBASE-LR4

  • `OPTIC_100GBASE_SR4`: 100GBASE-SR4

  • `OPTIC_100GBASE_CWDM4`: 100GBASE-CWDM4

  • `OPTIC_100GBASE_LR4`: 100GBASE-LR4

  • `OPTIC_100G_PSM4_MSA`: 100G PSM4 MSA

  • `OPTIC_1000BASE_LX`: 1000Base-LX

  • `OPTIC_1000BASE_SX`: 1000Base-SX

[1]: docs.aws.amazon.com/outposts/latest/userguide/outposts-requirements.html#facility-networking

Returns:

  • (String)


2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'lib/aws-sdk-outposts/types.rb', line 2149

class UpdateSiteRackPhysicalPropertiesInput < Struct.new(
  :site_id,
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

#power_connectorString

Specify the power connector that Amazon Web Services should plan to provide for connections to the hardware. Note the correlation between `PowerPhase` and `PowerConnector`.

  • Single-phase AC feed

    • *L6-30P* – (common in US); 30A; single phase

    • **IEC309 (blue)** – P+N+E, 6hr; 32 A; single phase

  • Three-phase AC feed

    • **AH530P7W (red)** – 3P+N+E, 7hr; 30A; three phase

    • **AH532P6W (red)** – 3P+N+E, 6hr; 32A; three phase

Returns:

  • (String)


2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'lib/aws-sdk-outposts/types.rb', line 2149

class UpdateSiteRackPhysicalPropertiesInput < Struct.new(
  :site_id,
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

#power_draw_kvaString

Specify in kVA the power draw available at the hardware placement position for the rack.

Returns:

  • (String)


2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'lib/aws-sdk-outposts/types.rb', line 2149

class UpdateSiteRackPhysicalPropertiesInput < Struct.new(
  :site_id,
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

#power_feed_dropString

Specify whether the power feed comes above or below the rack.

Returns:

  • (String)


2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'lib/aws-sdk-outposts/types.rb', line 2149

class UpdateSiteRackPhysicalPropertiesInput < Struct.new(
  :site_id,
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

#power_phaseString

Specify the power option that you can provide for hardware.

  • Single-phase AC feed: 200 V to 277 V, 50 Hz or 60 Hz

  • Three-phase AC feed: 346 V to 480 V, 50 Hz or 60 Hz

Returns:

  • (String)


2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'lib/aws-sdk-outposts/types.rb', line 2149

class UpdateSiteRackPhysicalPropertiesInput < Struct.new(
  :site_id,
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

#site_idString

The ID or the Amazon Resource Name (ARN) of the site.

<note markdown=“1”> In requests, Amazon Web Services Outposts accepts the Amazon Resource Name (ARN) or an ID for Outposts and sites throughout the Outposts Query API. To address backwards compatibility, the parameter names `OutpostID` or `SiteID` remain in use. Despite the parameter name, you can make the request with an ARN.

</note>

Returns:

  • (String)


2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'lib/aws-sdk-outposts/types.rb', line 2149

class UpdateSiteRackPhysicalPropertiesInput < Struct.new(
  :site_id,
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

Racks come with two Outpost network devices. Depending on the supported uplink speed at the site, the Outpost network devices provide a variable number of uplinks. Specify the number of uplinks for each Outpost network device that you intend to use to connect the rack to your network. Note the correlation between `UplinkGbps` and `UplinkCount`.

  • 1Gbps - Uplinks available: 1, 2, 4, 6, 8

  • 10Gbps - Uplinks available: 1, 2, 4, 8, 12, 16

  • 40 and 100 Gbps- Uplinks available: 1, 2, 4

Returns:

  • (String)


2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'lib/aws-sdk-outposts/types.rb', line 2149

class UpdateSiteRackPhysicalPropertiesInput < Struct.new(
  :site_id,
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end

Specify the uplink speed the rack should support for the connection to the Region.

Returns:

  • (String)


2149
2150
2151
2152
2153
2154
2155
2156
2157
2158
2159
2160
2161
2162
# File 'lib/aws-sdk-outposts/types.rb', line 2149

class UpdateSiteRackPhysicalPropertiesInput < Struct.new(
  :site_id,
  :power_draw_kva,
  :power_phase,
  :power_connector,
  :power_feed_drop,
  :uplink_gbps,
  :uplink_count,
  :fiber_optic_cable_type,
  :optical_standard,
  :maximum_supported_weight_lbs)
  SENSITIVE = []
  include Aws::Structure
end