Class: Aws::Outposts::Types::UpdateSiteRackPhysicalPropertiesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Outposts::Types::UpdateSiteRackPhysicalPropertiesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-outposts/types.rb
Overview
When making an API call, you may pass UpdateSiteRackPhysicalPropertiesInput data as a hash:
{
site_id: "SiteId", # required
power_draw_kva: "POWER_5_KVA", # accepts POWER_5_KVA, POWER_10_KVA, POWER_15_KVA
power_phase: "SINGLE_PHASE", # accepts SINGLE_PHASE, THREE_PHASE
power_connector: "L6_30P", # accepts L6_30P, IEC309, AH530P7W, AH532P6W
power_feed_drop: "ABOVE_RACK", # accepts ABOVE_RACK, BELOW_RACK
uplink_gbps: "UPLINK_1G", # accepts UPLINK_1G, UPLINK_10G, UPLINK_40G, UPLINK_100G
uplink_count: "UPLINK_COUNT_1", # accepts UPLINK_COUNT_1, UPLINK_COUNT_2, UPLINK_COUNT_3, UPLINK_COUNT_4, UPLINK_COUNT_5, UPLINK_COUNT_6, UPLINK_COUNT_7, UPLINK_COUNT_8, UPLINK_COUNT_12, UPLINK_COUNT_16
fiber_optic_cable_type: "SINGLE_MODE", # accepts SINGLE_MODE, MULTI_MODE
optical_standard: "OPTIC_10GBASE_SR", # accepts OPTIC_10GBASE_SR, OPTIC_10GBASE_IR, OPTIC_10GBASE_LR, OPTIC_40GBASE_SR, OPTIC_40GBASE_ESR, OPTIC_40GBASE_IR4_LR4L, OPTIC_40GBASE_LR4, OPTIC_100GBASE_SR4, OPTIC_100GBASE_CWDM4, OPTIC_100GBASE_LR4, OPTIC_100G_PSM4_MSA, OPTIC_1000BASE_LX, OPTIC_1000BASE_SX
maximum_supported_weight_lbs: "NO_LIMIT", # accepts NO_LIMIT, MAX_1400_LBS, MAX_1600_LBS, MAX_1800_LBS, MAX_2000_LBS
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#fiber_optic_cable_type ⇒ String
Specify the type of fiber that you will use to attach the Outpost to your network.
-
#maximum_supported_weight_lbs ⇒ String
Specify the maximum rack weight that this site can support.
-
#optical_standard ⇒ String
Specify the type of optical standard that you will use to attach the Outpost to your network.
-
#power_connector ⇒ String
Specify the power connector that Amazon Web Services should plan to provide for connections to the hardware.
-
#power_draw_kva ⇒ String
Specify in kVA the power draw available at the hardware placement position for the rack.
-
#power_feed_drop ⇒ String
Specify whether the power feed comes above or below the rack.
-
#power_phase ⇒ String
Specify the power option that you can provide for hardware.
-
#site_id ⇒ String
The ID or the Amazon Resource Name (ARN) of the site.
-
#uplink_count ⇒ String
Racks come with two Outpost network devices.
-
#uplink_gbps ⇒ String
Specify the uplink speed the rack should support for the connection to the Region.
Instance Attribute Details
#fiber_optic_cable_type ⇒ String
Specify the type of fiber that you will use to attach the Outpost to your network.
1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 |
# File 'lib/aws-sdk-outposts/types.rb', line 1924 class UpdateSiteRackPhysicalPropertiesInput < Struct.new( :site_id, :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#maximum_supported_weight_lbs ⇒ String
Specify the maximum rack weight that this site can support. `NO_LIMIT` is over 2000lbs.
1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 |
# File 'lib/aws-sdk-outposts/types.rb', line 1924 class UpdateSiteRackPhysicalPropertiesInput < Struct.new( :site_id, :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#optical_standard ⇒ String
Specify the type of optical standard that you will use to attach the Outpost to your network. This field is dependent on uplink speed, fiber type, and distance to the upstream device. For more information about networking requirements for racks, see
- Network][1
-
in the Amazon Web Services Outposts User Guide.
-
`OPTIC_10GBASE_SR`: 10GBASE-SR
-
`OPTIC_10GBASE_IR`: 10GBASE-IR
-
`OPTIC_10GBASE_LR`: 10GBASE-LR
-
`OPTIC_40GBASE_SR`: 40GBASE-SR
-
`OPTIC_40GBASE_ESR`: 40GBASE-ESR
-
`OPTIC_40GBASE_IR4_LR4L`: 40GBASE-IR (LR4L)
-
`OPTIC_40GBASE_LR4`: 40GBASE-LR4
-
`OPTIC_100GBASE_SR4`: 100GBASE-SR4
-
`OPTIC_100GBASE_CWDM4`: 100GBASE-CWDM4
-
`OPTIC_100GBASE_LR4`: 100GBASE-LR4
-
`OPTIC_100G_PSM4_MSA`: 100G PSM4 MSA
-
`OPTIC_1000BASE_LX`: 1000Base-LX
-
`OPTIC_1000BASE_SX`: 1000Base-SX
[1]: docs.aws.amazon.com/outposts/latest/userguide/outposts-requirements.html#facility-networking
1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 |
# File 'lib/aws-sdk-outposts/types.rb', line 1924 class UpdateSiteRackPhysicalPropertiesInput < Struct.new( :site_id, :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#power_connector ⇒ String
Specify the power connector that Amazon Web Services should plan to provide for connections to the hardware. Note the correlation between `PowerPhase` and `PowerConnector`.
-
Single-phase AC feed
-
*L6-30P* – (common in US); 30A; single phase
-
**IEC309 (blue)** – P+N+E, 6hr; 32 A; single phase
-
-
Three-phase AC feed
-
**AH530P7W (red)** – 3P+N+E, 7hr; 30A; three phase
-
**AH532P6W (red)** – 3P+N+E, 6hr; 32A; three phase
-
1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 |
# File 'lib/aws-sdk-outposts/types.rb', line 1924 class UpdateSiteRackPhysicalPropertiesInput < Struct.new( :site_id, :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#power_draw_kva ⇒ String
Specify in kVA the power draw available at the hardware placement position for the rack.
1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 |
# File 'lib/aws-sdk-outposts/types.rb', line 1924 class UpdateSiteRackPhysicalPropertiesInput < Struct.new( :site_id, :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#power_feed_drop ⇒ String
Specify whether the power feed comes above or below the rack.
1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 |
# File 'lib/aws-sdk-outposts/types.rb', line 1924 class UpdateSiteRackPhysicalPropertiesInput < Struct.new( :site_id, :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#power_phase ⇒ String
Specify the power option that you can provide for hardware.
-
Single-phase AC feed: 200 V to 277 V, 50 Hz or 60 Hz
-
Three-phase AC feed: 346 V to 480 V, 50 Hz or 60 Hz
1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 |
# File 'lib/aws-sdk-outposts/types.rb', line 1924 class UpdateSiteRackPhysicalPropertiesInput < Struct.new( :site_id, :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#site_id ⇒ String
The ID or the Amazon Resource Name (ARN) of the site.
1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 |
# File 'lib/aws-sdk-outposts/types.rb', line 1924 class UpdateSiteRackPhysicalPropertiesInput < Struct.new( :site_id, :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#uplink_count ⇒ String
Racks come with two Outpost network devices. Depending on the supported uplink speed at the site, the Outpost network devices provide a variable number of uplinks. Specify the number of uplinks for each Outpost network device that you intend to use to connect the rack to your network. Note the correlation between `UplinkGbps` and `UplinkCount`.
-
1Gbps - Uplinks available: 1, 2, 4, 6, 8
-
10Gbps - Uplinks available: 1, 2, 4, 8, 12, 16
-
40 and 100 Gbps- Uplinks available: 1, 2, 4
1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 |
# File 'lib/aws-sdk-outposts/types.rb', line 1924 class UpdateSiteRackPhysicalPropertiesInput < Struct.new( :site_id, :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |
#uplink_gbps ⇒ String
Specify the uplink speed the rack should support for the connection to the Region.
1924 1925 1926 1927 1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 |
# File 'lib/aws-sdk-outposts/types.rb', line 1924 class UpdateSiteRackPhysicalPropertiesInput < Struct.new( :site_id, :power_draw_kva, :power_phase, :power_connector, :power_feed_drop, :uplink_gbps, :uplink_count, :fiber_optic_cable_type, :optical_standard, :maximum_supported_weight_lbs) SENSITIVE = [] include Aws::Structure end |