Class: Aws::Outposts::Types::VpcInformation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-outposts/types.rb

Overview

Information about a VPC used for private connectivity, including its subnets and an associated VPC endpoint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#subnet_idsArray<String>

The IDs of the subnets associated with the VPC endpoint. Currently, only one subnet is supported.

Returns:

  • (Array<String>)


3829
3830
3831
3832
3833
3834
3835
# File 'lib/aws-sdk-outposts/types.rb', line 3829

class VpcInformation < Struct.new(
  :vpc_id,
  :subnet_ids,
  :vpc_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_idString

The ID of the interface VPC endpoint for the Amazon Web Services Outposts service. When specified, the endpoint must be in the available state and the specified subnets must be associated with it.

Returns:

  • (String)


3829
3830
3831
3832
3833
3834
3835
# File 'lib/aws-sdk-outposts/types.rb', line 3829

class VpcInformation < Struct.new(
  :vpc_id,
  :subnet_ids,
  :vpc_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC used for private connectivity.

Returns:

  • (String)


3829
3830
3831
3832
3833
3834
3835
# File 'lib/aws-sdk-outposts/types.rb', line 3829

class VpcInformation < Struct.new(
  :vpc_id,
  :subnet_ids,
  :vpc_endpoint_id)
  SENSITIVE = []
  include Aws::Structure
end